@@ -540,6 +540,67 @@ GetLinkColors(int page_num, int *r, int *g, int *b)
      }
 }
 
+static void
+CalcOffset(Page * pg, int col_w, int x, int y, int th, int *pxspace, int *poff)
+{
+   int                 xspace, off;
+   int                 sx, sy, ssx, ssy;
+   Img_               *img;
+   int                 j;
+
+   xspace = col_w;
+   off = 0;
+   sx = x + off;
+   sy = y;
+   ssx = sx + col_w - 1;
+   ssy = sy + th - 1;
+   for (j = 0; j < pg->count; j++)
+     {
+	if (pg->obj[j].type != IMG)
+	   continue;
+
+	img = (Img_ *) pg->obj[j].object;
+	if ((img->w > 0) && (img->h > 0))
+	  {
+	     int                 ix, iy, iix, iiy;
+
+	     ix = img->x;
+	     iy = img->y;
+	     iix = img->x + img->w - 1;
+	     iiy = img->y + img->h - 1;
+
+	     if ((iy <= ssy) && (iiy >= sy))
+	       {
+		  if ((ix >= sx) && (ix <= ssx))
+		    {
+		       if ((iix >= sx) && (iix <= ssx))
+			 {
+			    if (((ix + iix) / 2) > ((sx + ssx) / 2))
+			       ssx = ix - 1;
+			    else
+			       sx = iix + 1;
+			 }
+		       else
+			 {
+			    ssx = ix - 1;
+			 }
+		    }
+		  else if ((iix >= sx) && (iix <= ssx))
+		    {
+		       sx = iix + 1;
+		    }
+	       }
+	  }
+     }
+   off = sx - x;
+   xspace = (ssx - sx) + 1;
+   if (xspace < 0)
+      xspace = 0;
+
+   *pxspace = xspace;
+   *poff = off;
+}
+
 Link               *
 RenderPage(Window win, int page_num, int w, int h)
 {
@@ -662,10 +723,9 @@ RenderPage(Window win, int page_num, int w, int h)
 		  char               *txt_disp;
 		  int                 tw, th, xspace;
 		  int                 off, j;
-		  int                 sx, sy, ssx, ssy;
 		  char                link_txt[1024];
 		  char                link_link[1024];
-		  int                 spaceflag, oldwc = 0;
+		  int                 spaceflag, oldwc = 0, linkwc;
 
 		  wd[0] = 0;
 #ifdef USE_WORD_MB
@@ -686,6 +746,7 @@ RenderPage(Window win, int page_num, int w, int h)
 		  if ((eot != 1) && spaceflag)
 		     strcat(s, " ");
 
+		  linkwc = -1;
 		  if (wd[0] == '_')
 		    {
 		       link_txt[0] = '\0';
@@ -745,9 +806,17 @@ RenderPage(Window win, int page_num, int w, int h)
 			      {
 				 wd[j++] = '\0';
 				 strcpy(link_link, wd + j);
-				 link_link[strlen(link_link) - 1] = '\0';
+				 k = strlen(link_link) - 1;
+				 if (k <= 0)
+				    continue;
+				 for (j = k; j > 0 && link_link[j] != ')'; j--)
+				    ;
+				 link_link[j] = '\0';
 				 strcpy(wd, link_txt);
+				 if (j < k)
+				    strcat(wd, link_link + j + 1);
 				 islink = 2;
+				 linkwc = wc;
 			      }
 			    else
 			       continue;
@@ -755,55 +824,9 @@ RenderPage(Window win, int page_num, int w, int h)
 		    }
 
 		  strcat(s, wd);
-		  xspace = col_w;
-		  off = 0;
-		  sx = x + off;
-		  sy = y;
-		  ssx = sx + col_w - 1;
-		  ssy = sy + ts.height - 1;
-		  for (j = 0; j < pg->count; j++)
-		    {
-		       if (pg->obj[j].type == IMG)
-			 {
-			    img = (Img_ *) pg->obj[j].object;
-			    if ((img->w > 0) && (img->h > 0))
-			      {
-				 int                 ix, iy, iix, iiy;
 
-				 ix = img->x;
-				 iy = img->y;
-				 iix = img->x + img->w - 1;
-				 iiy = img->y + img->h - 1;
+		  CalcOffset(pg, col_w, x, y, ts.height, &xspace, &off);
 
-				 if ((iy <= ssy) && (iiy >= sy))
-				   {
-				      if ((ix >= sx) && (ix <= ssx))
-					{
-					   if ((iix >= sx) && (iix <= ssx))
-					     {
-						if (((ix + iix) / 2) >
-						    ((sx + ssx) / 2))
-						   ssx = ix - 1;
-						else
-						   sx = iix + 1;
-					     }
-					   else
-					     {
-						ssx = ix - 1;
-					     }
-					}
-				      else if ((iix >= sx) && (iix <= ssx))
-					{
-					   sx = iix + 1;
-					}
-				   }
-			      }
-			 }
-		    }
-		  off = sx - x;
-		  xspace = (ssx - sx) + 1;
-		  if (xspace < 0)
-		     xspace = 0;
 		  TextSize(&ts, s, &tw, &th, 17);
 		  txt_disp = ss;
 		  if (eot == 1)
@@ -860,73 +883,8 @@ RenderPage(Window win, int page_num, int w, int h)
 					   y = pg->padding;
 					   x += col_w + pg->padding;
 					}
-				      xspace = col_w;
-				      off = 0;
-				      sx = x + off;
-				      sy = y;
-				      ssx = sx + col_w - 1;
-				      ssy = sy + ts.height - 1;
-				      for (j = 0; j < pg->count; j++)
-					{
-					   if (pg->obj[j].type == IMG)
-					     {
-						img =
-						   (Img_ *) pg->obj[j].object;
-						if ((img->w > 0)
-						    && (img->h > 0))
-						  {
-						     int                 ix,
-							iy, iix, iiy;
-
-						     ix = img->x;
-						     iy = img->y;
-						     iix = img->x + img->w - 1;
-						     iiy = img->y + img->h - 1;
-
-						     if ((iy <= ssy)
-							 && (iiy >= sy))
-						       {
-							  if ((ix >= sx)
-							      && (ix <= ssx))
-							    {
-							       if ((iix >= sx)
-								   && (iix <=
-								       ssx))
-								 {
-								    if (((ix +
-									  iix) /
-									 2) >
-									((sx +
-									  ssx) /
-									 2))
-								       ssx =
-									  ix -
-									  1;
-								    else
-								       sx =
-									  iix +
-									  1;
-								 }
-							       else
-								 {
-								    ssx =
-								       ix - 1;
-								 }
-							    }
-							  else if ((iix >= sx)
-								   && (iix <=
-								       ssx))
-							    {
-							       sx = iix + 1;
-							    }
-						       }
-						  }
-					     }
-					}
-				      off = sx - x;
-				      xspace = (ssx - sx) + 1;
-				      if (xspace < 0)
-					 xspace = 0;
+				      CalcOffset(pg, col_w, x, y, ts.height,
+						 &xspace, &off);
 				   }
 			      }
 			 }
@@ -937,7 +895,7 @@ RenderPage(Window win, int page_num, int w, int h)
 			    wastext = 1;
 			    TextDraw(&ts, win, txt_disp, x + off, y,
 				     xspace, 99999, 17, justification);
-			    if (islink > 1 && !strcmp(wd, link_txt))
+			    if (islink > 1 && linkwc > wc)
 			      {
 				 islink = 0;
 				 link_link[0] = '\0';
