@@ -24,55 +24,18 @@
  * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
 #include "config.h"
 
 #include "alert.h"
 #include "edebug.h"
 #include "lang.h"
-#include "sound.h"
+#include "sounds.h"
 #include "util.h"
 
-#define USE_EXT_INIT_WIN 1
-
 #include <X11/X.h>
 
-#ifdef HAVE_SM
-#define USE_SM 1
-#endif
-
-#ifdef HAVE_XSYNC
-#define USE_XSYNC 1
-#endif
-
-#ifdef HAVE_XSCREENSAVER
-#define USE_XSCREENSAVER 1	/* Experimental */
-#endif
-
-#ifdef HAVE_XRANDR
-#ifdef HAVE_X11_EXTENSIONS_XRANDR_H
-#define USE_XRANDR 1
-#endif
-#endif
-
-#ifdef HAVE_COMPOSITE
-#define USE_COMPOSITE 1
-#endif
-
-#ifdef HAVE_GLX
-#define USE_GLX 1
-#endif
-
 #include "xtypes.h"
 
-#define ENABLE_COLOR_MODIFIERS 0	/* Not functional */
-#define ENABLE_DESKRAY         0	/* Not functional */
-
-#define ENABLE_TRANSPARENCY 1
-#define ENABLE_THEME_TRANSPARENCY 1
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
@@ -80,13 +43,6 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#ifndef HAVE_STRCASESTR
-# define strcasestr(haystack, needle) strstr(haystack, needle)
-#endif
-#ifndef HAVE_STRCASECMP
-# define strcasecmp(s1, s2) strcmp(s1, s2)
-#endif
-
 #define FILEPATH_LEN_MAX 4096
 
 #ifndef MAX
@@ -193,6 +149,7 @@ typedef struct {
    struct {
       char                hiquality;
       char                user;
+      char                no_scan;
       int                 timeout;
    } backgrounds;
    struct {
@@ -258,6 +215,7 @@ typedef struct {
       char                avoid_server_grab;
       char                update_while_moving;
       char                enable_sync_request;
+      char                dragbar_nocover;
    } movres;
    struct {
       int                 movres;
@@ -277,7 +235,7 @@ typedef struct {
       int                 slidemode;
       int                 slidespeedmap;
       int                 slidespeedcleanup;
-#ifdef HAVE_XINERAMA
+#ifdef USE_XINERAMA
       char                extra_head;	/* Not used */
 #endif
    } place;
@@ -303,11 +261,9 @@ typedef struct {
       char                animate;
    } startup;
    struct {
-      char                localise;
       char                use_alt_font_cfg;
       char               *name;
       char               *extra_path;
-      char               *ttfont_path;
       char               *font_cfg;
    } theme;
 #ifdef ENABLE_THEME_TRANSPARENCY
@@ -346,6 +302,7 @@ typedef struct {
       int                 mask_alpha_threshold;
       char                enable_startup_id;
       char                use_render_for_scaling;
+      char                bindings_reload;
       unsigned int        no_sync_mask;
    } testing;
 
@@ -366,7 +323,7 @@ typedef struct {
    } conf;
    struct {
       char                dummy;	/* Prevent empty struct */
-#ifdef HAVE_XINERAMA
+#ifdef USE_XINERAMA
       char                xinerama_active;
 #endif
 #if USE_XSYNC
@@ -424,6 +381,7 @@ typedef struct {
       char                ext_pmap_valid;
    } root;
    struct {
+      char               *paths;
       char               *path;
    } theme;
    struct {
@@ -462,6 +420,7 @@ typedef struct {
    char                showing_desktop;
    Window              button_proxy_win;
    char                firsttime;
+   char                debug_exit;
 } EMode;
 
 /*
@@ -484,9 +443,8 @@ char               *GetLine(char *s, int size, FILE * f);
 int                 ConfigParseline1(char *str, char *s2, char **p2, char **p3);
 void                ConfigParseError(const char *where, const char *line);
 void                ConfigAlertLoad(const char *txt);
-char               *FindFile(const char *file, const char *themepath,
-			     int localized);
-char               *ThemeFileFind(const char *file, int localized);
+char               *FindFile(const char *file, const char *themepath);
+char               *ThemeFileFind(const char *file);
 char               *ConfigFileFind(const char *name, const char *themepath,
 				   int pp);
 int                 ConfigFileLoad(const char *name, const char *themepath,
@@ -497,8 +455,6 @@ int                 ThemeConfigLoad(void);
 /* dialog.c */
 void __PRINTF_2__   DialogOK(const char *title, const char *fmt, ...);
 void                DialogOKstr(const char *title, const char *txt);
-void __PRINTF__     DialogAlert(const char *fmt, ...);
-void __PRINTF__     DialogAlertOK(const char *fmt, ...);
 
 /* econfig.c */
 void                ConfigurationLoad(void);
@@ -527,8 +483,8 @@ void                SignalsSetup(void);
 void                SignalsRestore(void);
 
 /* main.c */
-void                EExit(int exitcode);
-const char         *EDirRoot(void);
+__NORETURN__ void   EExit(int exitcode);
+__EXPORT__ const char *EDirRoot(void);
 const char         *EDirBin(void);
 const char         *EDirUser(void);
 const char         *EDirUserCache(void);
@@ -560,6 +516,8 @@ void                StartupWindowsCreate(void);
 void                StartupWindowsOpen(void);
 
 /* theme.c */
+char               *ThemeFind(const char *theme);
+char               *ThemePathName(const char *path);
 void                ThemePathFind(void);
 char              **ThemesList(int *num);
 
@@ -568,6 +526,5 @@ char              **ThemesList(int *num);
  */
 extern const char   e_wm_name[];
 extern const char   e_wm_version[];
-extern const char   e_wm_date[];
 __EXPORT__ extern EConf Conf;
 __EXPORT__ extern EMode Mode;
