@@ -30,6 +30,7 @@
 #include "ewins.h"
 #include "file.h"
 #include "grabs.h"
+#include "timers.h"
 #include <ctype.h>
 
 typedef struct _actiontype {
@@ -186,10 +187,20 @@ ActionclassCreate(const char *name, int global)
 }
 
 static void
-ActionclassDestroy(ActionClass * ac)
+ActionclassEmpty(ActionClass * ac)
 {
    int                 i;
 
+   for (i = 0; i < ac->num; i++)
+      ActionDestroy(ac->list[i]);
+   ac->num = 0;
+   _EFREE(ac->list);
+   _EFREE(ac->tooltipstring);
+}
+
+static void
+ActionclassDestroy(ActionClass * ac)
+{
    if (!ac)
       return;
 
@@ -202,11 +213,8 @@ ActionclassDestroy(ActionClass * ac)
 
    ecore_list_node_remove(aclass_list, ac);
 
-   for (i = 0; i < ac->num; i++)
-      ActionDestroy(ac->list[i]);
-   Efree(ac->list);
+   ActionclassEmpty(ac);
    Efree(ac->name);
-   Efree(ac->tooltipstring);
 
    Efree(ac);
    mode_action_destroy = 1;
@@ -302,19 +310,17 @@ AclassConfigLoad(FILE * fs)
 
 	  case CONFIG_CLASSNAME:
 	  case ACLASS_NAME:
-	     ac = (ActionClass *) ecore_list_node_remove(aclass_list,
-							 ActionclassFind(s2));
-	     if (!ac)
-		ac = (ActionClass *) ecore_list_node_remove(aclass_list_global,
-							    ActionclassFindGlobal
-							    (s2));
+	     ac = ActionclassFindAny(s2);
 	     if (ac)
 	       {
 		  if (!strcmp(s2, "KEYBINDINGS"))
 		     Mode.keybinds_changed = 1;
-		  ActionclassDestroy(ac);
+		  ActionclassEmpty(ac);
+	       }
+	     else
+	       {
+		  ac = ActionclassCreate(s2, 0);
 	       }
-	     ac = ActionclassCreate(s2, 0);
 	     break;
 	  case CONFIG_TYPE:
 	  case ACLASS_TYPE:
@@ -712,16 +718,9 @@ AclassConfigLoad2(FILE * fs)
 	       }
 	     else
 	       {
-		  ac = (ActionClass *) ecore_list_node_remove(aclass_list,
-							      ActionclassFind
-							      (prm2));
-		  if (!ac)
-		     ac = (ActionClass *)
-			ecore_list_node_remove(aclass_list_global,
-					       ActionclassFindGlobal(prm2));
+		  ac = ActionclassFindAny(prm2);
 		  if (ac)
-		     ActionclassDestroy(ac);
-		  ac = NULL;
+		     ActionclassEmpty(ac);
 	       }
 
 	     if (!ac)
@@ -778,27 +777,6 @@ AclassConfigLoadConfig(const char *name)
    fclose(fs);
 }
 
-/* This is now only for backward compatibility */
-static void
-AclassConfigLoadUser(void)
-{
-   char                s[FILEPATH_LEN_MAX], ss[FILEPATH_LEN_MAX];
-   FILE               *fs;
-
-   Esnprintf(s, sizeof(s), "%s.bindings", EGetSavePrefixCommon());
-   fs = fopen(s, "r");
-   if (!fs)
-      return;
-
-   AclassConfigLoad2(fs);
-
-   fclose(fs);
-
-   /* This file should no longer be used. Rename. */
-   Esnprintf(ss, sizeof(ss), "%s.old", s);
-   E_mv(s, ss);
-}
-
 static void
 AclassConfigWrite(const ActionClass * ac, void (*prf) (const char *fmt, ...))
 {
@@ -1125,26 +1103,20 @@ ActionclassesGlobalEvent(XEvent * ev)
    return match;
 }
 
-static void
-AclassSetupFallback(void)
+static int
+_ac_reload(void *data __UNUSED__)
 {
-   ActionClass        *ac;
-   Action             *aa;
+   AclassConfigLoadConfig("bindings.cfg");
+   return 0;
+}
 
-   /* Create a default fallback actionclass for the fallback border */
-   ac = ActionclassCreate("__FALLBACK_ACTION", 0);
+void
+ActionclassesReload(void)
+{
+   static Timer       *ac_reload_timer;
 
-   aa = ActionCreate(EVENT_MOUSE_DOWN, 1, 0, 0, 1, 0, NULL, NULL);
-   ActionclassAddAction(ac, aa);
-   ActionAddTo(aa, "wop * mo ptr");
-
-   aa = ActionCreate(EVENT_MOUSE_DOWN, 1, 0, 0, 2, 0, NULL, NULL);
-   ActionclassAddAction(ac, aa);
-   ActionAddTo(aa, "wop * close");
-
-   aa = ActionCreate(EVENT_MOUSE_DOWN, 1, 0, 0, 3, 0, NULL, NULL);
-   ActionclassAddAction(ac, aa);
-   ActionAddTo(aa, "wop * sz ptr");
+   TIMER_DEL(ac_reload_timer);
+   TIMER_ADD(ac_reload_timer, 0.2, _ac_reload, NULL);
 }
 
 /*
@@ -1157,9 +1129,7 @@ AclassSighan(int sig, void *prm __UNUSED__)
    switch (sig)
      {
      case ESIGNAL_INIT:
-	AclassSetupFallback();
 	AclassConfigLoadConfig("bindings.cfg");
-	AclassConfigLoadUser();
 	break;
      }
 }
@@ -1314,13 +1284,11 @@ IPC_KeybindingsSet(const char *params)
 
    Mode.keybinds_changed = 1;
 
-   ac = (ActionClass *) ecore_list_node_remove(aclass_list_global,
-					       ActionclassFindGlobal
-					       ("KEYBINDINGS"));
+   ac = ActionclassFindGlobal("KEYBINDINGS");
    if (ac)
-      ActionclassDestroy(ac);
-
-   ac = ActionclassCreate("KEYBINDINGS", 1);
+      ActionclassEmpty(ac);
+   else
+      ac = ActionclassCreate("KEYBINDINGS", 1);
    if (!ac)
       return;
 
@@ -1427,13 +1395,12 @@ extern const EModule ModAclass;
 const EModule       ModAclass = {
    "aclass", "ac",
    AclassSighan,
-   {N_IPC_FUNCS, AclassIpcArray}
-   ,
+   {N_IPC_FUNCS, AclassIpcArray},
    {0, NULL}
 };
 
 void
-GrabButtonGrabs(EWin * ewin)
+GrabButtonGrabs(Win win)
 {
    ActionClass        *ac;
    int                 j;
@@ -1448,20 +1415,20 @@ GrabButtonGrabs(EWin * ewin)
    for (j = 0; j < ac->num; j++)
      {
 	aa = ac->list[j];
-	if ((!aa) || ((aa->event != EVENT_MOUSE_DOWN)
-		      && (aa->event != EVENT_MOUSE_UP)))
+	if ((!aa) || ((aa->event != EVENT_MOUSE_DOWN) &&
+		      (aa->event != EVENT_MOUSE_UP)))
 	   continue;
 
 	mod = (aa->anymodifier) ? AnyModifier : aa->modifiers;
 	button = (aa->anybutton) ? AnyButton : aa->button;
 	mask = ButtonPressMask | ButtonReleaseMask;
 
-	GrabButtonSet(button, mod, EoGetWin(ewin), mask, ECSR_PGRAB, 1);
+	GrabButtonSet(button, mod, win, mask, ECSR_PGRAB, 1);
      }
 }
 
 void
-UnGrabButtonGrabs(EWin * ewin)
+UnGrabButtonGrabs(Win win)
 {
    ActionClass        *ac;
    int                 j;
@@ -1483,7 +1450,7 @@ UnGrabButtonGrabs(EWin * ewin)
 	mod = (aa->anymodifier) ? AnyModifier : aa->modifiers;
 	button = (aa->anybutton) ? AnyButton : aa->button;
 
-	GrabButtonRelease(button, mod, EoGetWin(ewin));
+	GrabButtonRelease(button, mod, win);
      }
 }
 
