@@ -53,9 +53,6 @@ struct _background {
    char                bg_tile;
    BgPart              bg;
    BgPart              top;
-#if ENABLE_COLOR_MODIFIERS
-   ColorModifierClass *cmclass;
-#endif
    char                external;
    char                keepim;
    char                referenced;
@@ -64,6 +61,7 @@ struct _background {
 };
 
 static Ecore_List  *bg_list = NULL;
+static Timer       *bg_timer = NULL;
 static unsigned int bg_seq_no = 0;
 
 #define N_BG_ASSIGNED 32
@@ -95,7 +93,7 @@ BackgroundGetUniqueString(const Background * bg)
      {
 	char               *f;
 
-	f = ThemeFileFind(bg->bg.file, 0);
+	f = ThemeFileFind(bg->bg.file);
 	if (f)
 	  {
 	     f1 = fileinode(f);
@@ -108,7 +106,7 @@ BackgroundGetUniqueString(const Background * bg)
      {
 	char               *f;
 
-	f = ThemeFileFind(bg->top.file, 0);
+	f = ThemeFileFind(bg->top.file);
 	if (f)
 	  {
 	     f4 = fileinode(f);
@@ -261,7 +259,7 @@ BackgroundDelete(Background * bg)
    /* And delete the actual image files */
    if (bg->bg.file)
      {
-	f = ThemeFileFind(bg->bg.file, 0);
+	f = ThemeFileFind(bg->bg.file);
 	if (f)
 	  {
 	     E_rm(f);
@@ -270,7 +268,7 @@ BackgroundDelete(Background * bg)
      }
    if (bg->top.file)
      {
-	f = ThemeFileFind(bg->top.file, 0);
+	f = ThemeFileFind(bg->top.file);
 	if (f)
 	  {
 	     E_rm(f);
@@ -327,6 +325,9 @@ BackgroundCreate(const char *name, EColor * solid, const char *bgn, char tile,
 static int
 BackgroundCmp(Background * bg, Background * bgx)
 {
+   if (*bgx->name != '.')	/* Discard only generated backgrounds */
+      return 1;
+
    if (bg->bg.file && bgx->bg.file)
      {
 	if ((strcmp(bg->bg.file, bgx->bg.file)) ||
@@ -469,15 +470,6 @@ BackgroundModify(Background * bg, EColor * solid, const char *bgn, char tile,
    return updated;
 }
 
-#if ENABLE_COLOR_MODIFIERS
-static void
-BackgroundSetColorMofifier(Background * bg, ColorModifierClass * cm)
-{
-   cm->ref_count++;
-   bg->cmclass = cm;
-}
-#endif
-
 static void
 BgFindImageSize(BgPart * bgp, unsigned int rw, unsigned int rh,
 		unsigned int *pw, unsigned int *ph)
@@ -556,14 +548,10 @@ BackgroundRealize(Background * bg, Win win, Drawable draw, unsigned int rw,
    char                hasbg, hasfg;
    EImage             *im;
 
-#if ENABLE_COLOR_MODIFIERS
-   ColorModifierClass *cm;
-#endif
-
    if (bg->bg.file && !bg->bg.im)
      {
 	if (!bg->bg.real_file)
-	   bg->bg.real_file = ThemeFileFind(bg->bg.file, 0);
+	   bg->bg.real_file = ThemeFileFind(bg->bg.file);
 	if (bg->bg.real_file)
 	   bg->bg.im = EImageLoad(bg->bg.real_file);
      }
@@ -571,42 +559,11 @@ BackgroundRealize(Background * bg, Win win, Drawable draw, unsigned int rw,
    if (bg->top.file && !bg->top.im)
      {
 	if (!bg->top.real_file)
-	   bg->top.real_file = ThemeFileFind(bg->top.file, 0);
+	   bg->top.real_file = ThemeFileFind(bg->top.file);
 	if (bg->top.real_file)
 	   bg->top.im = EImageLoad(bg->top.real_file);
      }
 
-#if ENABLE_COLOR_MODIFIERS
-   cm = bg->cmclass;
-   if (cm)
-      cm->ref_count--;
-   else
-      cm = FindItem("BACKGROUND", 0, LIST_FINDBY_NAME, LIST_TYPE_COLORMODIFIER);
-
-   if (cm)
-     {
-	cm->ref_count++;
-#if 0				/* To be implemented? */
-	if (bg->top.im)
-	  {
-	     Imlib_set_image_red_curve(pImlib_Context, bg->top.im, cm->red.map);
-	     Imlib_set_image_green_curve(pImlib_Context, bg->top.im,
-					 cm->green.map);
-	     Imlib_set_image_blue_curve(pImlib_Context, bg->top.im,
-					cm->blue.map);
-	  }
-	if (bg->bg.im)
-	  {
-	     Imlib_set_image_red_curve(pImlib_Context, bg->bg.im, cm->red.map);
-	     Imlib_set_image_green_curve(pImlib_Context, bg->bg.im,
-					 cm->green.map);
-	     Imlib_set_image_blue_curve(pImlib_Context, bg->bg.im,
-					cm->blue.map);
-	  }
-#endif
-     }
-#endif
-
    if (!draw)
       draw = WinGetXwin(win);
 
@@ -944,14 +901,6 @@ BackgroundGetFgFile(const Background * bg)
    return bg->top.file;
 }
 
-#if 0				/* Unused */
-int
-BackgroundGetColor(const Background * bg)
-{
-   return (bg->pmap) ? 0 : bg->bg_solid.pixel;
-}
-#endif
-
 Pixmap
 BackgroundGetPixmap(const Background * bg)
 {
@@ -1118,11 +1067,7 @@ BackgroundsConfigLoad(FILE * fs)
    char               *bg2 = 0;
    char               *name = 0;
    char                ignore = 0;
-   unsigned int        desk;
-
-#if ENABLE_COLOR_MODIFIERS
-   ColorModifierClass *cm = NULL;
-#endif
+   int                 desk;
 
    SET_COLOR(&color, 0, 0, 0);
 
@@ -1132,49 +1077,13 @@ BackgroundsConfigLoad(FILE * fs)
 	switch (ii1)
 	  {
 	  case CONFIG_CLOSE:
-	     if (!ignore)
-	       {
-		  if ((!bg) && (name))
-		    {
-		       char               *tmp;
-		       char                ok = 1;
-
-		       /* check first if we can actually find the files */
-		       if (bg1)
-			 {
-			    tmp = ThemeFileFind(bg1, 0);
-			    if (!tmp)
-			       ok = 0;
-			    else
-			       Efree(tmp);
-			 }
-		       if (bg2)
-			 {
-			    tmp = ThemeFileFind(bg2, 0);
-			    if (!tmp)
-			       ok = 0;
-			    else
-			       Efree(tmp);
-			 }
-		       if (ok)
-			 {
-			    bg = BackgroundCreate(name, &color, bg1, i1, i2, i3,
-						  i4, i5, i6, bg2, j1, j2, j3,
-						  j4, j5);
-#if ENABLE_COLOR_MODIFIERS
-			    if (cm)
-			       BackgroundSetColorMofifier(bg, cm);
-#endif
-			 }
-		    }
-	       }
+	     if (!ignore && !bg && name)
+		bg = BackgroundCreate(name, &color, bg1, i1, i2, i3, i4, i5,
+				      i6, bg2, j1, j2, j3, j4, j5);
 	     goto done;
 
 	  case CONFIG_COLORMOD:
 	  case ICLASS_COLORMOD:
-#if ENABLE_COLOR_MODIFIERS
-	     cm = FindItem(s2, 0, LIST_FINDBY_NAME, LIST_TYPE_COLORMODIFIER);
-#endif
 	     break;
 
 	  case CONFIG_CLASSNAME:
@@ -1192,20 +1101,30 @@ BackgroundsConfigLoad(FILE * fs)
 	     break;
 
 	  case BG_DESKNUM:
+	     if (!ignore && !bg && name)
+		bg = BackgroundCreate(name, &color, bg1, i1, i2, i3, i4, i5,
+				      i6, bg2, j1, j2, j3, j4, j5);
+	     if (!bg)
+		break;
 	     desk = atoi(s2);
 	     if (desk >= N_BG_ASSIGNED)
 		break;
-	     if (!bg_assigned[desk] || Conf.backgrounds.user)
+	     if (desk >= 0)
 	       {
-		  if (!ignore)
+		  if (!bg_assigned[desk] || Conf.backgrounds.user)
 		    {
-		       if (!bg)
-			  bg = BackgroundCreate(name, &color, bg1, i1, i2,
-						i3, i4, i5, i6, bg2, j1,
-						j2, j3, j4, j5);
+		       bg_assigned[desk] = bg;
+		       bg->referenced = 1;
 		    }
-		  bg_assigned[desk] = bg;
+	       }
+	     else
+	       {
 		  bg->referenced = 1;
+		  for (ii1 = 0; ii1 < N_BG_ASSIGNED; ii1++)
+		    {
+		       if (!bg_assigned[ii1])
+			  bg_assigned[ii1] = bg;
+		    }
 	       }
 	     break;
 
@@ -1313,10 +1232,10 @@ BackgroundsConfigSave(void)
 	fprintf(fs, "560 %d %d %d\n", r, g, b);
 
 	if ((bg->bg.file) && (!bg->bg.real_file))
-	   bg->bg.real_file = ThemeFileFind(bg->bg.file, 0);
+	   bg->bg.real_file = ThemeFileFind(bg->bg.file);
 
 	if ((bg->top.file) && (!bg->top.real_file))
-	   bg->top.real_file = ThemeFileFind(bg->top.file, 0);
+	   bg->top.real_file = ThemeFileFind(bg->top.file);
 
 	if ((bg->bg.file) && (bg->bg.real_file))
 	  {
@@ -1348,13 +1267,6 @@ BackgroundsConfigSave(void)
 		     bg->top.yperc);
 	  }
 
-#if ENABLE_COLOR_MODIFIERS
-	if (bg->cmclass)
-	  {
-	     fprintf(fs, "370 %s\n", bg->cmclass->name);
-	  }
-#endif
-
 	for (j = 0; j < N_BG_ASSIGNED; j++)
 	  {
 	     if (bg == bg_assigned[j])
@@ -1423,16 +1335,17 @@ BackgroundsAccounting(void)
    }
 }
 
-static void
-BackgroundsTimeout(int val __UNUSED__, void *data __UNUSED__)
+static int
+BackgroundsTimeout(void *data __UNUSED__)
 {
    if (Conf.backgrounds.timeout <= 0)
       Conf.backgrounds.timeout = 1;
 
    BackgroundsAccounting();
 
-   DoIn("BACKGROUND_ACCOUNTING_TIMEOUT", 1.0 * Conf.backgrounds.timeout,
-	BackgroundsTimeout, 0, NULL);
+   TimerSetInterval(bg_timer, 1.0 * Conf.backgrounds.timeout);
+
+   return 1;
 }
 
 static void
@@ -1454,8 +1367,7 @@ BackgroundsSighan(int sig, void *prm __UNUSED__)
 	break;
 
      case ESIGNAL_START:
-	DoIn("BACKGROUND_ACCOUNTING_TIMEOUT", 30.0, BackgroundsTimeout, 0,
-	     NULL);
+	TIMER_ADD(bg_timer, 30.0, BackgroundsTimeout, NULL);
 	break;
 
      case ESIGNAL_EXIT:
@@ -1519,9 +1431,9 @@ CB_ConfigureBG(Dialog * d __UNUSED__, int val, void *data __UNUSED__)
 	tmp_bg->bg_tile = tmp_bg_tile;
 	tmp_bg->bg.keep_aspect = tmp_bg_keep_aspect;
 	tmp_bg->bg.xjust = tmp_bg_xjust;
-	tmp_bg->bg.yjust = 1024 - tmp_bg_yjust;
+	tmp_bg->bg.yjust = tmp_bg_yjust;
 	tmp_bg->bg.xperc = tmp_bg_xperc;
-	tmp_bg->bg.yperc = 1024 - tmp_bg_yperc;
+	tmp_bg->bg.yperc = tmp_bg_yperc;
 	if (!tmp_bg_image)
 	   BackgroundFilesRemove(tmp_bg);
 
@@ -1558,13 +1470,13 @@ CB_DesktopMiniDisplayRedraw(Dialog * d __UNUSED__, int val __UNUSED__,
    fbg = (tmp_bg_image) ? BackgroundGetBgFile(tmp_bg) : NULL;
    ffg = (tmp_bg_image) ? BackgroundGetFgFile(tmp_bg) : NULL;
    SET_COLOR(&color, tmp_bg_r, tmp_bg_g, tmp_bg_b);
-   bg = BackgroundCreate("TEMP", &color, fbg, tmp_bg_tile,
-			 tmp_bg_keep_aspect, tmp_bg_xjust,
-			 1024 - tmp_bg_yjust, tmp_bg_xperc,
-			 1024 - tmp_bg_yperc, ffg,
-			 tmp_bg->top.keep_aspect, tmp_bg->top.xjust,
-			 tmp_bg->top.yjust, tmp_bg->top.xperc,
-			 tmp_bg->top.yperc);
+   bg = BackgroundCreate("TEMP", &color,
+			 fbg, tmp_bg_tile, tmp_bg_keep_aspect,
+			 tmp_bg_xjust, tmp_bg_yjust,
+			 tmp_bg_xperc, tmp_bg_yperc,
+			 ffg, tmp_bg->top.keep_aspect,
+			 tmp_bg->top.xjust, tmp_bg->top.yjust,
+			 tmp_bg->top.xperc, tmp_bg->top.yperc);
 
    BackgroundApplyPmap(bg, win, pmap, w, h);
    BackgroundDestroy(bg);
@@ -1581,23 +1493,21 @@ BG_GetValues(void)
    tmp_bg_tile = tmp_bg->bg_tile;
    tmp_bg_keep_aspect = tmp_bg->bg.keep_aspect;
    tmp_bg_xjust = tmp_bg->bg.xjust;
-   tmp_bg_yjust = 1024 - tmp_bg->bg.yjust;
+   tmp_bg_yjust = tmp_bg->bg.yjust;
    tmp_bg_xperc = tmp_bg->bg.xperc;
-   tmp_bg_yperc = 1024 - tmp_bg->bg.yperc;
+   tmp_bg_yperc = tmp_bg->bg.yperc;
 }
 
 static void
 BG_DialogSetFileName(DItem * di)
 {
-   char               *stmp = NULL;
+   const char         *stmp;
    char                s[1024];
 
-   if (BackgroundGetBgFile(tmp_bg))
-      stmp = fullfileof(BackgroundGetBgFile(tmp_bg));
+   stmp = fullfileof(BackgroundGetBgFile(tmp_bg));
    Esnprintf(s, sizeof(s),
 	     _("Background definition information:\nName: %s\nFile: %s\n"),
 	     BackgroundGetName(tmp_bg), (stmp) ? stmp : _("-NONE-"));
-   Efree(stmp);
    DialogItemSetText(di, s);
 }
 
@@ -1652,13 +1562,13 @@ CB_ConfigureNewBG(Dialog * d __UNUSED__, int val __UNUSED__,
 
    SET_COLOR(&color, tmp_bg_r, tmp_bg_g, tmp_bg_b);
 
-   tmp_bg = BackgroundCreate(s, &color, tmp_bg->bg.file, tmp_bg_tile,
-			     tmp_bg_keep_aspect, tmp_bg_xjust,
-			     1024 - tmp_bg_yjust, tmp_bg_xperc,
-			     1024 - tmp_bg_yperc, tmp_bg->top.file,
-			     tmp_bg->top.keep_aspect, tmp_bg->top.xjust,
-			     tmp_bg->top.yjust, tmp_bg->top.xperc,
-			     tmp_bg->top.yperc);
+   tmp_bg = BackgroundCreate(s, &color,
+			     tmp_bg->bg.file, tmp_bg_tile, tmp_bg_keep_aspect,
+			     tmp_bg_xjust, tmp_bg_yjust,
+			     tmp_bg_xperc, tmp_bg_yperc,
+			     tmp_bg->top.file, tmp_bg->top.keep_aspect,
+			     tmp_bg->top.xjust, tmp_bg->top.yjust,
+			     tmp_bg->top.xperc, tmp_bg->top.yperc);
 
    DialogItemSliderGetBounds(bg_sel_slider, &lower, &upper);
    upper += 4;
@@ -1733,7 +1643,6 @@ BG_RedrawView(void)
    int                 x, w, h, num;
    Win                 win;
    Pixmap              pmap;
-   GC                  gc;
    ImageClass         *ic_button;
 
    num = ecore_list_count(bg_list);
@@ -1744,12 +1653,10 @@ BG_RedrawView(void)
    DialogItemAreaGetSize(bg_sel, &w, &h);
 
    pmap = EGetWindowBackgroundPixmap(win);
-   gc = EXCreateGC(pmap, 0, NULL);
 
-   ic_button = ImageclassFind("DIALOG_BUTTON", 0);
+   ic_button = ImageclassFind("DIALOG_BUTTON", 1);
 
-   XSetForeground(disp, gc, Dpy.pixel_black);
-   XFillRectangle(disp, pmap, gc, 0, 0, w, h);
+   ImageclassApplySimple(ic_button, win, pmap, STATE_NORMAL, 0, 0, w, h);
 
    x = -(num * (64 + 8) - w) * tmp_bg_sel_sliderval / (4 * num);
 
@@ -1759,11 +1666,9 @@ BG_RedrawView(void)
 	{
 	   EImage             *im;
 
-	   if (ic_button)
-	      ImageclassApplySimple(ic_button, win, pmap,
-				    (bg == tmp_bg) ?
-				    STATE_CLICKED : STATE_NORMAL,
-				    x, 0, 64 + 8, 48 + 8);
+	   ImageclassApplySimple(ic_button, win, pmap,
+				 (bg == tmp_bg) ? STATE_CLICKED : STATE_NORMAL,
+				 x, 0, 64 + 8, 48 + 8);
 
 	   if (BackgroundIsNone(bg))
 	     {
@@ -1793,7 +1698,6 @@ BG_RedrawView(void)
 	}
       x += (64 + 8);
    }
-   EXFreeGC(gc);
 
    EClearWindow(win);
 }
@@ -1810,18 +1714,15 @@ CB_BGAreaSlide(Dialog * d __UNUSED__, int val __UNUSED__, void *data __UNUSED__)
 static void
 CB_BGScan(Dialog * d, int val __UNUSED__, void *data __UNUSED__)
 {
-   int                 slider, lower, upper;
+   int                 num;
 
-   SoundPlay("SOUND_WAIT");
+   SoundPlay(SOUND_WAIT);
+   ScanBackgroundMenu();
 
-   DialogItemSliderGetBounds(bg_sel_slider, &lower, &upper);
-
-   for (slider = lower; slider <= upper; slider += 8)
-     {
-	DialogItemSliderSetVal(bg_sel_slider, slider);
-	DialogDrawItems(bg_sel_dialog, bg_sel_slider, 0, 0, 99999, 99999);
-	DialogItemCallCallback(d, bg_sel_slider);
-     }
+   num = ecore_list_count(bg_list);
+   DialogItemSliderSetBounds(bg_sel_slider, 0, num * 4);
+   DialogDrawItems(d, bg_sel_slider, 0, 0, 99999, 99999);
+   DialogItemCallCallback(d, bg_sel_slider);
 }
 
 static void
@@ -2057,7 +1958,8 @@ _DlgFillBackground(Dialog * d, DItem * table, void *data)
    int                 i, num;
    char                s[1024];
 
-   ScanBackgroundMenu();
+   if (!Conf.backgrounds.no_scan)
+      ScanBackgroundMenu();
 
    if (!bg)
       bg = DeskBackgroundGet(DesksGetCurrent());
@@ -2319,7 +2221,7 @@ const DialogDef     DlgBackground = {
    "CONFIGURE_BG",
    N_("Background"),
    N_("Desktop Background Settings"),
-   "SOUND_SETTINGS_BG",
+   SOUND_SETTINGS_BG,
    "pix/bg.png",
    N_("Enlightenment Desktop\n" "Background Settings Dialog\n"),
    _DlgFillBackground,
@@ -2515,10 +2417,6 @@ BackgroundsIpc(const char *params)
 	BackgroundApplyWin(bg, win);
 	EDestroyWin(win);
      }
-   else if (!strncmp(cmd, "cfg", 2))
-     {
-	DialogShowSimple(&DlgBackground, DeskBackgroundGet(DesksGetCurrent()));
-     }
    else if (!strncmp(cmd, "del", 2))
      {
 	BackgroundDestroyByName(prm);
@@ -2621,56 +2519,6 @@ IPC_BackgroundUse(const char *params)
    autosave();
 }
 
-#if ENABLE_COLOR_MODIFIERS
-static void
-IPC_BackgroundColormodifierSet(const char *params)
-{
-   Background         *bg;
-   ColorModifierClass *cm;
-   int                 i;
-   char                buf[FILEPATH_LEN_MAX], buf2[FILEPATH_LEN_MAX];
-
-   if (params == NULL)
-      return;
-
-   sscanf(params, "%1000s %1000s", buf, buf2);
-   bg = BackgroundFind(buf);
-   cm = FindItem(buf2, 0, LIST_FINDBY_NAME, LIST_TYPE_COLORMODIFIER);
-   if ((bg) && (bg->cmclass != cm))
-     {
-	if (!strcmp(buf, "(null)"))
-	  {
-	     bg->cmclass->ref_count--;
-	     bg->cmclass = NULL;
-	  }
-	else if (cm)
-	  {
-	     bg->cmclass->ref_count--;
-	     bg->cmclass = cm;
-	  }
-
-	BackgroundInvalidate(bg, 1);
-     }
-}
-
-static void
-IPC_BackgroundColormodifierGet(const char *params)
-{
-   char                param1[FILEPATH_LEN_MAX], buf[FILEPATH_LEN_MAX];
-   Background         *bg;
-
-   if (params == NULL)
-      return;
-
-   sscanf(params, "%1000s", param1);
-   bg = BackgroundFind(param1);
-   Esnprintf(buf, sizeof(buf), "(null)");
-   if ((bg) && (bg->cmclass))
-      Esnprintf(buf, sizeof(buf), "%s", bg->cmclass->name);
-   IpcPrintf(buf);
-}
-#endif
-
 static const IpcItem BackgroundsIpcArray[] = {
    {
     BackgroundsIpc,
@@ -2678,7 +2526,6 @@ static const IpcItem BackgroundsIpcArray[] = {
     "Background commands",
     "  background                       Show current background\n"
     "  background apply <name> <win>    Apply background to window\n"
-    "  background cfg                   Configure backgrounds\n"
     "  background del <name>            Delete background\n"
     "  background list                  Show all background\n"
     "  background load <name> <file>    Load new wallpaper from file\n"
@@ -2691,12 +2538,6 @@ static const IpcItem BackgroundsIpcArray[] = {
    {
     IPC_BackgroundUse, "use_bg", NULL, "Deprecated - do not use", NULL}
    ,
-#if ENABLE_COLOR_MODIFIERS
-   {IPC_BackgroundColormodifierSet, "set_bg_colmod", NULL, "TBD", NULL}
-   ,
-   {IPC_BackgroundColormodifierGet, "get_bg_colmod", NULL, "TBD", NULL}
-   ,
-#endif
 };
 #define N_IPC_FUNCS (sizeof(BackgroundsIpcArray)/sizeof(IpcItem))
 
@@ -2706,6 +2547,7 @@ static const IpcItem BackgroundsIpcArray[] = {
 static const CfgItem BackgroundsCfgItems[] = {
    CFG_ITEM_BOOL(Conf.backgrounds, hiquality, 1),
    CFG_ITEM_BOOL(Conf.backgrounds, user, 1),
+   CFG_ITEM_BOOL(Conf.backgrounds, no_scan, 0),
    CFG_ITEM_INT(Conf.backgrounds, timeout, 240),
 };
 #define N_CFG_ITEMS (sizeof(BackgroundsCfgItems)/sizeof(CfgItem))
