@@ -37,6 +37,8 @@
 #include "user.h"
 #include "windowmatch.h"
 
+#define MAX_E_CFG_VERSION 2	/* Max. supported configuration version */
+
 void
 SkipTillEnd(FILE * fs)
 {
@@ -223,19 +225,24 @@ ConfigAlertLoad(const char *txt)
 }
 
 static int
-ConfigFilePreparse(const char *path, const char *dest)
+ConfigFilePreparse(const char *src, const char *dst, const char *themepath)
 {
    char                execline[FILEPATH_LEN_MAX];
    const char         *epp_path = ENLIGHTENMENT_BIN "/epp";
    char               *def_home, *def_user, *def_shell;
 
    if (EDebug(EDBUG_TYPE_CONFIG))
-      Eprintf("ConfigFilePreparse %s -> %s\n", path, dest);
+      Eprintf("ConfigFilePreparse %s -> %s\n", src, dst);
 
    def_home = homedir(getuid());
    def_user = username(getuid());
    def_shell = usershell(getuid());
 
+   /* When themepath is NULL it shouldn't be used, but this is consistent
+    * with old behavior */
+   if (!themepath)
+      themepath = Mode.theme.path;
+
    Esnprintf(execline, sizeof(execline), "%s " "-P " "-nostdinc " "-undef "
 	     "-include %s/config/definitions " "-I%s " "-I%s/config "
 	     "-D ENLIGHTENMENT_VERSION=%s " "-D ENLIGHTENMENT_ROOT=%s "
@@ -246,18 +253,18 @@ ConfigFilePreparse(const char *path, const char *dest)
 	     "-D SCREEN_DEPTH_%i=1 " "-D USER_NAME=%s " "-D HOME_DIR=%s "
 	     "-D USER_SHELL=%s " "-D ENLIGHTENMENT_VERSION_015=1 "
 	     "%s %s",
-	     epp_path, EDirRoot(), Mode.theme.path, EDirRoot(),
-	     E_PKG_VERSION, EDirRoot(), EDirBin(),
-	     Mode.theme.path, EDirUser(), EDirUserCache(),
+	     epp_path, EDirRoot(), themepath, EDirRoot(),
+	     "0.16.8", EDirRoot(), EDirBin(),
+	     themepath, EDirUser(), EDirUserCache(),
 	     WinGetW(VROOT), WinGetH(VROOT), WinGetW(VROOT), WinGetH(VROOT),
-	     WinGetDepth(VROOT), def_user, def_home, def_shell, path, dest);
+	     WinGetDepth(VROOT), def_user, def_home, def_shell, src, dst);
    system(execline);
 
    Efree(def_user);
    Efree(def_shell);
    Efree(def_home);
 
-   return exists(dest) ? 0 : 1;
+   return exists(dst) ? 0 : 1;
 }
 
 /* Split the process of finding the file from the process of loading it */
@@ -268,7 +275,6 @@ ConfigFileRead(FILE * fs)
    int                 i1, i2, fields;
    char                s[FILEPATH_LEN_MAX];
    int                 e_cfg_ver = 0;
-   int                 max_e_cfg_ver = 1;
 
    while (GetLine(s, sizeof(s), fs))
      {
@@ -302,7 +308,7 @@ ConfigFileRead(FILE * fs)
 
 	if (i2 == CONFIG_OPEN)
 	  {
-	     if (e_cfg_ver > max_e_cfg_ver)
+	     if (e_cfg_ver > MAX_E_CFG_VERSION)
 	       {
 		  AlertX(_("Theme versioning ERROR"),
 			 _("Restart with Defaults"), " ",
@@ -321,7 +327,7 @@ ConfigFileRead(FILE * fs)
 			   "it may be that you haven't upgraded Enlightenment for\n"
 			   "a while and this theme takes advantages of new\n"
 			   "features in Enlightenment in new versions.\n"),
-			 e_cfg_ver, max_e_cfg_ver);
+			 e_cfg_ver, MAX_E_CFG_VERSION);
 		  SessionExit(EEXIT_THEME, "DEFAULT");
 	       }
 	     else
@@ -377,9 +383,6 @@ ConfigFileRead(FILE * fs)
 			  ConfigAlertLoad("Window match");
 		       break;
 		    case CONFIG_COLORMOD:
-#if ENABLE_COLOR_MODIFIERS
-		       Config_ColorModifier(fs);
-#endif
 		       break;
 		    case CONFIG_ACTIONCLASS:
 		       err = AclassConfigLoad(fs);
@@ -403,55 +406,31 @@ ConfigFileRead(FILE * fs)
 }
 
 static char        *
-FindFileLocalized(const char *name, const char *path, int localized)
+FindFilePath(const char *name, const char *path)
 {
    char                s[FILEPATH_LEN_MAX];
-   const char         *lang;
-   char               *p[4];
-   int                 i, len;
+   int                 len;
 
    if (path)
-      len = Esnprintf(s, sizeof(s), "%s/%s", path, name);
+     {
+	len = Esnprintf(s, sizeof(s), "%s/%s", path, name);
+	name = s;
+     }
    else
-      len = Esnprintf(s, sizeof(s), "%s", name);
+     {
+	len = strlen(name);
+     }
    if (len <= 0)
       return NULL;
 
-   lang = Mode.locale.lang;
-   if (!localized || !lang)
-     {
-	if (canread(s))
-	   return Estrdup(s);
-	else
-	   return NULL;
-     }
-
-   if (len + 1 + strlen(lang) >= sizeof(s))
+   if (canread(name))
+      return Estrdup(name);
+   else
       return NULL;
-
-   s[len] = '.';
-   strcpy(s + len + 1, lang);
-
-   p[0] = s + len + 1 + strlen(lang);	/* .da_DK.UTF-8 */
-   p[1] = strchr(s + len + 1, '.');	/* .da_DK       */
-   p[2] = strchr(s + len + 1, '_');	/* .da          */
-   p[3] = s + len;
-
-   for (i = 0; i < 4; i++)
-     {
-	if (p[i] == NULL)
-	   continue;
-
-	*p[i] = '\0';
-	if (canread(s))
-	   return Estrdup(s);
-     }
-
-   return NULL;
 }
 
 char               *
-FindFile(const char *file, const char *themepath, int localized)
+FindFile(const char *file, const char *themepath)
 {
    char                s[FILEPATH_LEN_MAX];
    char               *p;
@@ -459,27 +438,27 @@ FindFile(const char *file, const char *themepath, int localized)
    /* if absolute path - and file exists - return it */
    if (isabspath(file))
      {
-	p = FindFileLocalized(file, NULL, localized);
+	p = FindFilePath(file, NULL);
 	if (p)
 	   return p;
      }
 
    /* look in ~/.e16 first */
-   p = FindFileLocalized(file, EDirUser(), localized);
+   p = FindFilePath(file, EDirUser());
    if (p)
       return p;
 
    if (themepath)
      {
 	/* look in theme dir */
-	p = FindFileLocalized(file, themepath, localized);
+	p = FindFilePath(file, themepath);
 	if (p)
 	   return p;
      }
 
    /* look in system config dir */
    Esnprintf(s, sizeof(s), "%s/config", EDirRoot());
-   p = FindFileLocalized(file, s, localized);
+   p = FindFilePath(file, s);
    if (p)
       return p;
 
@@ -488,9 +467,9 @@ FindFile(const char *file, const char *themepath, int localized)
 }
 
 char               *
-ThemeFileFind(const char *file, int localized)
+ThemeFileFind(const char *file)
 {
-   return FindFile(file, Mode.theme.path, localized);
+   return FindFile(file, Mode.theme.path);
 }
 
 char               *
@@ -500,7 +479,7 @@ ConfigFileFind(const char *name, const char *themepath, int pp)
    char               *fullname, *file, *ppfile;
    int                 i, err;
 
-   fullname = FindFile(name, themepath, Conf.theme.localise);
+   fullname = FindFile(name, themepath);
    if (!fullname)
       return NULL;
 
@@ -520,7 +499,7 @@ ConfigFileFind(const char *name, const char *themepath, int pp)
       goto done;
 
    /* No preparesd file or source is newer. Do preparsing. */
-   err = ConfigFilePreparse(fullname, ppfile);
+   err = ConfigFilePreparse(fullname, ppfile, themepath);
    if (err)
      {
 	Efree(ppfile);
@@ -567,9 +546,6 @@ ThemeConfigLoad(void)
    static const char  *const config_files[] = {
       "init.cfg",
       "textclasses.cfg",
-#if ENABLE_COLOR_MODIFIERS
-      "colormodifiers.cfg",
-#endif
       "imageclasses.cfg",
       "desktops.cfg",
       "actionclasses.cfg",
@@ -592,7 +568,7 @@ ThemeConfigLoad(void)
    for (i = 0; i < (int)(sizeof(config_files) / sizeof(char *)); i++)
 
      {
-	if (!Mode.wm.restart)
+	if (!Mode.wm.restart && Conf.startup.animate)
 	  {
 	     if (i == 2)
 		StartupWindowsCreate();
@@ -619,8 +595,5 @@ ThemeConfigLoad(void)
    /* Font mappings no longer needed */
    FontConfigUnload();
 
-   /* Loose ends... */
-   BordersSetupFallback();
-
    return 0;
 }
