@@ -174,9 +174,6 @@ ContainerDestroy(Container * ct, int exiting)
    ct->ops->Exit(ct, exiting);
 
    Efree(ct->name);
-
-   EDestroyWindow(ct->win);
-
    Efree(ct->objs);
 
    Efree(ct);
@@ -286,7 +283,6 @@ static void
 _ContainerEwinClose(EWin * ewin)
 {
    ContainerDestroy((Container *) ewin->data, 0);
-   ewin->client.win = NULL;
    ewin->data = NULL;
 }
 
@@ -531,7 +527,7 @@ ContainerLayoutImageWin(Container * ct)
 static void
 ContainerDrawScroll(Container * ct)
 {
-   ImageClass         *ic;
+   ImageClass         *ic, *ic_sbb;
    EImageBorder       *pad;
    int                 arrow_mode = ct->arrow_side;
    int                 bs, bw, bx;
@@ -543,13 +539,13 @@ ContainerDrawScroll(Container * ct)
 	if (ct->h < 2 * ct->arrow_thickness + ct->knob_length)
 	   arrow_mode = 3;	/* No arrows */
 
-	ic = ImageclassFind("ICONBOX_SCROLLBAR_BASE_VERTICAL", 0);
-	pad = ImageclassGetPadding(ic);
+	ic_sbb = ImageclassFind("ICONBOX_SCROLLBAR_BASE_VERTICAL", 1);
+	pad = ImageclassGetPadding(ic_sbb);
 	if (arrow_mode < 3)
 	   bs = ct->h - (ct->arrow_thickness * 2);
 	else
 	   bs = ct->h;
-	if (ic)
+	if (pad)
 	   bs -= pad->top + pad->bottom;
 	bw = (ct->h * bs) / ct->max;
 	if (bs < 1)
@@ -559,7 +555,7 @@ ContainerDrawScroll(Container * ct)
 	if (bw < 1)
 	   bw = 1;
 	bx = ((ct->pos * bs) / ct->max);
-	if (ic)
+	if (pad)
 	   bx += pad->top;
 	if ((ct->scrollbar_hide) && (bw == bs))
 	   goto do_hide_sb;
@@ -686,15 +682,13 @@ ContainerDrawScroll(Container * ct)
 	       }
 	  }
 
-	ic = ImageclassFind("ICONBOX_SCROLLBAR_BASE_VERTICAL", 0);
-	if (ic)
-	   ImageclassApply(ic, ct->scroll_win, 0, 0, STATE_NORMAL, ST_ICONBOX);
+	ImageclassApply(ic_sbb, ct->scroll_win, 0, 0, STATE_NORMAL, ST_ICONBOX);
 
 	EMoveResizeWindow(ct->scrollbar_win,
 			  (ct->scroll_thickness - ct->bar_thickness) / 2, bx,
 			  ct->bar_thickness, bw);
 
-	ic = ImageclassFind("ICONBOX_SCROLLBAR_KNOB_VERTICAL", 0);
+	ic = ImageclassFind("ICONBOX_SCROLLBAR_KNOB_VERTICAL", 1);
 	if (ic)
 	  {
 	     state = STATE_NORMAL;
@@ -728,7 +722,7 @@ ContainerDrawScroll(Container * ct)
 
 	if (arrow_mode < 3)
 	  {
-	     ic = ImageclassFind("ICONBOX_ARROW_UP", 0);
+	     ic = ImageclassFind("ICONBOX_ARROW_UP", 1);
 	     if (ic)
 	       {
 		  state = STATE_NORMAL;
@@ -739,7 +733,7 @@ ContainerDrawScroll(Container * ct)
 		  ImageclassApply(ic, ct->arrow1_win, 0, 0, state, ST_ICONBOX);
 	       }
 
-	     ic = ImageclassFind("ICONBOX_ARROW_DOWN", 0);
+	     ic = ImageclassFind("ICONBOX_ARROW_DOWN", 1);
 	     if (ic)
 	       {
 		  state = STATE_NORMAL;
@@ -756,13 +750,13 @@ ContainerDrawScroll(Container * ct)
 	if (ct->w < 2 * ct->arrow_thickness + ct->knob_length)
 	   arrow_mode = 3;	/* No arrows */
 
-	ic = ImageclassFind("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0);
-	pad = ImageclassGetPadding(ic);
+	ic_sbb = ImageclassFind("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 1);
+	pad = ImageclassGetPadding(ic_sbb);
 	if (arrow_mode < 3)
 	   bs = ct->w - (ct->arrow_thickness * 2);
 	else
 	   bs = ct->w;
-	if (ic)
+	if (pad)
 	   bs -= pad->left + pad->right;
 	bw = (ct->w * bs) / ct->max;
 	if (bs < 1)
@@ -772,7 +766,7 @@ ContainerDrawScroll(Container * ct)
 	if (bw < 1)
 	   bw = 1;
 	bx = ((ct->pos * bs) / ct->max);
-	if (ic)
+	if (pad)
 	   bx += pad->left;
 	if ((ct->scrollbar_hide) && (bw == bs))
 	   goto do_hide_sb;
@@ -902,11 +896,9 @@ ContainerDrawScroll(Container * ct)
 			  (ct->scroll_thickness - ct->bar_thickness) / 2, bw,
 			  ct->bar_thickness);
 
-	ic = ImageclassFind("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0);
-	if (ic)
-	   ImageclassApply(ic, ct->scroll_win, 0, 0, STATE_NORMAL, ST_ICONBOX);
+	ImageclassApply(ic_sbb, ct->scroll_win, 0, 0, STATE_NORMAL, ST_ICONBOX);
 
-	ic = ImageclassFind("ICONBOX_SCROLLBAR_KNOB_HORIZONTAL", 0);
+	ic = ImageclassFind("ICONBOX_SCROLLBAR_KNOB_HORIZONTAL", 1);
 	if (ic)
 	  {
 	     state = STATE_NORMAL;
@@ -940,7 +932,7 @@ ContainerDrawScroll(Container * ct)
 
 	if (arrow_mode < 3)
 	  {
-	     ic = ImageclassFind("ICONBOX_ARROW_LEFT", 0);
+	     ic = ImageclassFind("ICONBOX_ARROW_LEFT", 1);
 	     if (ic)
 	       {
 		  state = STATE_NORMAL;
@@ -951,7 +943,7 @@ ContainerDrawScroll(Container * ct)
 		  ImageclassApply(ic, ct->arrow1_win, 0, 0, state, ST_ICONBOX);
 	       }
 
-	     ic = ImageclassFind("ICONBOX_ARROW_RIGHT", 0);
+	     ic = ImageclassFind("ICONBOX_ARROW_RIGHT", 1);
 	     if (ic)
 	       {
 		  state = STATE_NORMAL;
@@ -1297,7 +1289,7 @@ ContainerEventScrollbarWin(Win win __UNUSED__, XEvent * ev, void *prm)
    Container          *ct = (Container *) prm;
    static int          px, py, pos0;
    int                 bs, dp;
-   ImageClass         *ic;
+   ImageClass         *ic_sbb;
    EImageBorder       *pad;
 
    switch (ev->type)
@@ -1333,10 +1325,10 @@ ContainerEventScrollbarWin(Win win __UNUSED__, XEvent * ev, void *prm)
 
 	if (ct->orientation)
 	  {
-	     ic = ImageclassFind("ICONBOX_SCROLLBAR_BASE_VERTICAL", 0);
-	     pad = ImageclassGetPadding(ic);
+	     ic_sbb = ImageclassFind("ICONBOX_SCROLLBAR_BASE_VERTICAL", 1);
+	     pad = ImageclassGetPadding(ic_sbb);
 	     bs = ct->h - (ct->arrow_thickness * 2);
-	     if (ic)
+	     if (pad)
 		bs -= pad->top + pad->bottom;
 	     if (bs < 1)
 		bs = 1;
@@ -1344,10 +1336,10 @@ ContainerEventScrollbarWin(Win win __UNUSED__, XEvent * ev, void *prm)
 	  }
 	else
 	  {
-	     ic = ImageclassFind("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 0);
-	     pad = ImageclassGetPadding(ic);
+	     ic_sbb = ImageclassFind("ICONBOX_SCROLLBAR_BASE_HORIZONTAL", 1);
+	     pad = ImageclassGetPadding(ic_sbb);
 	     bs = ct->w - (ct->arrow_thickness * 2);
-	     if (ic)
+	     if (pad)
 		bs -= pad->left + pad->right;
 	     if (bs < 1)
 		bs = 1;
@@ -1716,7 +1708,7 @@ static const DialogDef DlgContainer = {
    "CONFIGURE_ICONBOX",
    NULL,
    NULL,
-   "SOUND_SETTINGS_ICONBOX",
+   SOUND_SETTINGS_ICONBOX,
    "pix/iconbox.png",
    N_("Enlightenment Iconbox\n" "Settings Dialog\n"),
    _DlgFillContainer,
@@ -1763,7 +1755,7 @@ ContainersConfigLoad(void)
 	  case CONFIG_CLASSNAME:	/* __NAME %s */
 	     ct = ContainerFind(s2);
 	     if (ct)
-		ContainerDestroy(ct, 0);
+		EwinHide(ct->ewin);
 	     ct = ContainerCreate(s2);
 	     break;
 	  case TEXT_ORIENTATION:	/* __ORIENTATION [ __HORIZONTAL | __VERTICAL ] */
