@@ -149,8 +149,7 @@ DeskControlsCreate(Desk * dsk)
 	a = ActionCreate(EVENT_MOUSE_UP, 1, 0, 1, 0, 0, NULL, NULL);
 	ActionclassAddAction(ac, a);
 
-	Esnprintf(s, sizeof(s), "desk raise %i", dsk->num);
-	ActionAddTo(a, s);
+	ActionAddTo(a, "desk next");
 	t = _("Click here to raise this desktop\nto the top.\n");
 	ActionclassSetTooltipString(ac, t);
      }
@@ -162,8 +161,7 @@ DeskControlsCreate(Desk * dsk)
 	a = ActionCreate(EVENT_MOUSE_UP, 1, 0, 1, 0, 0, NULL, NULL);
 	ActionclassAddAction(ac, a);
 
-	Esnprintf(s, sizeof(s), "desk lower %i", dsk->num);
-	ActionAddTo(a, s);
+	ActionAddTo(a, "desk prev");
 	t = _("Click here to lower this desktop\nto the bottom.\n");
 	ActionclassSetTooltipString(ac, t);
      }
@@ -389,8 +387,6 @@ DeskCreate(int desk, int configure)
    EoInit(dsk, EOBJ_TYPE_DESK, win,
 	  0, 0, WinGetW(VROOT), WinGetH(VROOT), 0, buf);
    EventCallbackRegister(EoGetWin(dsk), 0, DeskHandleEvents, dsk);
-   EoSetFade(dsk, 0);
-   EoSetShadow(dsk, 0);
    dsk->bg.o = EoObj(dsk);
    if (desk == 0)
      {
@@ -402,7 +398,6 @@ DeskCreate(int desk, int configure)
 			      0, 0, WinGetW(VROOT), WinGetH(VROOT),
 			      0, "Root-bg");
 	eo->floating = 0;
-	eo->fade = eo->shadow = 0;
 	EobjSetLayer(eo, 0);
 	EventCallbackRegister(EobjGetWin(eo), 0, DeskHandleEvents, dsk);
 	dsk->bg.o_bg = eo;
@@ -425,7 +420,6 @@ DeskCreate(int desk, int configure)
    eo = EobjWindowCreate(EOBJ_TYPE_MISC,
 			 0, 0, WinGetW(VROOT), WinGetH(VROOT), 0, buf);
    eo->floating = 0;
-   eo->fade = eo->shadow = 0;
    EobjReparent(eo, EoObj(dsk), 0, 0);
    EobjSetLayer(eo, 0);
    dsk->bg.o_bg = eo;
@@ -473,12 +467,10 @@ DeskDestroy(Desk * dsk)
    Efree(dsk);
 }
 
-Win
-DeskGetBackgroundWin(const Desk * dsk)
+EObj               *
+DeskGetBackgroundObj(const Desk * dsk)
 {
-   if (!dsk)
-      return VROOT;
-   return EobjGetWin(dsk->bg.o);
+   return (dsk) ? dsk->bg.o : NULL;
 }
 
 Pixmap
@@ -809,22 +801,6 @@ DesksSetCurrent(Desk * dsk)
    desks.current = dsk;
 }
 
-#if 0				/* Unused */
-void
-DesksClear(void)
-{
-   Desk               *dsk;
-   unsigned int        i;
-
-   for (i = 0; i < Conf.desks.num; i++)
-     {
-	dsk = _DeskGet(i);
-	if (dsk->viewable)
-	   EClearWindow(EoGetWin(dsk));
-     }
-}
-#endif
-
 static void
 DesksResize(int w, int h)
 {
@@ -1633,13 +1609,13 @@ DeskCurrentGotoArea(int ax, int ay)
    dy = WinGetH(VROOT) * (ay - pay);
 
    if (dx < 0)
-      SoundPlay("SOUND_MOVE_AREA_LEFT");
+      SoundPlay(SOUND_MOVE_AREA_LEFT);
    else if (dx > 0)
-      SoundPlay("SOUND_MOVE_AREA_RIGHT");
+      SoundPlay(SOUND_MOVE_AREA_RIGHT);
    else if (dy < 0)
-      SoundPlay("SOUND_MOVE_AREA_UP");
+      SoundPlay(SOUND_MOVE_AREA_UP);
    else if (dy > 0)
-      SoundPlay("SOUND_MOVE_AREA_DOWN");
+      SoundPlay(SOUND_MOVE_AREA_DOWN);
 
    ActionsSuspend();
 
@@ -1867,12 +1843,13 @@ DeskRootResize(int root, int w, int h)
    if (EDebug(EDBUG_TYPE_DESKS))
       Eprintf("DeskRootResize %d %dx%d\n", root, w, h);
 
-   if (root)
+   if (root && (VROOT != RROOT))
      {
 	WinGetW(RROOT) = w;
 	WinGetH(RROOT) = h;
      }
 
+   /* Quit if no change */
    if (w == WinGetW(VROOT) && h == WinGetH(VROOT))
       return;
 
@@ -1882,11 +1859,11 @@ DeskRootResize(int root, int w, int h)
    if (w != WinGetW(VROOT) || h != WinGetH(VROOT))
       return;
 
-   Mode.screen.w_old = WinGetW(VROOT);
-   Mode.screen.h_old = WinGetH(VROOT);
-
    ScreenInit();
    DesksResize(w, h);
+
+   Mode.screen.w_old = WinGetW(VROOT);
+   Mode.screen.h_old = WinGetH(VROOT);
 }
 
 static ActionClass *
@@ -2107,6 +2084,9 @@ DesksInit(void)
 
    memset(&desks, 0, sizeof(desks));
 
+   Mode.screen.w_old = WinGetW(VROOT);
+   Mode.screen.h_old = WinGetH(VROOT);
+
    /* Backward compatibility hack */
    if (Conf.desks.edge_flip_resistance <= 0)
       Conf.desks.edge_flip_mode = EDGE_FLIP_OFF;
@@ -2155,7 +2135,7 @@ DesksSighan(int sig, void *prm __UNUSED__)
      case ESIGNAL_START:
 	/* Draw all the buttons that belong on the desktop */
 	DeskShowButtons();
-	IdlerAdd(50, _DesksIdler, NULL);
+	IdlerAdd(_DesksIdler, NULL);
 	break;
      }
 }
@@ -2222,9 +2202,8 @@ CB_DesktopDisplayRedraw(Dialog * d, int val, void *data)
 
    if (!called)
      {
-	ic = ImageclassFind("SETTINGS_DESKTOP_AREA", 0);
-	if (ic)
-	   ImageclassApply(ic, win, 0, 0, STATE_NORMAL, ST_SOLID);
+	ic = ImageclassFind("SETTINGS_DESKTOP_AREA", 1);
+	ImageclassApply(ic, win, 0, 0, STATE_NORMAL, ST_SOLID);
 	for (i = 0; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; i++)
 	   wins[i] = 0;
 	called = 1;
@@ -2249,9 +2228,8 @@ CB_DesktopDisplayRedraw(Dialog * d, int val, void *data)
 	       }
 	     else
 	       {
-		  ic = ImageclassFind("SETTINGS_DESKTOP_AREA", 0);
-		  if (ic)
-		     ImageclassApply(ic, wins[i], 0, 0, STATE_NORMAL, ST_SOLID);
+		  ic = ImageclassFind("SETTINGS_DESKTOP_AREA", 1);
+		  ImageclassApply(ic, wins[i], 0, 0, STATE_NORMAL, ST_SOLID);
 	       }
 	  }
      }
@@ -2269,17 +2247,14 @@ CB_DesktopDisplayRedraw(Dialog * d, int val, void *data)
 	EMapWindow(wins[i]);
      }
 
-   for (i = tmp_desktops; i < (int)Conf.desks.num; i++)
+   for (i = tmp_desktops; i < ENLIGHTENMENT_CONF_NUM_DESKTOPS; i++)
      {
 	if (!wins[i])
 	   continue;
 	EUnmapWindow(wins[i]);
      }
 
-   if (tmp_desktops > 1)
-      Esnprintf(s, sizeof(s), _("%i Desktops"), tmp_desktops);
-   else
-      Esnprintf(s, sizeof(s), _("%i Desktop"), tmp_desktops);
+   Esnprintf(s, sizeof(s), "%i", tmp_desktops);
    DialogItemSetText(tmp_desk_text, s);
    DialogDrawItems(d, tmp_desk_text, 0, 0, 99999, 99999);
 }
@@ -2295,7 +2270,6 @@ static void
 _DlgFillDesks(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
 {
    DItem              *di, *slider, *radio;
-   char                s[64];
 
    tmp_desktops = Conf.desks.num;
    tmp_desktop_slide = Conf.desks.slidein;
@@ -2315,11 +2289,7 @@ _DlgFillDesks(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
 
    di = tmp_desk_text = DialogAddItem(table, DITEM_TEXT);
    DialogItemSetColSpan(di, 2);
-   if (tmp_desktops > 1)
-      Esnprintf(s, sizeof(s), _("%i Desktops"), tmp_desktops);
-   else
-      Esnprintf(s, sizeof(s), _("%i Desktop"), tmp_desktops);
-   DialogItemSetText(di, s);
+   DialogItemSetText(di, "X");
 
    di = slider = DialogAddItem(table, DITEM_SLIDER);
    DialogItemSliderSetBounds(di, 1, 32);
@@ -2406,7 +2376,7 @@ const DialogDef     DlgDesks = {
    "CONFIGURE_DESKTOPS",
    N_("Desks"),
    N_("Multiple Desktop Settings"),
-   "SOUND_SETTINGS_DESKTOPS",
+   SOUND_SETTINGS_DESKTOPS,
    "pix/desktops.png",
    N_("Enlightenment Multiple Desktop\n" "Settings Dialog\n"),
    _DlgFillDesks,
@@ -2425,7 +2395,7 @@ CB_ConfigureAreas(Dialog * d __UNUSED__, int val, void *data __UNUSED__)
 {
    if (val < 2)
      {
-	SetNewAreaSize(tmp_area_x, 9 - tmp_area_y);
+	SetNewAreaSize(tmp_area_x, tmp_area_y);
 	Conf.desks.areas_wraparound = tmp_area_wraparound;
 	Conf.desks.edge_flip_mode = tmp_edge_flip;
 	if (tmp_edge_resist < 1)
@@ -2439,17 +2409,13 @@ static void
 CB_AreaDisplayRedraw(Dialog * d __UNUSED__, int val, void *data)
 {
    static int          prev_ax = 0, prev_ay = 0;
-   static char         called = 0;
    static Win          awin;
    char                s[64];
    DItem              *di;
    Win                 win;
-   int                 w, h;
+   int                 w, h, ww, hh;
 
-   if (val == 1)
-      called = 0;
-
-   if ((val != 1) && ((prev_ax == tmp_area_x) && (prev_ay == tmp_area_y)))
+   if ((val != 1) && (prev_ax == tmp_area_x) && (prev_ay == tmp_area_y))
       return;
 
    prev_ax = tmp_area_x;
@@ -2459,29 +2425,26 @@ CB_AreaDisplayRedraw(Dialog * d __UNUSED__, int val, void *data)
    win = DialogItemAreaGetWindow(di);
    DialogItemAreaGetSize(di, &w, &h);
 
-   if (!called)
+   if (val == 1)
      {
 	ImageClass         *ic;
+	Pixmap              pmap;
 
-	ic = ImageclassFind("SETTINGS_AREA_AREA", 0);
+	ic = ImageclassFind("SETTINGS_AREA_AREA", 1);
 	ImageclassApply(ic, win, 0, 0, STATE_NORMAL, ST_SOLID);
 
+	/* Note: awin is destroyed when the dialog is destroyed */
 	awin = ECreateWindow(win, 0, 0, 18, 14, 0);
-	ic = ImageclassFind("SETTINGS_AREADESK_AREA", 0);
-	ImageclassApply(ic, awin, 0, 0, STATE_NORMAL, ST_SOLID);
-
-	called = 1;
+	ic = ImageclassFind("SETTINGS_AREADESK_AREA", 1);
+	pmap = EGetWindowBackgroundPixmap(awin);
+	ImageclassApplySimple(ic, awin, pmap, STATE_NORMAL, 0, 0, 18, 14);
      }
-   EMoveResizeWindow(awin, ((w / 2) - (9 * tmp_area_x)),
-		     ((h / 2) - (7 * (9 - tmp_area_y))), 18 * tmp_area_x,
-		     14 * (9 - tmp_area_y));
+   ww = 18 * prev_ax;
+   hh = 14 * prev_ay;
+   EMoveResizeWindow(awin, (w - ww) / 2, (h - hh) / 2, ww, hh);
    EMapWindow(awin);
 
-   if ((tmp_area_x > 1) || ((9 - tmp_area_y) > 1))
-      Esnprintf(s, sizeof(s), _("%i x %i\nScreens in size"), tmp_area_x,
-		9 - tmp_area_y);
-   else
-      Esnprintf(s, sizeof(s), _("1\nScreen in size"));
+   Esnprintf(s, sizeof(s), "%i x %i", prev_ax, prev_ay);
    DialogItemSetText(tmp_area_text, s);
    DialogDrawItems(d, tmp_area_text, 0, 0, 99999, 99999);
 }
@@ -2496,7 +2459,6 @@ static void
 _DlgFillAreas(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
 {
    DItem              *di, *slider, *slider2, *table2, *radio;
-   char                s[64];
 
    tmp_area_wraparound = Conf.desks.areas_wraparound;
 
@@ -2504,7 +2466,6 @@ _DlgFillAreas(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
    tmp_edge_resist = Conf.desks.edge_flip_resistance;
 
    DesksGetAreaSize(&tmp_area_x, &tmp_area_y);
-   tmp_area_y = 9 - tmp_area_y;
 
    DialogItemTableSetOptions(table, 1, 0, 0, 0);
 
@@ -2512,12 +2473,7 @@ _DlgFillAreas(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
    DialogItemSetText(di, _("Virtual Desktop size:\n"));
 
    di = tmp_area_text = DialogAddItem(table, DITEM_TEXT);
-   if ((tmp_area_x > 1) || (tmp_area_y > 1))
-      Esnprintf(s, sizeof(s), _("%i x %i\nScreens in size"), tmp_area_x,
-		9 - tmp_area_y);
-   else
-      Esnprintf(s, sizeof(s), _("1\nScreen in size"));
-   DialogItemSetText(di, s);
+   DialogItemSetText(di, "X");
 
    table2 = DialogAddItem(table, DITEM_TABLE);
    DialogItemTableSetOptions(table2, 2, 0, 0, 0);
@@ -2590,7 +2546,7 @@ const DialogDef     DlgAreas = {
    "CONFIGURE_AREA",
    N_("Areas"),
    N_("Virtual Desktop Settings"),
-   "SOUND_SETTINGS_AREA",
+   SOUND_SETTINGS_AREA,
    "pix/areas.png",
    N_("Enlightenment Virtual Desktop\n" "Settings Dialog\n"),
    _DlgFillAreas,
@@ -2615,7 +2571,7 @@ DeskOpGoto(unsigned int desk)
    DeskGoto(dsk);
 
    if (DesksGetCurrent() != pd)
-      SoundPlay("SOUND_DESKTOP_SHUT");
+      SoundPlay(SOUND_DESKTOP_SHUT);
 }
 
 static void
@@ -2659,10 +2615,6 @@ DesksIpcDesk(const char *params)
      {
 	IpcPrintf("Current Desktop: %d/%d\n", desk, Conf.desks.num);
      }
-   else if (!strncmp(cmd, "cfg", 3))
-     {
-	DialogShowSimple(&DlgDesks, NULL);
-     }
    else if (!strncmp(cmd, "set", 3))
      {
 	sscanf(prm, "%i", &desk);
@@ -2702,13 +2654,13 @@ DesksIpcDesk(const char *params)
    else if (!strncmp(cmd, "raise", 2))
      {
 	sscanf(prm, "%i", &desk);
-	SoundPlay("SOUND_DESKTOP_RAISE");
+	SoundPlay(SOUND_DESKTOP_RAISE);
 	DeskRaise(desk);
      }
    else if (!strncmp(cmd, "lower", 2))
      {
 	sscanf(prm, "%i", &desk);
-	SoundPlay("SOUND_DESKTOP_LOWER");
+	SoundPlay(SOUND_DESKTOP_LOWER);
 	DeskLower(desk);
      }
    else if (!strcmp(cmd, "drag"))
@@ -2757,10 +2709,6 @@ DesksIpcArea(const char *params)
      {
 	IpcPrintf("Current Area: %d %d\n", ax, ay);
      }
-   else if (!strncmp(cmd, "cfg", 3))
-     {
-	DialogShowSimple(&DlgAreas, NULL);
-     }
    else if (!strncmp(cmd, "set", 3))
      {
 	sscanf(params, "%*s %i %i", &ax, &ay);
@@ -2796,7 +2744,6 @@ static const IpcItem DesksIpcArray[] = {
     "desk", NULL,
     "Desktop functions",
     "  desk ?               Desktop info\n"
-    "  desk cfg             Configure desktops\n"
     "  desk drag            Start deskdrag\n"
     "  desk set <nd>        Set number of desktops\n"
     "  desk goto <d>        Goto specified desktop\n"
@@ -2816,7 +2763,6 @@ static const IpcItem DesksIpcArray[] = {
     "area", NULL,
     "Area functions",
     "  area ?               Area info\n"
-    "  area cfg             Configure areas\n"
     "  area set <nx> <ny>   Set area size\n"
     "  area goto <ax> <ay>  Goto specified area\n"
     "  area move <dx> <dy>  Move relative to current area\n"
