@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
- * Copyright (C) 2004-2007 Kim Woelders
+ * Copyright (C) 2004-2008 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -69,7 +69,7 @@ void                DeskSetDirtyStack(Desk * dsk, EObj * eo);
 void                DeskGoto(Desk * dsk);
 void                DeskGotoNum(unsigned int desk);
 void                DeskRestack(Desk * dsk);
-Win                 DeskGetBackgroundWin(const Desk * dsk);
+EObj               *DeskGetBackgroundObj(const Desk * dsk);
 Pixmap              DeskGetBackgroundPixmap(const Desk * dsk);
 
 Background         *DeskBackgroundGet(const Desk * dsk);
@@ -89,7 +89,6 @@ Desk               *DesktopAt(int x, int y);
 unsigned int        DesksGetCurrentNum(void);
 void                DesksSetCurrent(Desk * dsk);
 void                DesksGetAreaSize(int *aw, int *ah);
-void                DesksClear(void);
 
 void                DesksFixArea(int *ax, int *ay);
 
