@@ -51,23 +51,18 @@ typedef struct {
 
    int                 base_orig_w, base_orig_h;
    int                 knob_orig_w, knob_orig_h;
-   int                 border_orig_w, border_orig_h;
 
    int                 base_x, base_y, base_w, base_h;
    int                 knob_x, knob_y, knob_w, knob_h;
-   int                 border_x, border_y, border_w, border_h;
    int                 numeric_x, numeric_y, numeric_w, numeric_h;
 
    ImageClass         *ic_base;
    ImageClass         *ic_knob;
-   ImageClass         *ic_border;
 
    char                in_drag;
-   int                 wanted_val;
 
    Win                 base_win;
    Win                 knob_win;
-   Win                 border_win;
 } DItemSlider;
 
 typedef struct {
@@ -264,7 +259,6 @@ DialogDestroy(Dialog * d)
    TextclassFree(d->tclass);
 
    FreePmapMask(&(d->pmm_bg));
-   EDestroyWindow(d->win);
 
    Efree(d);
 }
@@ -458,13 +452,12 @@ DialogRedraw(Dialog * d)
 
    FreePmapMask(&(d->pmm_bg));
    ImageclassApplyCopy(d->iclass, d->win, d->w, d->h, 0, 0, STATE_NORMAL,
-		       &(d->pmm_bg), IC_FLAG_NONE, ST_DIALOG);
+		       &(d->pmm_bg), IC_FLAG_FULL_SIZE, ST_DIALOG);
    if (d->pmm_bg.pmap == None)
       return;
 
    EGetWindowBackgroundPixmap(d->win);
-   EXCopyAreaTiled(d->pmm_bg.pmap, None, WinGetPmap(d->win), 0, 0, d->w, d->h,
-		   0, 0);
+   EXCopyArea(d->pmm_bg.pmap, WinGetPmap(d->win), 0, 0, d->w, d->h, 0, 0);
 
    d->redraw = 1;
 
@@ -501,7 +494,6 @@ static void
 _DialogEwinClose(EWin * ewin)
 {
    DialogDestroy((Dialog *) ewin->data);
-   ewin->client.win = NULL;
    ewin->data = NULL;
 }
 
@@ -650,7 +642,7 @@ DialogShowSimpleWithName(const DialogDef * dd, const char *name, void *data)
    d = DialogFind(name);
    if (d)
      {
-	SoundPlay("SOUND_SETTINGS_ACTIVE");
+	SoundPlay(SOUND_SETTINGS_ACTIVE);
 	DialogShow(d);
 	return;
      }
@@ -777,16 +769,12 @@ DialogAddItem(DItem * dii, int type)
 	di->item.slider.min_length = 64;
 	di->item.slider.ic_base = NULL;
 	di->item.slider.ic_knob = NULL;
-	di->item.slider.ic_border = NULL;
 	di->item.slider.base_win = 0;
 	di->item.slider.knob_win = 0;
-	di->item.slider.border_win = 0;
 	di->item.slider.base_orig_w = 10;
 	di->item.slider.base_orig_h = 10;
 	di->item.slider.knob_orig_w = 6;
 	di->item.slider.knob_orig_h = 6;
-	di->item.slider.border_orig_w = 14;
-	di->item.slider.border_orig_h = 14;
 	di->item.slider.base_x = 0;
 	di->item.slider.base_y = 0;
 	di->item.slider.base_w = 0;
@@ -795,16 +783,11 @@ DialogAddItem(DItem * dii, int type)
 	di->item.slider.knob_y = 0;
 	di->item.slider.knob_w = 0;
 	di->item.slider.knob_h = 0;
-	di->item.slider.border_x = 0;
-	di->item.slider.border_y = 0;
-	di->item.slider.border_w = 0;
-	di->item.slider.border_h = 0;
 	di->item.slider.numeric_x = 0;
 	di->item.slider.numeric_y = 0;
 	di->item.slider.numeric_w = 0;
 	di->item.slider.numeric_h = 0;
 	di->item.slider.in_drag = 0;
-	di->item.slider.wanted_val = 0;
 	break;
      }
 
@@ -939,7 +922,7 @@ DialogItemCallCallback(Dialog * d, DItem * di)
 static void
 DialogRealizeItem(Dialog * d, DItem * di)
 {
-   const char         *def = NULL;
+   const char         *iclass, *tclass;
    int                 iw = 0, ih = 0;
    int                 register_win_callback;
    EImage             *im;
@@ -949,43 +932,60 @@ DialogRealizeItem(Dialog * d, DItem * di)
       return;
    di->realized = 1;
 
+   iclass = tclass = NULL;
    if (di->type == DITEM_BUTTON)
      {
-	def = "DIALOG_WIDGET_BUTTON";
+	iclass = "DIALOG_WIDGET_BUTTON";
+	tclass = iclass;
      }
    else if (di->type == DITEM_CHECKBUTTON)
      {
-	def = "DIALOG_WIDGET_CHECK_BUTTON";
+	iclass = "DIALOG_WIDGET_CHECK_BUTTON";
+	tclass = iclass;
      }
    else if (di->type == DITEM_TEXT)
      {
-	def = "DIALOG_WIDGET_TEXT";
+	tclass = "DIALOG_WIDGET_TEXT";
      }
    else if (di->type == DITEM_SEPARATOR)
      {
-	def = "DIALOG_WIDGET_SEPARATOR";
-     }
-   else if (di->type == DITEM_TABLE)
-     {
-	def = "DIALOG_WIDGET_TABLE";
+	iclass = "DIALOG_WIDGET_SEPARATOR";
      }
    else if (di->type == DITEM_RADIOBUTTON)
      {
-	def = "DIALOG_WIDGET_RADIO_BUTTON";
+	iclass = "DIALOG_WIDGET_RADIO_BUTTON";
+	tclass = iclass;
      }
+#if 0
+   else if (di->type == DITEM_SLIDER)
+     {
+	iclass = NULL;
+     }
+#endif
    else if (di->type == DITEM_AREA)
      {
-	def = "DIALOG_WIDGET_AREA";
-     }
-   else
-     {
-	def = "DIALOG_WIDGET_BUTTON";
+	iclass = "DIALOG_WIDGET_AREA";
      }
 
-   if (!di->iclass)
-      di->iclass = ImageclassAlloc(def, 1);
-   if (!di->tclass)
-      di->tclass = TextclassAlloc(def, 1);
+   if (!di->iclass && iclass)
+     {
+	di->iclass = ImageclassAlloc(iclass, 1);
+	if (!di->iclass)
+	  {
+	     di->type = DITEM_NONE;
+	     return;
+	  }
+     }
+
+   if (!di->tclass && tclass)
+     {
+	di->tclass = TextclassAlloc(tclass, 1);
+	if (!di->tclass)
+	  {
+	     di->type = DITEM_NONE;
+	     return;
+	  }
+     }
 
    if (di->type == DITEM_TABLE)
      {
@@ -1005,19 +1005,20 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	     di->win = ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	     EMapWindow(di->win);
 	     ESelectInput(di->win,
-			  EnterWindowMask | LeaveWindowMask | ButtonPressMask
-			  | ButtonReleaseMask);
+			  EnterWindowMask | LeaveWindowMask |
+			  ButtonPressMask | ButtonReleaseMask);
 	  }
 	di->item.slider.base_win = ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	EMapWindow(di->item.slider.base_win);
 	di->item.slider.knob_win = ECreateWindow(d->win, -20, -20, 2, 2, 0);
 	EMapWindow(di->item.slider.knob_win);
 	ESelectInput(di->item.slider.base_win,
-		     EnterWindowMask | LeaveWindowMask | ButtonPressMask |
-		     ButtonReleaseMask);
+		     EnterWindowMask | LeaveWindowMask |
+		     ButtonPressMask | ButtonReleaseMask);
 	EventCallbackRegister(di->item.slider.base_win, 0, DItemHandleEvents,
 			      di);
 	ESelectInput(di->item.slider.knob_win,
+		     EnterWindowMask | LeaveWindowMask |
 		     ButtonPressMask | ButtonReleaseMask | PointerMotionMask);
 	EventCallbackRegister(di->item.slider.knob_win, 0, DItemHandleEvents,
 			      di);
@@ -1056,26 +1057,6 @@ DialogRealizeItem(Dialog * d, DItem * di)
 	     EImageFree(im);
 	  }
 
-	if (!di->item.slider.ic_border)
-	  {
-	     if (di->item.slider.horizontal)
-		di->item.slider.ic_border =
-		   ImageclassAlloc("DIALOG_WIDGET_SLIDER_BORDER_HORIZONTAL", 1);
-	     else
-		di->item.slider.ic_border =
-		   ImageclassAlloc("DIALOG_WIDGET_SLIDER_BORDER_VERTICAL", 1);
-	  }
-	im = ImageclassGetImage(di->item.slider.ic_border, 0, 0, 0);
-	if (im)
-	  {
-	     EImageGetSize(im, &di->item.slider.border_orig_w,
-			   &di->item.slider.border_orig_h);
-	     EImageFree(im);
-	     di->item.slider.border_win =
-		ECreateWindow(d->win, -20, -20, 2, 2, 0);
-	     EMapWindow(di->item.slider.border_win);
-	  }
-
 	pad = ImageclassGetPadding(di->item.slider.ic_base);
 	if (di->item.slider.horizontal)
 	  {
@@ -1299,6 +1280,8 @@ DialogRealizeItem(Dialog * d, DItem * di)
 			dii->w = sw - (dii->padding.left + dii->padding.right);
 		     if (dii->fill_v)
 			dii->h = sh - (dii->padding.top + dii->padding.bottom);
+		     if (dii->w <= 0 || dii->h <= 0)
+			goto skip;
 		     if (dii->type == DITEM_TABLE)
 		       {
 			  int                 dx, dy, newx, newy;
@@ -1376,10 +1359,6 @@ DialogRealizeItem(Dialog * d, DItem * di)
 			       dii->item.slider.base_y = 0;
 			       dii->item.slider.base_w = dii->w;
 			       dii->item.slider.base_h = dii->h;
-			       dii->item.slider.border_x = 0;
-			       dii->item.slider.border_y = 0;
-			       dii->item.slider.border_w = dii->w;
-			       dii->item.slider.border_h = dii->h;
 			       dii->item.slider.knob_w =
 				  dii->item.slider.knob_orig_w;
 			       dii->item.slider.knob_h =
@@ -1392,15 +1371,6 @@ DialogRealizeItem(Dialog * d, DItem * di)
 						    dii->item.slider.base_y,
 						    dii->item.slider.base_w,
 						    dii->item.slider.base_h);
-			       if (dii->item.slider.border_win)
-				  EMoveResizeWindow(dii->item.slider.
-						    border_win,
-						    dii->x +
-						    dii->item.slider.border_x,
-						    dii->y +
-						    dii->item.slider.border_y,
-						    dii->item.slider.border_w,
-						    dii->item.slider.border_h);
 			       if (dii->win)
 				  EMoveResizeWindow(dii->win,
 						    dii->x +
@@ -1414,6 +1384,7 @@ DialogRealizeItem(Dialog * d, DItem * di)
 						    dii->item.slider.numeric_h);
 			    }
 		       }
+		   skip:
 		     x += sw;
 		     c += dii->col_span;
 		     if (c >= cols)
@@ -1491,12 +1462,6 @@ MoveTableBy(Dialog * d, DItem * di, int dx, int dy)
 				     dii->y + dii->item.slider.knob_y,
 				     dii->item.slider.knob_w,
 				     dii->item.slider.knob_h);
-		if (dii->item.slider.border_win)
-		   EMoveResizeWindow(dii->item.slider.border_win,
-				     dii->x + dii->item.slider.border_x,
-				     dii->y + dii->item.slider.border_y,
-				     dii->item.slider.border_w,
-				     dii->item.slider.border_h);
 		if (dii->win)
 		   EMoveResizeWindow(dii->win,
 				     dii->x + dii->item.slider.numeric_x,
@@ -1587,27 +1552,20 @@ DialogDrawItem(Dialog * d, DItem * di)
      case DITEM_SLIDER:
 	if (di->item.slider.horizontal)
 	  {
-	     di->item.slider.knob_x =
-		di->item.slider.base_x +
-		(((di->item.slider.base_w -
-		   di->item.slider.knob_w) * (di->item.slider.val -
-					      di->item.slider.lower)) /
+	     di->item.slider.knob_x = di->item.slider.base_x +
+		(((di->item.slider.base_w - di->item.slider.knob_w) *
+		  (di->item.slider.val - di->item.slider.lower)) /
 		 (di->item.slider.upper - di->item.slider.lower));
-	     di->item.slider.knob_y =
-		di->item.slider.base_y +
+	     di->item.slider.knob_y = di->item.slider.base_y +
 		((di->item.slider.base_h - di->item.slider.knob_h) / 2);
 	  }
 	else
 	  {
-	     di->item.slider.knob_y =
-		(di->item.slider.base_y + di->item.slider.base_h -
-		 di->item.slider.knob_h) -
-		(((di->item.slider.base_h -
-		   di->item.slider.knob_h) * (di->item.slider.val -
-					      di->item.slider.lower)) /
+	     di->item.slider.knob_y = di->item.slider.base_y +
+		(((di->item.slider.base_h - di->item.slider.knob_h) *
+		  (di->item.slider.val - di->item.slider.lower)) /
 		 (di->item.slider.upper - di->item.slider.lower));
-	     di->item.slider.knob_x =
-		di->item.slider.base_x +
+	     di->item.slider.knob_x = di->item.slider.base_x +
 		((di->item.slider.base_w - di->item.slider.knob_w) / 2);
 	  }
 	if (di->item.slider.knob_win)
@@ -1619,10 +1577,6 @@ DialogDrawItem(Dialog * d, DItem * di)
 	   ImageclassApply(di->item.slider.ic_base,
 			   di->item.slider.base_win,
 			   0, 0, STATE_NORMAL, ST_WIDGET);
-	if (di->item.slider.border_win)
-	   ImageclassApply(di->item.slider.ic_border,
-			   di->item.slider.border_win,
-			   0, 0, STATE_NORMAL, ST_WIDGET);
 	state = STATE_NORMAL;
 	if ((di->hilited) && (di->clicked))
 	   state = STATE_CLICKED;
@@ -1713,11 +1667,11 @@ DialogDrawItem(Dialog * d, DItem * di)
 
       draw_text:
 	di->state = state;
-	if (!di->text)
+	if (!di->text || !di->tclass)
 	   break;
-	if (!d->redraw)
-	   EXCopyAreaTiled(d->pmm_bg.pmap, None, WinGetPmap(d->win),
-			   di->x, di->y, di->w, di->h, di->x, di->y);
+	if (!d->redraw || di->update)
+	   EXCopyArea(d->pmm_bg.pmap, WinGetPmap(d->win),
+		      di->x, di->y, di->w, di->h, di->x, di->y);
 	TextDraw(di->tclass, d->win, WinGetPmap(d->win), 0, 0, state, di->text,
 		 x, di->y, w, 99999, 17, TextclassGetJustification(di->tclass));
 	break;
@@ -1730,11 +1684,15 @@ DialogDrawItem(Dialog * d, DItem * di)
 static void
 DialogUpdate(Dialog * d)
 {
-   if (d->item)
-      DialogDrawItem(d, d->item);
+   do
+     {
+	d->update = 0;
+	if (d->item)
+	   DialogDrawItem(d, d->item);
+     }
+   while (d->update);
    if (d->xu1 < d->xu2 && d->yu1 < d->yu2)
       EClearArea(d->win, d->xu1, d->yu1, d->xu2 - d->xu1, d->yu2 - d->yu1);
-   d->update = 0;
    d->xu1 = d->yu1 = 99999;
    d->xu2 = d->yu2 = 0;
 }
@@ -1759,7 +1717,7 @@ _DialogsCheckUpdate(void *data __UNUSED__)
 void
 DialogsInit(void)
 {
-   IdlerAdd(50, _DialogsCheckUpdate, NULL);
+   IdlerAdd(_DialogsCheckUpdate, NULL);
 }
 
 static void
@@ -2014,12 +1972,10 @@ DialogItemDestroy(DItem * di, int clean)
      case DITEM_SLIDER:
 	ImageclassFree(di->item.slider.ic_base);
 	ImageclassFree(di->item.slider.ic_knob);
-	ImageclassFree(di->item.slider.ic_border);
 	if (!clean)
 	   break;
 	EDestroyWindow(di->item.slider.base_win);
 	EDestroyWindow(di->item.slider.knob_win);
-	EDestroyWindow(di->item.slider.border_win);
 	break;
      case DITEM_AREA:
 	if (!clean)
@@ -2084,33 +2040,26 @@ DialogOKstr(const char *title, const char *txt)
    DialogShow(d);
 }
 
-void
-DialogAlert(const char *fmt, ...)
-{
-   char                text[10240];
-   va_list             args;
-
-   va_start(args, fmt);
-   Evsnprintf(text, 10240, fmt, args);
-   va_end(args);
-   Alert(text);
-}
-
-void
-DialogAlertOK(const char *fmt, ...)
-{
-   char                text[10240];
-   va_list             args;
-
-   va_start(args, fmt);
-   Evsnprintf(text, 10240, fmt, args);
-   va_end(args);
-   AlertX(_("Attention !!!"), _("OK"), NULL, NULL, text);
-}
-
 /*
  * Dialog event handlers
  */
+static int
+_DlgPixToVal(const DItem * di, int dx, int sr)
+{
+   int                 vr, value;
+
+   vr = di->item.slider.upper - di->item.slider.lower;
+   dx = (int)(((float)dx / (sr * di->item.slider.unit)) * vr + .5);
+   dx *= di->item.slider.unit;
+   value = di->item.slider.lower + dx;
+
+   if (value < di->item.slider.lower)
+      value = di->item.slider.lower;
+   if (value > di->item.slider.upper)
+      value = di->item.slider.upper;
+
+   return value;
+}
 
 static void
 DialogEventKeyPress(Dialog * d, XEvent * ev)
@@ -2146,8 +2095,6 @@ DialogHandleEvents(Win win __UNUSED__, XEvent * ev, void *prm)
 static void
 DItemEventMotion(Win win __UNUSED__, DItem * di, XEvent * ev)
 {
-   int                 dx, dy;
-
    switch (di->type)
      {
      case DITEM_AREA:
@@ -2160,38 +2107,24 @@ DItemEventMotion(Win win __UNUSED__, DItem * di, XEvent * ev)
 	   break;
 	if (ev->xmotion.window == WinGetXwin(di->item.slider.knob_win))
 	  {
-	     dx = Mode.events.mx - Mode.events.px;
-	     dy = Mode.events.my - Mode.events.py;
 	     if (di->item.slider.horizontal)
 	       {
-		  di->item.slider.wanted_val += dx;
 		  di->item.slider.val =
-		     di->item.slider.lower +
-		     (((di->item.slider.wanted_val *
-			(di->item.slider.upper -
-			 di->item.slider.lower)) /
-		       (di->item.slider.base_w -
-			di->item.slider.knob_w)) /
-		      di->item.slider.unit) * di->item.slider.unit;
+		     _DlgPixToVal(di,
+				  ev->xbutton.x + di->item.slider.knob_x -
+				  di->item.slider.knob_w / 2,
+				  di->item.slider.base_w -
+				  di->item.slider.knob_w);
 	       }
 	     else
 	       {
-		  di->item.slider.wanted_val += dy;
 		  di->item.slider.val =
-		     di->item.slider.lower +
-		     ((((di->item.
-			 slider.base_h - di->item.slider.knob_h -
-			 di->item.slider.wanted_val) *
-			(di->item.slider.upper -
-			 di->item.slider.lower)) /
-		       (di->item.slider.base_h -
-			di->item.slider.knob_h)) /
-		      di->item.slider.unit) * di->item.slider.unit;
+		     _DlgPixToVal(di,
+				  ev->xbutton.y + di->item.slider.knob_y -
+				  di->item.slider.knob_h / 2,
+				  di->item.slider.base_h -
+				  di->item.slider.knob_h);
 	       }
-	     if (di->item.slider.val < di->item.slider.lower)
-		di->item.slider.val = di->item.slider.lower;
-	     if (di->item.slider.val > di->item.slider.upper)
-		di->item.slider.val = di->item.slider.upper;
 	     if (di->item.slider.val_ptr)
 		*di->item.slider.val_ptr = di->item.slider.val;
 	     if (di->func)
@@ -2216,20 +2149,11 @@ DItemEventMouseDown(Win win, DItem * di, XEvent * ev)
 	break;
 
      case DITEM_SLIDER:
-#if 0				/* Do any themes have this? */
-	if (win == di->item.slider.border_win)
-	   break;
-#endif
-
 	if (ev->xbutton.window == WinGetXwin(di->item.slider.knob_win))
 	  {
 	     if (ev->xbutton.button >= 1 && ev->xbutton.button <= 3)
 	       {
 		  di->item.slider.in_drag = 1;
-		  if (di->item.slider.horizontal)
-		     di->item.slider.wanted_val = di->item.slider.knob_x;
-		  else
-		     di->item.slider.wanted_val = di->item.slider.knob_y;
 		  break;
 	       }
 	  }
@@ -2254,20 +2178,29 @@ DItemEventMouseDown(Win win, DItem * di, XEvent * ev)
 	       {
 		  if (ev->xbutton.y >
 		      (di->item.slider.knob_y + (di->item.slider.knob_h / 2)))
-		     di->item.slider.val -= di->item.slider.jump;
-		  else
 		     di->item.slider.val += di->item.slider.jump;
+		  else
+		     di->item.slider.val -= di->item.slider.jump;
 	       }
 	     break;
 
 	  case 2:
 	     if (di->item.slider.horizontal)
-		di->item.slider.val = x *
-		   (di->item.slider.upper - di->item.slider.lower) / di->w;
+	       {
+		  di->item.slider.val =
+		     _DlgPixToVal(di,
+				  ev->xbutton.x - di->item.slider.knob_w / 2,
+				  di->item.slider.base_w -
+				  di->item.slider.knob_w);
+	       }
 	     else
-		di->item.slider.val = ((di->h - y) *
-				       (di->item.slider.upper -
-					di->item.slider.lower) / di->h);
+	       {
+		  di->item.slider.val =
+		     _DlgPixToVal(di,
+				  ev->xbutton.y - di->item.slider.knob_h / 2,
+				  di->item.slider.base_h -
+				  di->item.slider.knob_h);
+	       }
 	     break;
 
 	  case 4:
@@ -2397,7 +2330,8 @@ DItemEventMouseOut(Win win __UNUSED__, DItem * di, XEvent * ev)
 	break;
      }
 
-   di->hilited = 0;
+   if (!di->clicked)
+      di->hilited = 0;
 
    DialogDrawItems(di->dlg, di, di->x, di->y, di->w, di->h);
 }
