@@ -61,7 +61,7 @@ typedef struct {
    const char         *name;
    const char         *label;
    const char         *title;
-   const char         *sound;
+   int                 sound;
    const char         *header_image;
    const char         *header_text;
    void                (*fill) (Dialog * d, DItem * table, void *data);
@@ -75,7 +75,6 @@ Dialog             *DialogFind(const char *name);
 void                DialogBindKey(Dialog * d, const char *key,
 				  DialogCallbackFunc * func, int val,
 				  void *data);
-void                DialogSetText(Dialog * d, const char *text);
 void                DialogSetTitle(Dialog * d, const char *title);
 void                DialogSetExitFunction(Dialog * d, DialogCallbackFunc * func,
 					  int val);
