@@ -35,7 +35,6 @@
 #include "eobj.h"
 #include "events.h"
 #include "hints.h"
-#include "settings.h"
 #include "timers.h"
 #include "windowmatch.h"
 #include "xwin.h"
@@ -47,8 +46,10 @@
 #include <unistd.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
+#include <X11/extensions/shape.h>
 #include <X11/extensions/Xcomposite.h>
 #include <X11/extensions/Xdamage.h>
+#include <X11/extensions/Xfixes.h>
 #include <X11/extensions/Xrender.h>
 
 #define ENABLE_SHADOWS      1
@@ -463,6 +464,19 @@ ERegionShow(const char *txt, XserverRegion rgn)
       XFree(pr);
 }
 
+void
+ECompMgrWinClipToGC(EObj * eo, GC gc)
+{
+   XserverRegion       rgn = rgn_tmp2;
+
+   if (!eo || !eo->cmhook)
+      return;
+
+   ERegionCopy(rgn, Mode_compmgr.rgn_screen);
+   ERegionSubtract(rgn, eo->cmhook->clip);
+   XFixesSetGCClipRegion(disp, gc, 0, 0, rgn);
+}
+
 /*
  * Pictures
  */
@@ -537,15 +551,15 @@ ECompMgrMoveResizeFix(EObj * eo, int x, int y, int w, int h)
 
    if (!cw || !Conf_compmgr.resize_fix_enable)
      {
-	EMoveResizeWindow(eo->win, x, y, w, h);
+	EMoveResizeWindow(EobjGetWin(eo), x, y, w, h);
 	return;
      }
 
    wo = ho = 0;
-   EGetGeometry(eo->win, NULL, NULL, NULL, &wo, &ho, NULL, NULL);
+   EGetGeometry(EobjGetWin(eo), NULL, NULL, NULL, &wo, &ho, NULL, NULL);
    if (wo <= 0 || ho <= 0 || (wo == w && ho == h))
      {
-	EMoveResizeWindow(eo->win, x, y, w, h);
+	EMoveResizeWindow(EobjGetWin(eo), x, y, w, h);
 	return;
      }
 
@@ -555,7 +569,7 @@ ECompMgrMoveResizeFix(EObj * eo, int x, int y, int w, int h)
 		    wo, ho);
 
    /* Resize (+move) */
-   EMoveResizeWindow(eo->win, x, y, w, h);
+   EMoveResizeWindow(EobjGetWin(eo), x, y, w, h);
 
    /* Paste old contents back in */
    if (w < wo)
@@ -1043,7 +1057,7 @@ ECompMgrWinSetExtents(EObj * eo)
 
 #if ENABLE_SHADOWS
    cw->has_shadow = (Mode_compmgr.shadow_mode != ECM_SHADOWS_OFF) &&
-      eo->shadow && (EShapeCheck(eo->win) >= 0);
+      eo->shadow && (EShapeCheck(EobjGetWin(eo)) >= 0);
    if (!cw->has_shadow)
       goto skip_shadow;
 
@@ -1171,7 +1185,7 @@ ECompMgrWinSetShape(EObj * eo)
 }
 
 static              Pixmap
-EWindowGetNamePixmap(Win win)
+EWindowGetNamePixmap(const struct _xwin *win)
 {
    XWindowAttributes   xwa;
 
@@ -1270,7 +1284,7 @@ ECompMgrWinSetOpacity(EObj * eo, unsigned int opacity)
 
    if (eo->noredir)
       mode = WINDOW_UNREDIR;
-   else if (eo->win->argb)
+   else if (EobjGetWin(eo)->argb)
       mode = WINDOW_ARGB;
    else if (cw->opacity != OPAQUE)
       mode = WINDOW_TRANS;
@@ -1501,7 +1515,7 @@ ECompMgrWinSetPicts(EObj * eo)
 	if (draw == None)
 	   return;
 
-	pictfmt = XRenderFindVisualFormat(disp, WinGetVisual(eo->win));
+	pictfmt = XRenderFindVisualFormat(disp, WinGetVisual(EobjGetWin(eo)));
 	pa.subwindow_mode = IncludeInferiors;
 	cw->picture = XRenderCreatePicture(disp, draw,
 					   pictfmt, CPSubwindowMode, &pa);
@@ -1527,7 +1541,7 @@ ECompMgrWinNew(EObj * eo)
    if (!Mode_compmgr.active)	/* FIXME - Here? */
       return;
 
-   if (eo->inputonly || eo->win == VROOT)
+   if (eo->inputonly || EobjGetWin(eo) == VROOT)
      {
 	eo->noredir = 1;
 	return;
@@ -1578,7 +1592,7 @@ ECompMgrWinNew(EObj * eo)
 
    if (eo->type == EOBJ_TYPE_DESK || eo->type == EOBJ_TYPE_ROOT_BG)
      {
-	ESelectInputChange(eo->win, VisibilityChangeMask, 0);
+	ESelectInputChange(EobjGetWin(eo), VisibilityChangeMask, 0);
      }
 
    if (eo->type != EOBJ_TYPE_EWIN)
@@ -1587,7 +1601,7 @@ ECompMgrWinNew(EObj * eo)
    cw->opacity = 0xdeadbeef;
    ECompMgrWinSetOpacity(eo, eo->opacity);
 
-   EventCallbackRegister(eo->win, 0, ECompMgrHandleWindowEvent, eo);
+   EventCallbackRegister(EobjGetWin(eo), 0, ECompMgrHandleWindowEvent, eo);
 }
 
 void
@@ -1695,7 +1709,7 @@ ECompMgrWinConfigure(EObj * eo, XEvent * ev)
    change_wh = EobjGetW(eo) != w || EobjGetH(eo) != h;
    change_bw = EobjGetBW(eo) != bw;
 
-   EWindowSetGeometry(eo->win, x, y, w, h, bw);
+   EWindowSetGeometry(EobjGetWin(eo), x, y, w, h, bw);
 
    ECompMgrWinMoveResize(eo, change_xy, change_wh, change_bw);
 }
@@ -1786,7 +1800,7 @@ ECompMgrWinDel(EObj * eo)
    if (eo->fading)
       ECompMgrWinFadeEnd(eo, 1);
 
-   EventCallbackUnregister(eo->win, 0, ECompMgrHandleWindowEvent, eo);
+   EventCallbackUnregister(EobjGetWin(eo), 0, ECompMgrHandleWindowEvent, eo);
 
    if (!eo->gone)
      {
@@ -2843,7 +2857,7 @@ ECompMgrSighan(int sig, void *prm __UNUSED__)
 	ECompMgrInit();
 	if (Conf_compmgr.enable)
 	   ECompMgrStart();
-	IdlerAdd(50, _ECompMgrIdler, NULL);
+	IdlerAdd(_ECompMgrIdler, NULL);
 	break;
      }
 }
@@ -2868,10 +2882,6 @@ CompMgrIpc(const char *params)
      {
 	IpcPrintf("CompMgr - on=%d\n", Mode_compmgr.active);
      }
-   else if (!strcmp(cmd, "cfg"))
-     {
-	SettingsComposite();
-     }
    else if (!strcmp(cmd, "start"))
      {
 	ECompMgrStart();
@@ -2905,7 +2915,6 @@ static const IpcItem CompMgrIpcArray[] = {
     "compmgr", "cm",
     "Composite manager functions",
     "  cm ?                     Show info\n"
-    "  cm cfg                   Configure\n"
     "  cm start                 Start composite manager\n"
     "  cm stop                  Stop composite manager\n"}
    ,
