@@ -40,7 +40,8 @@ typedef struct {
    ECfgFileItem       *pitms;
 } ECfgFile;
 
-#define E_DB_File ECfgFile
+static void         CfgItemSetFromString(const CfgItem * ci, const char *str,
+					 int set_dflt);
 
 static ECfgFile    *
 e16_db_open(const char *name)
@@ -145,84 +146,16 @@ ECfgFileFindValue(ECfgFile * ecf, const char *key)
    return NULL;
 }
 
-static int
-e16_db_int_get(ECfgFile * ecf, const char *key, int *pint)
-{
-   const char         *value;
-
-   value = ECfgFileFindValue(ecf, key);
-   if (!value)
-      return 0;
-
-   if (sscanf(value, "%i", pint) < 1)
-      return 0;
-
-   return 1;
-}
-
-static int
-e16_db_float_get(ECfgFile * ecf, const char *key, float *pflt)
-{
-   const char         *value;
-
-   value = ECfgFileFindValue(ecf, key);
-   if (!value)
-      return 0;
-
-   if (sscanf(value, "%f", pflt) < 1)
-      return 0;
-
-   return 1;
-}
-
-static char        *
-e16_db_str_get(ECfgFile * ecf, const char *key)
-{
-   const char         *value;
-
-   value = ECfgFileFindValue(ecf, key);
-   if (!value || !value[0])
-      return NULL;
-
-   return Estrdup(value);
-}
-
-static void
-e16_db_int_set(ECfgFile * ecf, const char *key, int value)
-{
-   fprintf(ecf->fs, "%s = %d\n", key, value);
-}
-
-static void
-e16_db_hex_set(ECfgFile * ecf, const char *key, unsigned int value)
-{
-   fprintf(ecf->fs, "%s = %#x\n", key, value);
-}
-
-static void
-e16_db_float_set(ECfgFile * ecf, const char *key, float value)
-{
-   fprintf(ecf->fs, "%s = %f\n", key, value);
-}
-
-static void
-e16_db_str_set(ECfgFile * ecf, const char *key, const char *value)
-{
-   fprintf(ecf->fs, "%s = %s\n", key, (value) ? value : "");
-}
-
 /*
  * Configuration handling.
  */
 
 static void
-CfgItemLoad(E_DB_File * edf, const char *prefix, const CfgItem * ci)
+CfgItemLoad(ECfgFile * ecf, const char *prefix, const CfgItem * ci)
 {
    char                buf[1024];
    const char         *name = buf;
-   int                 my_int;
-   float               my_float;
-   char               *s;
+   const char         *value;
 
    if (prefix)
       Esnprintf(buf, sizeof(buf), "%s.%s", prefix, ci->name);
@@ -235,37 +168,15 @@ CfgItemLoad(E_DB_File * edf, const char *prefix, const CfgItem * ci)
    if (!ci->ptr)
       return;
 
-   switch (ci->type)
-     {
-     case ITEM_TYPE_BOOL:
-	if (!edf || !e16_db_int_get(edf, name, &my_int))
-	   my_int = (ci->dflt) ? 1 : 0;
-	*((char *)ci->ptr) = my_int;
-	break;
-     case ITEM_TYPE_INT:
-     case ITEM_TYPE_HEX:
-	if (!edf || !e16_db_int_get(edf, name, &my_int))
-	   my_int = ci->dflt;
-	*((int *)ci->ptr) = my_int;
-	break;
-     case ITEM_TYPE_FLOAT:
-	if (!edf || !e16_db_float_get(edf, name, &my_float))
-	   my_float = ci->dflt;
-	*((float *)ci->ptr) = my_float;
-	break;
-     case ITEM_TYPE_STRING:
-	s = (edf) ? e16_db_str_get(edf, name) : NULL;
-	*((char **)ci->ptr) = s;
-	break;
-     }
+   value = (ecf) ? ECfgFileFindValue(ecf, name) : NULL;
+   CfgItemSetFromString(ci, value, 1);
 }
 
 static void
-CfgItemSave(E_DB_File * edf, const char *prefix, const CfgItem * ci)
+CfgItemSave(ECfgFile * ecf, const char *prefix, const CfgItem * ci)
 {
-   char                buf[1024];
+   char                buf[1024], buf2[1024];
    const char         *name = buf;
-   char               *s;
 
    if (prefix)
       Esnprintf(buf, sizeof(buf), "%s.%s", prefix, ci->name);
@@ -278,25 +189,8 @@ CfgItemSave(E_DB_File * edf, const char *prefix, const CfgItem * ci)
    if (!ci->ptr)
       return;
 
-   switch (ci->type)
-     {
-     case ITEM_TYPE_BOOL:
-	e16_db_int_set(edf, name, *((char *)ci->ptr));
-	break;
-     case ITEM_TYPE_INT:
-	e16_db_int_set(edf, name, *((int *)ci->ptr));
-	break;
-     case ITEM_TYPE_HEX:
-	e16_db_hex_set(edf, name, *((unsigned int *)ci->ptr));
-	break;
-     case ITEM_TYPE_FLOAT:
-	e16_db_float_set(edf, name, *((float *)ci->ptr));
-	break;
-     case ITEM_TYPE_STRING:
-	s = *(char **)(ci->ptr);
-	e16_db_str_set(edf, name, s);
-	break;
-     }
+   CfgItemToString(ci, buf2, sizeof(buf2));
+   fprintf(ecf->fs, "%s = %s\n", name, buf2);
 }
 
 static const char  *
@@ -313,14 +207,14 @@ ConfigurationLoad(void)
    const EModule     **pml, *pm;
    const CfgItem      *pcl;
    char                buf[4096];
-   E_DB_File          *edf;
+   ECfgFile           *ecf;
 
    if (EDebug(EDBUG_TYPE_CONFIG))
       Eprintf("ConfigurationLoad\n");
 
    memset(&Conf, 0, sizeof(EConf));
 
-   edf = e16_db_open_read(ConfigurationGetFile(buf, sizeof(buf)));
+   ecf = e16_db_open_read(ConfigurationGetFile(buf, sizeof(buf)));
    /* NB! We have to assign the defaults even if it doesn't exist */
 
    /* Load module configs */
@@ -331,12 +225,12 @@ ConfigurationLoad(void)
 	ncl = pm->cfg.num;
 	pcl = pm->cfg.lst;
 	for (j = 0; j < ncl; j++)
-	   CfgItemLoad(edf, pm->name, pcl + j);
+	   CfgItemLoad(ecf, pm->name, pcl + j);
      }
    ModuleListFree(pml);
 
-   if (edf)
-      e16_db_close(edf);
+   if (ecf)
+      e16_db_close(ecf);
 }
 
 void
@@ -346,13 +240,13 @@ ConfigurationSave(void)
    const EModule     **pml, *pm;
    const CfgItem      *pcl;
    char                buf[4096];
-   E_DB_File          *edf;
+   ECfgFile           *ecf;
 
    if (EDebug(EDBUG_TYPE_CONFIG))
       Eprintf("ConfigurationSave\n");
 
-   edf = e16_db_open(ConfigurationGetFile(buf, sizeof(buf)));
-   if (edf == NULL)
+   ecf = e16_db_open(ConfigurationGetFile(buf, sizeof(buf)));
+   if (ecf == NULL)
       return;
 
    /* Load module configs */
@@ -363,11 +257,11 @@ ConfigurationSave(void)
 	ncl = pm->cfg.num;
 	pcl = pm->cfg.lst;
 	for (j = 0; j < ncl; j++)
-	   CfgItemSave(edf, pm->name, pcl + j);
+	   CfgItemSave(ecf, pm->name, pcl + j);
      }
    ModuleListFree(pml);
 
-   e16_db_close(edf);
+   e16_db_close(ecf);
    e16_db_flush();
 }
 
@@ -383,35 +277,55 @@ CfgItemFind(const CfgItem * pcl, int ncl, const char *name)
 }
 
 static void
-CfgItemSetFromString(const CfgItem * ci, const char *str)
+CfgItemSetFromString(const CfgItem * ci, const char *str, int set_dflt)
 {
-   int                 n, ival;
-   float               fval;
+   int                 ival;
 
+#ifdef ITEM_TYPE_FLOAT
+   int                 n;
+   float               fval;
+#endif
+   char               *ptr;
+
+   ptr = (char *)str;
    switch (ci->type)
      {
      case ITEM_TYPE_BOOL:
-	n = sscanf(str, "%i", &ival);
-	if (n <= 0)
-	   break;
+	ival = (str) ? strtoul(str, &ptr, 0) : 0;
+	if (ptr <= str)
+	  {
+	     if (!set_dflt)
+		break;
+	     ival = (ci->dflt) ? 1 : 0;
+	  }
 	*((char *)ci->ptr) = ival;
 	break;
      case ITEM_TYPE_INT:
      case ITEM_TYPE_HEX:
-	n = sscanf(str, "%i", &ival);
-	if (n <= 0)
-	   break;
+	ival = (str) ? strtoul(str, &ptr, 0) : 0;
+	if (ptr <= str)
+	  {
+	     if (!set_dflt)
+		break;
+	     ival = ci->dflt;
+	  }
 	*((int *)ci->ptr) = ival;
 	break;
+#ifdef ITEM_TYPE_FLOAT
      case ITEM_TYPE_FLOAT:
-	n = sscanf(str, "%f", &fval);
+	n = (str) ? sscanf(str, "%f", &fval) : 0;
 	if (n <= 0)
-	   break;
+	  {
+	     if (!set_dflt)
+		break;
+	     fval = ci->dflt;
+	  }
 	*((float *)ci->ptr) = fval;
 	break;
+#endif
      case ITEM_TYPE_STRING:
 	Efree(*(char **)ci->ptr);
-	if (*str == '\0')
+	if (str && *str == '\0')
 	   str = NULL;
 	*((char **)ci->ptr) = Estrdup(str);
 	break;
@@ -421,6 +335,7 @@ CfgItemSetFromString(const CfgItem * ci, const char *str)
 void
 CfgItemToString(const CfgItem * ci, char *buf, int len)
 {
+   buf[0] = '\0';
    switch (ci->type)
      {
      case ITEM_TYPE_BOOL:
@@ -432,14 +347,14 @@ CfgItemToString(const CfgItem * ci, char *buf, int len)
      case ITEM_TYPE_HEX:
 	Esnprintf(buf, len, "%#x", *((unsigned int *)ci->ptr));
 	break;
+#ifdef ITEM_TYPE_FLOAT
      case ITEM_TYPE_FLOAT:
 	Esnprintf(buf, len, "%.3f", *((float *)ci->ptr));
 	break;
+#endif
      case ITEM_TYPE_STRING:
 	if (*((char **)ci->ptr))
 	   Esnprintf(buf, len, "%s", *((char **)ci->ptr));
-	else
-	   buf[0] = '\0';
 	break;
      }
 }
@@ -457,11 +372,12 @@ CfgItemListNamedItemSet(const CfgItem * pcl, int ncl, const char *item,
    if (ci->func)
       ci->func(ci->ptr, value);
    else
-      CfgItemSetFromString(ci, value);
+      CfgItemSetFromString(ci, value, 0);
 
    return 0;
 }
 
+#if 0				/* Unused */
 int
 CfgItemListNamedItemToString(const CfgItem * pcl, int ncl, const char *item,
 			     char *buf, int len)
@@ -475,6 +391,7 @@ CfgItemListNamedItemToString(const CfgItem * pcl, int ncl, const char *item,
 
    return 0;
 }
+#endif
 
 /*
  * Set <module>.<item> <value>
