@@ -29,6 +29,8 @@
 #include "tooltips.h"
 #include "xwin.h"
 #include <sys/time.h>
+#include <X11/Xutil.h>
+#include <X11/extensions/shape.h>
 #if USE_XSYNC
 #include <X11/extensions/sync.h>
 #endif
@@ -387,7 +389,7 @@ HandleEvent(XEvent * ev)
 	break;
 
      case ButtonPress:		/*  4 */
-	SoundPlay("SOUND_BUTTON_CLICK");
+	SoundPlay(SOUND_BUTTON_CLICK);
 
 	Mode.events.double_click =
 	   ((ev->xbutton.time - Mode.events.last_btime < DOUBLE_CLICK_TIME) &&
@@ -400,7 +402,7 @@ HandleEvent(XEvent * ev)
 	Mode.events.last_button = ev->xbutton.button;
 	break;
      case ButtonRelease:	/*  5 */
-	SoundPlay("SOUND_BUTTON_RAISE");
+	SoundPlay(SOUND_BUTTON_RAISE);
 	break;
      }
 
@@ -420,6 +422,11 @@ HandleEvent(XEvent * ev)
 	EUnregisterXwin(ev->xdestroywindow.window);
 	break;
 #endif
+
+     case MappingNotify:
+	if (Conf.testing.bindings_reload)
+	   ActionclassesReload();
+	break;
      }
 }
 
@@ -996,6 +1003,11 @@ EventShow(const XEvent * ev)
 		ev->xclient.data.l[4]);
 	XFree(txt);
 	break;
+     case MappingNotify:
+	Eprintf("%s req=%d first=%d count=%d\n",
+		buf, ev->xmapping.request,
+		ev->xmapping.first_keycode, ev->xmapping.count);
+	break;
 
      case EX_EVENT_SHAPE_NOTIFY:
 #define se ((XShapeEvent *)ev)
@@ -1018,7 +1030,8 @@ EventShow(const XEvent * ev)
 #if USE_COMPOSITE
 #define de ((XDamageNotifyEvent *)ev)
      case EX_EVENT_DAMAGE_NOTIFY:
-	Eprintf("%s %d+%d %dx%d\n", buf,
+	Eprintf("%s level=%d more=%x %d+%d %dx%d\n", buf,
+		de->level, de->more,
 		de->area.x, de->area.y, de->area.width, de->area.height);
 	break;
 #undef de
