@@ -45,6 +45,7 @@ static const WinOp  winops[] = {
    {"close", 2, 1, 0, EWIN_OP_CLOSE},
    {"kill", 0, 1, 0, EWIN_OP_KILL},
    {"iconify", 2, 1, 1, EWIN_OP_ICONIFY},
+   {"alone", 0, 1, 0, EWIN_OP_ALONE},
    {"opacity", 2, 1, 1, EWIN_OP_OPACITY},
    {"focused_opacity", 0, 1, 1, EWIN_OP_FOCUSED_OPACITY},
    {"shadow", 0, 1, 1, EWIN_OP_SHADOW},	/* Place before "shade" */
@@ -90,7 +91,8 @@ static const WinOp  winops[] = {
    {"no_wm_focus", 0, 1, 1, EWIN_OP_INH_WM_FOCUS},
 
    {"fade", 0, 1, 1, EWIN_OP_FADE},
-   {"noredir", 4, 1, 1, EWIN_OP_NO_REDIRECT},
+   {"no_redir", 4, 1, 1, EWIN_OP_NO_REDIRECT},
+   {"no_argb", 0, 1, 1, EWIN_OP_NO_ARGB},
 
    {NULL, 0, 0, 0, EWIN_OP_INVALID}	/* Terminator */
 };
@@ -118,32 +120,6 @@ EwinOpFind(const char *op)
    return NULL;
 }
 
-#if 0				/* Unused */
-void
-EwinFixPosition(EWin * ewin)
-{
-   int                 x, y;
-
-   if (!EwinIsMapped(ewin))
-      return;
-
-   x = EoGetX(ewin);
-   if ((x + ewin->border->border.left + 1) > WinGetW(VROOT))
-      x = WinGetW(VROOT) - ewin->border->border.left - 1;
-   else if ((x + EoGetW(ewin) - ewin->border->border.right - 1) < 0)
-      x = 0 - EoGetW(ewin) + ewin->border->border.right + 1;
-
-   y = EoGetY(ewin);
-   if ((y + ewin->border->border.top + 1) > WinGetH(VROOT))
-      y = WinGetH(VROOT) - ewin->border->border.top - 1;
-   else if ((y + EoGetH(ewin) - ewin->border->border.bottom - 1) < 0)
-      y = 0 - EoGetH(ewin) + ewin->border->border.bottom + 1;
-
-   if (x != EoGetX(ewin) || y != EoGetY(ewin))
-      EwinMove(ewin, x, y);
-}
-#endif
-
 static void
 EwinDetermineArea(EWin * ewin)
 {
@@ -426,7 +402,7 @@ doEwinMoveResize(EWin * ewin, Desk * dsk, int x, int y, int w, int h, int flags)
    if (Mode.op_source == OPSRC_USER)
       EwinSetPlacementGravity(ewin, x, y);
 
-   if (ewin->ops && ewin->ops->MoveResize)
+   if ((flags & (MRF_MOVE | MRF_RESIZE)) && ewin->ops && ewin->ops->MoveResize)
       ewin->ops->MoveResize(ewin, resize);
 
    if (Mode.mode == MODE_NONE)
@@ -470,7 +446,7 @@ EwinMoveResize(EWin * ewin, int x, int y, int w, int h)
 void
 EwinMoveResizeWithGravity(EWin * ewin, int x, int y, int w, int h, int grav)
 {
-   EwinGetPosition(ewin, x, y, ewin->client.bw, grav, &x, &y);
+   EwinGetPosition(ewin, x, y, grav, &x, &y);
    doEwinMoveResize(ewin, NULL, x, y, w, h, MRF_MOVE | MRF_RESIZE);
 }
 
@@ -595,6 +571,26 @@ EwinIconify(EWin * ewin)
    call_depth--;
 }
 
+void
+EwinAlone(EWin * ewin)
+{
+   EWin               *const *lst, *item;
+   int                 i, num;
+
+   lst = EwinListGetForDesk(&num, EoGetDesk(ewin));
+
+   for (i = 0; i < num; i++)
+     {
+	item = lst[i];
+
+	if (item == ewin || EwinIsTransient(item) ||
+	    item->state.iconified || item->state.donthide ||
+	    item->area_x != ewin->area_x || item->area_y != ewin->area_y)
+	   continue;
+	EwinIconify(item);
+     }
+}
+
 static void
 GetOnScreenPos(int x, int y, int w, int h, int *px, int *py)
 {
@@ -850,8 +846,7 @@ EwinInstantUnShade(EWin * ewin)
 
 #define _EWIN_ADJUST_SHAPE(ewin, xo, yo) \
   do { \
-    EShapeCombineShape(ewin->win_container, ShapeBounding, xo, yo, \
-                       EwinGetClientWin(ewin), ShapeBounding, ShapeSet); \
+    EShapeSetShape(ewin->win_container, xo, yo, EwinGetClientWin(ewin)); \
     ewin->update.shape = 1; \
   } while (0)
 
@@ -1360,8 +1355,8 @@ EwinsShowDesktop(int on)
 
 	if (on)
 	  {
-	     if (EwinIsInternal(ewin) || ewin->state.iconified
-		 || ewin->props.donthide || EwinIsTransient(ewin))
+	     if (EwinIsTransient(ewin) ||
+		 ewin->state.iconified || ewin->state.donthide)
 		continue;
 
 	     ewin->state.showingdesk = 1;
@@ -1422,7 +1417,7 @@ EwinOpClose(EWin * ewin, int source __UNUSED__)
    for (i = 0; i < num; i++)
      {
 	ICCCM_Delete(gwins[i]);
-	SoundPlay("SOUND_WINDOW_CLOSE");
+	SoundPlay(SOUND_WINDOW_CLOSE);
      }
    Efree(gwins);
 }
@@ -1430,7 +1425,7 @@ EwinOpClose(EWin * ewin, int source __UNUSED__)
 void
 EwinOpKill(EWin * ewin, int source __UNUSED__)
 {
-   SoundPlay("SOUND_WINDOW_CLOSE");
+   SoundPlay(SOUND_WINDOW_CLOSE);
    EwinKill(ewin);
 }
 
@@ -1440,7 +1435,7 @@ EwinOpRaise(EWin * ewin, int source __UNUSED__)
    EWin              **gwins = NULL;
    int                 i, num;
 
-   SoundPlay("SOUND_RAISE");
+   SoundPlay(SOUND_RAISE);
    gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_RAISE,
 				      Mode.nogroup, &num);
    for (i = 0; i < num; i++)
@@ -1454,7 +1449,7 @@ EwinOpLower(EWin * ewin, int source __UNUSED__)
    EWin              **gwins = NULL;
    int                 i, num;
 
-   SoundPlay("SOUND_LOWER");
+   SoundPlay(SOUND_LOWER);
    gwins = ListWinGroupMembersForEwin(ewin, GROUP_ACTION_LOWER,
 				      Mode.nogroup, &num);
    for (i = 0; i < num; i++)
@@ -1508,13 +1503,13 @@ EwinOpRaiseLower(EWin * ewin)
 
    if (!raise)
      {
-	SoundPlay("SOUND_LOWER");
+	SoundPlay(SOUND_LOWER);
 	for (j = 0; j < gnum; j++)
 	   EwinLower(gwins[j]);
      }
    else
      {
-	SoundPlay("SOUND_RAISE");
+	SoundPlay(SOUND_RAISE);
 	for (j = 0; j < gnum; j++)
 	   EwinRaise(gwins[j]);
      }
@@ -1538,13 +1533,13 @@ EwinOpStick(EWin * ewin, int source __UNUSED__, int on)
 	if (EoIsSticky(gwins[i])
 	    && ((curr_group && !curr_group->cfg.mirror) || !on))
 	  {
-	     SoundPlay("SOUND_WINDOW_UNSTICK");
+	     SoundPlay(SOUND_WINDOW_UNSTICK);
 	     EwinUnStick(gwins[i]);
 	  }
 	else if (!EoIsSticky(gwins[i])
 		 && ((curr_group && !curr_group->cfg.mirror) || on))
 	  {
-	     SoundPlay("SOUND_WINDOW_STICK");
+	     SoundPlay(SOUND_WINDOW_STICK);
 	     EwinStick(gwins[i]);
 	  }
      }
@@ -1647,13 +1642,13 @@ EwinOpShade(EWin * ewin, int source __UNUSED__, int on)
 	if (gwins[i]->state.shaded
 	    && ((curr_group && !curr_group->cfg.mirror) || !on))
 	  {
-	     SoundPlay("SOUND_UNSHADE");
+	     SoundPlay(SOUND_UNSHADE);
 	     EwinUnShade(gwins[i]);
 	  }
 	else if (!gwins[i]->state.shaded
 		 && ((curr_group && !curr_group->cfg.mirror) || on))
 	  {
-	     SoundPlay("SOUND_SHADE");
+	     SoundPlay(SOUND_SHADE);
 	     EwinShade(gwins[i]);
 	  }
 	SnapshotEwinUpdate(gwins[i], SNAP_USE_SHADED);
@@ -1666,11 +1661,11 @@ EwinOpSetLayer(EWin * ewin, int source __UNUSED__, int layer)
 {
    if (EoGetLayer(ewin) > layer)
      {
-	SoundPlay("SOUND_WINDOW_CHANGE_LAYER_DOWN");
+	SoundPlay(SOUND_WINDOW_CHANGE_LAYER_DOWN);
      }
    else if (EoGetLayer(ewin) < layer)
      {
-	SoundPlay("SOUND_WINDOW_CHANGE_LAYER_UP");
+	SoundPlay(SOUND_WINDOW_CHANGE_LAYER_UP);
      }
    EoSetLayer(ewin, layer);
    EwinRaise(ewin);
@@ -1715,14 +1710,14 @@ EwinOpSetBorder(EWin * ewin, int source __UNUSED__, const char *name)
      {
 	if (b != gwins[i]->border)
 	  {
-	     SoundPlay("SOUND_WINDOW_BORDER_CHANGE");
+	     SoundPlay(SOUND_WINDOW_BORDER_CHANGE);
 	     shadechange = 0;
 	     if (gwins[i]->state.shaded)
 	       {
 		  shadechange = 1;
 		  EwinInstantUnShade(gwins[i]);
 	       }
-	     EwinSetBorder(gwins[i], b, 1);
+	     EwinBorderChange(gwins[i], b, 1);
 	     if (shadechange)
 		EwinInstantShade(gwins[i], 0);
 	  }
