@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2007 Kim Woelders
+ * Copyright (C) 2005-2008 Kim Woelders
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -32,6 +32,7 @@ typedef enum {
    EWIN_OP_CLOSE,
    EWIN_OP_KILL,
    EWIN_OP_ICONIFY,
+   EWIN_OP_ALONE,
    EWIN_OP_SHADE,
    EWIN_OP_STICK,
    EWIN_OP_FOCUS,
@@ -74,6 +75,7 @@ typedef enum {
    EWIN_OP_FADE,
    EWIN_OP_SHADOW,
    EWIN_OP_NO_REDIRECT,
+   EWIN_OP_NO_ARGB,
 } winop_e;
 
 typedef struct {
