@@ -39,6 +39,8 @@
 #include "timers.h"
 #include "windowmatch.h"
 #include "xwin.h"
+#include <X11/Xutil.h>
+#include <X11/extensions/shape.h>
 
 #define EWIN_TOP_EVENT_MASK \
   (/* ButtonPressMask | ButtonReleaseMask | */ \
@@ -53,7 +55,7 @@
    /* StructureNotifyMask | */ ResizeRedirectMask | \
    PropertyChangeMask | ColormapChangeMask | VisibilityChangeMask)
 
-static void         EwinSlideIn(int val __UNUSED__, void *data);
+static int          EwinSlideIn(void *data);
 
 static void         EwinChangesStart(EWin * ewin);
 static void         EwinChangesProcess(EWin * ewin);
@@ -93,6 +95,7 @@ EwinCreate(int type)
    ewin->o.stacked = -1;	/* Not placed on desk yet */
    EoSetDesk(ewin, DesksGetCurrent());
    EoSetLayer(ewin, 4);
+   EoSetFade(ewin, 1);
    EoSetShadow(ewin, 1);
 
    ewin->update.shape = 1;
@@ -152,7 +155,6 @@ EwinGetAttributes(EWin * ewin, Win win, Window xwin)
    ewin->client.h = ewin->save_max.h = ewin->save_fs.h = xwa.height;
    ewin->client.bw = xwa.border_width;
    ewin->client.cmap = xwa.colormap;
-   ewin->client.grav = NorthWestGravity;
 
    if (EDebug(EDBUG_TYPE_SNAPS))
       Eprintf("Snap get attr  %#lx: %4d+%4d %4dx%4d: %s\n",
@@ -217,6 +219,7 @@ EwinManage(EWin * ewin)
 {
    XSetWindowAttributes att;
    Win                 frame;
+   int                 type;
 
    if (ewin->client.w <= 0)
       ewin->client.w = 100;
@@ -229,9 +232,10 @@ EwinManage(EWin * ewin)
    frame = EoGetWin(ewin);
    if (!frame)
      {
+	type = (ewin->props.no_argb) ? WIN_TYPE_NO_ARGB : WIN_TYPE_CLIENT;
 	frame =
 	   ECreateObjectWindow(VROOT, ewin->client.x, ewin->client.y,
-			       ewin->client.w, ewin->client.h, 0, 0,
+			       ewin->client.w, ewin->client.h, 0, type,
 			       EwinGetClientWin(ewin));
 	ewin->win_container =
 	   ECreateWindow(frame, 0, 0, ewin->client.w, ewin->client.h, 0);
@@ -293,9 +297,11 @@ static void
 EwinSetGeometry(EWin * ewin)
 {
    int                 x, y, l, r, t, b;
+   int                 grav;
 
-   EwinGetPosition(ewin, ewin->client.x, ewin->client.y, ewin->client.bw,
-		   ewin->client.grav, &x, &y);
+   grav = (ewin->state.identified) ? StaticGravity : ewin->icccm.grav;
+
+   EwinGetPosition(ewin, ewin->client.x, ewin->client.y, grav, &x, &y);
 
    l = ewin->border->border.left;
    r = ewin->border->border.right;
@@ -306,8 +312,6 @@ EwinSetGeometry(EWin * ewin)
    ewin->client.y = y + t;
 
    EoMoveResize(ewin, x, y, ewin->client.w + l + r, ewin->client.h + t + b);
-
-   ewin->client.grav = NorthWestGravity;
 }
 
 static void
@@ -315,11 +319,9 @@ EwinConfigure(EWin * ewin)
 {
    EwinStateUpdate(ewin);
 
-   WindowMatchEwinOps(ewin);	/* Window matches */
    if (!EwinIsInternal(ewin) && Mode.wm.startup)
       EHintsGetInfo(ewin);	/* E restart hints */
    EwinHintsInferProps(ewin);
-   SnapshotsEwinMatch(ewin);	/* Find a saved settings match */
    SnapshotEwinApply(ewin);	/* Apply saved settings */
 
    if (ewin->save_fs.layer < 0)
@@ -334,7 +336,7 @@ EwinConfigure(EWin * ewin)
    EwinBorderSetTo(ewin, NULL);
 
    if (!ewin->props.no_button_grabs)
-      GrabButtonGrabs(ewin);
+      GrabButtonGrabs(EoGetWin(ewin));
 
    if (ewin->state.shaded)
       EwinInstantShade(ewin, 1);
@@ -466,18 +468,6 @@ DetermineEwinFloat(EWin * ewin, int dx, int dy)
      }
 }
 
-#if 0				/* Remove? */
-EWin               *
-GetEwinByCurrentPointer(void)
-{
-   Window              child;
-
-   EQueryPointer(EoGetWin(DesksGetCurrent()), NULL, NULL, &child, NULL);
-
-   return EwinFindByFrame(child);
-}
-#endif
-
 EWin               *
 GetEwinPointerInClient(void)
 {
@@ -548,29 +538,32 @@ SetContextEwin(EWin * ewin)
  * Derive frame window position from client window and border properties
  */
 void
-EwinGetPosition(const EWin * ewin, int x, int y, int bw, int grav,
-		int *px, int *py)
+EwinGetPosition(const EWin * ewin, int x, int y, int grav, int *px, int *py)
 {
-   int                 bd_lr, bd_tb;
+   int                 bw, bd_lr, bd_tb;
 
+   bw = ewin->client.bw;
    bd_lr = ewin->border->border.left + ewin->border->border.right;
    bd_tb = ewin->border->border.top + ewin->border->border.bottom;
 
+   if (grav == 0)
+      grav = ewin->icccm.grav;
+
    switch (grav)
      {
      case NorthWestGravity:
-     case SouthWestGravity:
      case WestGravity:
+     case SouthWestGravity:
 	x -= bw;
 	break;
-     case NorthEastGravity:
-     case EastGravity:
-     case SouthEastGravity:
-	x -= bd_lr;
-	break;
      case NorthGravity:
      case CenterGravity:
      case SouthGravity:
+	x -= bd_lr / 2;
+	break;
+     case NorthEastGravity:
+     case EastGravity:
+     case SouthEastGravity:
 	x -= bd_lr - bw;
 	break;
      case StaticGravity:
@@ -590,7 +583,7 @@ EwinGetPosition(const EWin * ewin, int x, int y, int bw, int grav,
      case WestGravity:
      case CenterGravity:
      case EastGravity:
-	y -= bd_tb;
+	y -= bd_tb / 2;
 	break;
      case SouthWestGravity:
      case SouthGravity:
@@ -612,7 +605,8 @@ void
 EwinUpdateShapeInfo(EWin * ewin)
 {
    EGrabServer();
-   ewin->state.shaped = EShapeCopy(ewin->win_container, EwinGetClientWin(ewin));
+   ewin->state.shaped =
+      EShapeSetShape(ewin->win_container, 0, 0, EwinGetClientWin(ewin));
    EUngrabServer();
 
    if (EDebug(EX_EVENT_SHAPE_NOTIFY))
@@ -667,6 +661,10 @@ EwinStateUpdate(EWin * ewin)
    ewin->state.inhibit_close = EwinInhGetApp(ewin, close) ||
       EwinInhGetUser(ewin, close);
 
+   ewin->state.donthide = ewin->props.donthide ||
+      ewin->props.skip_ext_task || ewin->props.skip_winlist ||
+      ewin->props.skip_focuslist;
+
    SnapshotEwinUpdate(ewin, SNAP_USE_FLAGS);
 }
 
@@ -696,6 +694,7 @@ AddToFamily(EWin * ewin, Window xwin)
      }
 
    EwinGetHints(ewin);
+   WindowMatchEwinOps(ewin);	/* Window matches */
    EwinManage(ewin);
    EwinConfigure(ewin);
 
@@ -795,7 +794,27 @@ AddToFamily(EWin * ewin, Window xwin)
 	goto done;
      }
 
-   EwinResize(ewin, ewin->client.w, ewin->client.h);
+   if (!ewin->state.identified &&
+       (ewin->state.maximized_horz || ewin->state.maximized_vert))
+     {
+	int                 hor, ver;
+
+	/* New client requested maximisation */
+	hor = ewin->state.maximized_horz;
+	ver = ewin->state.maximized_vert;
+	ewin->state.maximized_horz = ewin->state.maximized_vert = 0;
+	MaxSizeHV(ewin, "absolute", hor, ver);
+	/* Set old state to current maximized one */
+	ewin->save_max.x = EoGetX(ewin);
+	ewin->save_max.y = EoGetY(ewin);
+	ewin->save_max.w = ewin->client.w;
+	ewin->save_max.h = ewin->client.h;
+	ewin->state.placed = 0;
+     }
+   else
+     {
+	EwinResize(ewin, ewin->client.w, ewin->client.h);
+     }
 
    doslide = manplace = 0;
    if (Mode.place.enable_features > 0)
@@ -898,6 +917,8 @@ AddToFamily(EWin * ewin, Window xwin)
      }
    else if (doslide)
      {
+	Timer              *slide_timer;
+
 	k = rand() % 4;
 	if (k == 0)
 	  {
@@ -927,7 +948,7 @@ AddToFamily(EWin * ewin, Window xwin)
 	EwinShow(ewin);
 	ewin->req_x = x;
 	ewin->req_y = y;
-	DoIn("Slide", 0.05, EwinSlideIn, 0, ewin);
+	TIMER_ADD(slide_timer, 0.05, EwinSlideIn, ewin);
      }
    else
      {
@@ -951,7 +972,9 @@ AddInternalToFamily(Win win, const char *bname, int type,
    if (!ewin)
       goto done;
 
+   ewin->props.donthide = 1;
    EwinGetAttributes(ewin, win, None);
+   WindowMatchEwinOps(ewin);	/* Window matches */
    EwinManage(ewin);
 
    ewin->data = ptr;
@@ -1252,8 +1275,7 @@ EwinEventConfigureRequest(EWin * ewin, XEvent * ev)
 	if (ev->xconfigurerequest.value_mask & (CWX | CWY))
 	  {
 	     /* Correct position taking gravity into account */
-	     EwinGetPosition(ewin, x, y, ewin->client.bw, ewin->client.grav,
-			     &x, &y);
+	     EwinGetPosition(ewin, x, y, 0, &x, &y);
 	  }
 
 	Mode.move.check = 0;	/* Don't restrict client requests */
@@ -1471,15 +1493,15 @@ EwinHide(EWin * ewin)
    if (!EwinIsInternal(ewin) || ewin->state.iconified)
       return;
 
-   if (ewin->ops && ewin->ops->Close)
-      ewin->ops->Close(ewin);
-
    if (EwinGetClientWin(ewin))
      {
 	ESelectInput(EwinGetClientWin(ewin), NoEventMask);
 	XShapeSelectInput(disp, EwinGetClientXwin(ewin), NoEventMask);
      }
 
+   if (ewin->ops && ewin->ops->Close)
+      ewin->ops->Close(ewin);
+
    EwinDestroy(ewin);
 }
 
@@ -1888,8 +1910,8 @@ EwinUpdateOpacity(EWin * ewin)
 /*
  * Slidein
  */
-static void
-EwinSlideIn(int val __UNUSED__, void *data)
+static int
+EwinSlideIn(void *data)
 {
    EWin               *ewin = (EWin *) data;
 
@@ -1903,6 +1925,8 @@ EwinSlideIn(int val __UNUSED__, void *data)
  done:
    Mode.place.doing_slide = 0;
    FocusEnable(1);
+
+   return 0;
 }
 
 /*
