@@ -69,13 +69,11 @@ struct _ewin {
 
    const Border       *border;
    const Border       *normal_border;
-   const Border       *previous_border;
    EWinBit            *bits;
 
    struct {
       Win                 win;
       int                 x, y, w, h, bw;
-      int                 grav;
       Colormap            cmap;
       long                event_mask;
    } client;
@@ -110,6 +108,7 @@ struct _ewin {
 
       /* Derived state flags. Change only in EwinStateUpdate() */
       unsigned            no_border:1;
+      unsigned            donthide:1;	/* Don't hide on show desktop */
 
       unsigned            inhibit_move:1;
       unsigned            inhibit_resize:1;
@@ -137,6 +136,7 @@ struct _ewin {
       unsigned            skip_winlist:1;
       unsigned            focusclick:1;	/* Click to focus */
       unsigned            no_button_grabs:1;
+      unsigned            no_argb:1;	/* Do not use ARGB frame */
 
       /* Derived from other properties */
       unsigned            no_border:1;	/* Never apply border (MWM/netwm type) */
@@ -345,12 +345,11 @@ void                EwinHide(EWin * ewin);
 void                EwinKill(EWin * ewin);
 void                DetermineEwinFloat(EWin * ewin, int dx, int dy);
 EWin               *GetEwinPointerInClient(void);
-EWin               *GetEwinByCurrentPointer(void);
 EWin               *GetFocusEwin(void);
 EWin               *GetContextEwin(void);
 void                SetContextEwin(EWin * ewin);
-void                EwinGetPosition(const EWin * ewin, int x, int y, int bw,
-				    int grav, int *px, int *py);
+void                EwinGetPosition(const EWin * ewin, int x, int y, int grav,
+				    int *px, int *py);
 void                EwinUpdateShapeInfo(EWin * ewin);
 void                EwinPropagateShapes(EWin * ewin);
 void                EwinStateUpdate(EWin * ewin);
@@ -401,14 +400,13 @@ void                EwinMoveResizeWithGravity(EWin * ewin, int x, int y, int w,
 void                EwinMoveToDesktop(EWin * ewin, Desk * d);
 void                EwinMoveToDesktopAt(EWin * ewin, Desk * d, int x, int y);
 void                EwinIconify(EWin * ewin);
+void                EwinAlone(EWin * ewin);
 void                EwinDeIconify(EWin * ewin);
 void                EwinInstantShade(EWin * ewin, int force);
 void                EwinInstantUnShade(EWin * ewin);
 void                EwinShade(EWin * ewin);
 void                EwinUnShade(EWin * ewin);
 void                EwinMoveToArea(EWin * ewin, int ax, int ay);
-void                EwinMoveToLinearArea(EWin * ewin, int a);
-void                EwinMoveLinearAreaBy(EWin * ewin, int a);
 
 void                EwinOpMove(EWin * ewin, int source, int x, int y);
 void                EwinOpResize(EWin * ewin, int source, int w, int h);
@@ -439,7 +437,6 @@ void                EwinOpFullscreen(EWin * ewin, int source, int on);
 
 /* finders.c */
 EWin               *EwinFindByPtr(const EWin * ewin);
-EWin               *EwinFindByFrame(Window win);
 EWin               *EwinFindByClient(Window win);
 EWin               *EwinFindByChildren(Window win);
 EWin              **EwinsFindByExpr(const char *match, int *pnum, int *pflags);
@@ -461,9 +458,8 @@ void                ActionsHandleMotion(void);
 int                 ActionsEnd(EWin * ewin);
 
 /* size.c */
-void                MaxSize(EWin * ewin, const char *resize_type);
-void                MaxWidth(EWin * ewin, const char *resize_type);
-void                MaxHeight(EWin * ewin, const char *resize_type);
+void                MaxSizeHV(EWin * ewin, const char *resize_type,
+			      int hor, int ver);
 
 /* stacking.c */
 EWin               *const *EwinListStackGet(int *num);
