@@ -936,8 +936,7 @@ EWMH_ProcessClientClientMessage(EWin * ewin, XClientMessageEvent * ev)
 	else if (atom == ECORE_X_ATOM_NET_WM_STATE_MAXIMIZED_VERT ||
 		 atom == ECORE_X_ATOM_NET_WM_STATE_MAXIMIZED_HORZ)
 	  {
-	     void                (*func) (EWin *, const char *);
-	     unsigned int        maxh, maxv;
+	     int                 maxh, maxv;
 
 	     maxh = ewin->state.maximized_horz;
 	     maxv = ewin->state.maximized_vert;
@@ -945,25 +944,22 @@ EWMH_ProcessClientClientMessage(EWin * ewin, XClientMessageEvent * ev)
 		 atom2 == ECORE_X_ATOM_NET_WM_STATE_MAXIMIZED_HORZ)
 	       {
 		  /* (ok - ok) */
-		  func = MaxSize;
 		  maxh = do_set(maxh, action);
 		  maxv = do_set(maxv, action);
 	       }
 	     else if (atom == ECORE_X_ATOM_NET_WM_STATE_MAXIMIZED_VERT)
 	       {
-		  func = MaxHeight;
 		  maxv = do_set(maxv, action);
 	       }
 	     else
 	       {
-		  func = MaxWidth;
 		  maxh = do_set(maxh, action);
 	       }
 
 	     if ((ewin->state.maximized_horz != maxh) ||
 		 (ewin->state.maximized_vert != maxv))
 	       {
-		  func(ewin, "available");
+		  MaxSizeHV(ewin, "available", maxh, maxv);
 		  EWMH_SetWindowState(ewin);
 	       }
 	  }
@@ -977,17 +973,29 @@ EWMH_ProcessClientClientMessage(EWin * ewin, XClientMessageEvent * ev)
 	  {
 	     action = do_set(EoGetLayer(ewin) >= 6, action);
 	     if (action)
-		EwinOpSetLayer(ewin, source, 6);
+	       {
+		  if (EoGetLayer(ewin) < 6)
+		     EwinOpSetLayer(ewin, source, 6);
+	       }
 	     else
-		EwinOpSetLayer(ewin, source, 4);
+	       {
+		  if (EoGetLayer(ewin) >= 6)
+		     EwinOpSetLayer(ewin, source, 4);
+	       }
 	  }
 	else if (atom == ECORE_X_ATOM_NET_WM_STATE_BELOW)
 	  {
 	     action = do_set(EoGetLayer(ewin) <= 2, action);
 	     if (action)
-		EwinOpSetLayer(ewin, source, 2);
+	       {
+		  if (EoGetLayer(ewin) > 2)
+		     EwinOpSetLayer(ewin, source, 2);
+	       }
 	     else
-		EwinOpSetLayer(ewin, source, 4);
+	       {
+		  if (EoGetLayer(ewin) <= 2)
+		     EwinOpSetLayer(ewin, source, 4);
+	       }
 	  }
 	else if (atom == ECORE_X_ATOM_NET_WM_STATE_DEMANDS_ATTENTION)
 	  {
@@ -1002,9 +1010,7 @@ EWMH_ProcessClientClientMessage(EWin * ewin, XClientMessageEvent * ev)
 	int                 flags, grav, x, y, w, h;
 
 	flags = ev->data.l[0];
-	grav = flags & 0xf;
-	if (grav == 0)
-	   grav = ewin->client.grav;
+	grav = flags & 0xf;	/* 0 means use client gravity */
 	x = (flags & 0x0100) ? ev->data.l[1] : EoGetX(ewin);
 	y = (flags & 0x0200) ? ev->data.l[2] : EoGetY(ewin);
 	w = (flags & 0x0400) ? ev->data.l[3] : ewin->client.w;
