@@ -25,6 +25,7 @@
 #include "borders.h"
 #include "ewins.h"
 #include "groups.h"
+#include "util.h"
 #include <ctype.h>
 #include <string.h>
 
@@ -43,23 +44,6 @@ EwinFindByPtr(const EWin * ewin)
    return NULL;
 }
 
-#if 0				/* Remove? */
-EWin               *
-EwinFindByFrame(Window win)
-{
-   EWin               *const *ewins;
-   int                 i, num;
-
-   ewins = EwinListGetAll(&num);
-   for (i = 0; i < num; i++)
-     {
-	if (win == EoGetXwin(ewins[i]))
-	   return ewins[i];
-     }
-   return NULL;
-}
-#endif
-
 EWin               *
 EwinFindByClient(Window win)
 {
@@ -190,7 +174,7 @@ EwinsFindByExpr(const char *match, int *pnum, int *pflags)
 	     name = EwinGetIcccmName(ewin);
 	     if (!name)
 		continue;
-	     if (!strcasestr(name, match))
+	     if (!Estrcasestr(name, match))
 		continue;
 	  }
 	nfound++;
