@@ -35,7 +35,6 @@
 #include "xwin.h"
 
 #define EwinListFocusRaise(ewin) EobjListFocusRaise(EoObj(ewin))
-#define EwinListFocusLower(ewin) EobjListFocusLower(EoObj(ewin))
 
 static char         focus_inhibit = 1;
 static char         focus_is_set = 0;
@@ -43,6 +42,8 @@ static char         click_pending_update_grabs = 0;
 static int          focus_pending_why = 0;
 static EWin        *focus_pending_ewin = NULL;
 static EWin        *focus_pending_new = NULL;
+static EWin        *focus_pending_raise = NULL;
+static Timer       *focus_timer_autoraise = NULL;
 
 void
 FocusEnable(int on)
@@ -136,75 +137,72 @@ FocusEwinSelect(void)
    return ewin;
 }
 
-static void
-AutoraiseTimeout(int val, void *data __UNUSED__)
+static int
+AutoraiseTimeout(void *data)
 {
-   EWin               *ewin;
+   EWin               *ewin = (EWin *) data;
 
    if (Conf.focus.mode == MODE_FOCUS_CLICK)
-      return;
+      goto done;
 
-   ewin = EwinFindByClient(val);
-   if (ewin)
+   if (EwinFindByPtr(ewin))	/* May be gone */
       EwinRaise(ewin);
+
+ done:
+   focus_timer_autoraise = NULL;
+   return 0;
 }
 
 static void
-ReverseTimeout(int val, void *data __UNUSED__)
+FocusRaisePending(void)
 {
-   EWin               *ewin;
+   EWin               *ewin = focus_pending_raise;
+   unsigned int        mask;
 
-   ewin = EwinFindByClient(val);
-   if (ewin)
+   /* The focusing cycle ends when no more modifiers are depressed */
+   mask = 0;
+   EQueryPointer(NULL, NULL, NULL, NULL, &mask);
+   if ((mask & Mode.masks.mod_key_mask) != 0)
+      return;
+
+   if (EwinFindByPtr(ewin))	/* May be gone */
       EwinListFocusRaise(ewin);
+
+   GrabKeyboardRelease();
+
+   focus_pending_raise = NULL;
 }
 
+/*
+ * dir > 0: Focus previously focused window
+ * else   : Focus least recently focused window
+ */
 static void
-FocusGetNextEwin(void)
+FocusCycleEwin(int dir)
 {
    EWin               *const *lst;
    EWin               *ewin;
-   int                 i, num;
+   int                 i, j, num;
 
    lst = EwinListFocusGet(&num);
    if (num <= 1)
       return;
 
-   ewin = NULL;
-   for (i = num - 1; i >= 0; i--)
+   dir = (dir > 0) ? 1 : -1;
+
+   for (j = 0; j < num; j++)
      {
-	if (!FocusEwinValid(lst[i], 1, 0, 0) || lst[i]->props.skip_focuslist)
-	   continue;
-	ewin = lst[i];
-	break;
+	if (lst[j] == Mode.focuswin)
+	   break;
      }
-
-   if (ewin)
-      FocusToEWin(ewin, FOCUS_NEXT);
-}
-
-static void
-FocusGetPrevEwin(void)
-{
-   EWin               *const *lst;
-   EWin               *ewin;
-   int                 i, num;
-
-   lst = EwinListFocusGet(&num);
-   if (num <= 1)
-      return;
-
-   ewin = NULL;
    for (i = 1; i < num; i++)
      {
-	if (!FocusEwinValid(lst[i], 1, 0, 0) || lst[i]->props.skip_focuslist)
+	ewin = lst[(j + i * dir + num) % num];
+	if (!FocusEwinValid(ewin, 1, 0, 0) || ewin->props.skip_focuslist)
 	   continue;
-	ewin = lst[i];
+	FocusToEWin(ewin, FOCUS_PREV);
 	break;
      }
-
-   if (ewin)
-      FocusToEWin(ewin, FOCUS_PREV);
 }
 
 static void
@@ -213,7 +211,7 @@ ClickGrabsSet(EWin * ewin)
    int                 set = 0;
 
    if ((Conf.focus.clickraises && !EwinListStackIsRaised(ewin)) ||
-       (!ewin->state.active && FocusEwinValid(ewin, 0, 1, 0)))
+       (!ewin->state.active && !ewin->state.inhibit_focus))
       set = 1;
 
    if (set)
@@ -387,11 +385,11 @@ doFocusToEwin(EWin * ewin, int why)
 
    if (Conf.autoraise.enable)
      {
-	RemoveTimerEvent("AUTORAISE_TIMEOUT");
+	TIMER_DEL(focus_timer_autoraise);
 
 	if (Conf.focus.mode != MODE_FOCUS_CLICK)
-	   DoIn("AUTORAISE_TIMEOUT", 0.001 * Conf.autoraise.delay,
-		AutoraiseTimeout, EwinGetClientXwin(ewin), NULL);
+	   TIMER_ADD(focus_timer_autoraise, 0.001 * Conf.autoraise.delay,
+		     AutoraiseTimeout, ewin);
      }
 
    if (do_raise)
@@ -402,24 +400,23 @@ doFocusToEwin(EWin * ewin, int why)
    if (do_warp)
       EwinWarpTo(ewin);
 
-   RemoveTimerEvent("REVERSE_FOCUS_TIMEOUT");
    switch (why)
      {
      case FOCUS_PREV:
-	DoIn("REVERSE_FOCUS_TIMEOUT", 0.5, ReverseTimeout,
-	     EwinGetClientXwin(ewin), NULL);
+     case FOCUS_NEXT:
+	GrabKeyboardSet(VROOT);	/* Causes idler to be called on KeyRelease */
+	focus_pending_raise = ewin;
 	break;
      case FOCUS_DESK_ENTER:
 	if (Conf.focus.mode == MODE_FOCUS_CLICK)
 	   break;
      default:
      case FOCUS_INIT:
-     case FOCUS_NEXT:
 	EwinListFocusRaise(ewin);
 	break;
      }
 
-   SoundPlay("SOUND_FOCUS_SET");
+   SoundPlay(SOUND_FOCUS_SET);
  done:
 
    ClickGrabsUpdate();
@@ -514,11 +511,6 @@ FocusNewDeskBegin(void)
 void
 FocusNewDesk(void)
 {
-#if 0				/* Remove? */
-   /* Set the mouse-over window */
-   Mode.mouse_over_ewin = GetEwinByCurrentPointer();
-#endif
-
    FocusToEWin(NULL, FOCUS_DESK_ENTER);
 
    /* Unfreeze keyboard */
@@ -531,13 +523,6 @@ FocusInit(void)
    /* Start focusing windows */
    FocusEnable(1);
 
-#if 0				/* Remove? */
-   /* Set the mouse-over window */
-   Mode.mouse_over_ewin = GetEwinByCurrentPointer();
-#endif
-
-   focus_pending_why = 0;
-   focus_pending_ewin = focus_pending_new = NULL;
    FocusToEWin(NULL, FOCUS_INIT);
    FocusSet();
 
@@ -853,7 +838,7 @@ const DialogDef     DlgFocus = {
    "CONFIGURE_FOCUS",
    N_("Focus"),
    N_("Focus Settings"),
-   "SOUND_SETTINGS_FOCUS",
+   SOUND_SETTINGS_FOCUS,
    "pix/focus.png",
    N_("Enlightenment Focus\n" "Settings Dialog\n"),
    _DlgFillFocus,
@@ -864,10 +849,11 @@ const DialogDef     DlgFocus = {
  * Focus Module
  */
 
-static void
-FocusInitTimeout(int val __UNUSED__, void *data __UNUSED__)
+static int
+FocusInitTimeout(void *data __UNUSED__)
 {
    FocusInit();
+   return 0;
 }
 
 static void
@@ -877,17 +863,21 @@ _FocusIdler(void *data __UNUSED__)
       FocusSet();
    if (click_pending_update_grabs)
       doClickGrabsUpdate();
+   if (focus_pending_raise)
+      FocusRaisePending();
 }
 
 static void
 FocusSighan(int sig, void *prm __UNUSED__)
 {
+   Timer              *focus_init_timer;
+
    switch (sig)
      {
      case ESIGNAL_START:
 	/* Delay focusing a bit to allow things to settle down */
-	IdlerAdd(50, _FocusIdler, NULL);
-	DoIn("FOCUS_INIT_TIMEOUT", 0.5, FocusInitTimeout, 0, NULL);
+	IdlerAdd(_FocusIdler, NULL);
+	TIMER_ADD(focus_init_timer, 0.5, FocusInitTimeout, NULL);
 	break;
 
      case ESIGNAL_EXIT:
@@ -922,10 +912,6 @@ FocusIpc(const char *params)
 	else
 	   IpcPrintf("Focused: none\n");
      }
-   else if (!strcmp(cmd, "cfg"))
-     {
-	DialogShowSimple(&DlgFocus, NULL);
-     }
    else if (!strncmp(cmd, "mode", 2))
      {
 	int                 mode = Conf.focus.mode;
@@ -978,17 +964,19 @@ FocusIpc(const char *params)
      }
    else if (!strncmp(cmd, "next", 2))
      {
+	/* Focus previously focused window */
 	if (Conf.warplist.enable)
 	   WarpFocus(1);
 	else
-	   FocusGetNextEwin();
+	   FocusCycleEwin(1);
      }
    else if (!strncmp(cmd, "prev", 2))
      {
+	/* Focus least recently focused window */
 	if (Conf.warplist.enable)
 	   WarpFocus(-1);
 	else
-	   FocusGetPrevEwin();
+	   FocusCycleEwin(-1);
      }
 }
 
