@@ -23,6 +23,7 @@
 #include "E.h"
 #include "desktops.h"
 #include "dialog.h"
+#include "ecompmgr.h"
 #include "eimage.h"
 #include "emodule.h"
 #include "settings.h"
@@ -30,6 +31,9 @@
 #include "xwin.h"
 #include <math.h>
 
+#define E_FX_RAINDROPS          0
+#define E_FX_IMAGESPINNER       0
+
 /* FIXME - Needs cleaning up */
 
 #ifndef M_PI_2
@@ -50,25 +54,36 @@ typedef struct {
    char                paused;
 } FXHandler;
 
+#if USE_COMPOSITE
+/* As of composite 0.4 we need to set the clip region */
+#define SET_GC_CLIP(eo, gc) ECompMgrWinClipToGC(eo, gc)
+#else
+#define SET_GC_CLIP(eo, gc)
+#endif
+
 /****************************** RIPPLES *************************************/
 
 #define fx_ripple_waterh 64
 static Pixmap       fx_ripple_above = None;
 static Win          fx_ripple_win = NULL;
 static int          fx_ripple_count = 0;
+static Timer       *fx_ripple_timer = NULL;
 
-static void
-FX_ripple_timeout(int val __UNUSED__, void *data __UNUSED__)
+static int
+FX_ripple_timeout(void *data __UNUSED__)
 {
    static double       incv = 0, inch = 0;
    static GC           gc1 = 0, gc = 0;
    int                 y;
+   EObj               *bgeo;
+
+   bgeo = DeskGetBackgroundObj(DesksGetCurrent());
 
    if (fx_ripple_above == None)
      {
 	XGCValues           gcv;
 
-	fx_ripple_win = DeskGetBackgroundWin(DesksGetCurrent());
+	fx_ripple_win = EobjGetWin(bgeo);
 
 	fx_ripple_above =
 	   ECreatePixmap(fx_ripple_win, WinGetW(VROOT),
@@ -83,23 +98,23 @@ FX_ripple_timeout(int val __UNUSED__, void *data __UNUSED__)
      }
 
    if (fx_ripple_count == 0)
-      XCopyArea(disp, EoGetXwin(DesksGetCurrent()), fx_ripple_above, gc, 0,
+      XCopyArea(disp, WinGetXwin(fx_ripple_win), fx_ripple_above, gc, 0,
 		WinGetH(VROOT) - (fx_ripple_waterh * 3), WinGetW(VROOT),
 		fx_ripple_waterh * 2, 0, 0);
 
    fx_ripple_count++;
    if (fx_ripple_count > 32)
       fx_ripple_count = 0;
+
    incv += 0.40;
    if (incv > (M_PI_2 * 4))
-     {
-	incv = 0;
-     }
+      incv = 0;
    inch += 0.32;
    if (inch > (M_PI_2 * 4))
-     {
-	inch = 0;
-     }
+      inch = 0;
+
+   SET_GC_CLIP(bgeo, gc1);
+
    for (y = 0; y < fx_ripple_waterh; y++)
      {
 	double              aa, a, p;
@@ -115,14 +130,15 @@ FX_ripple_timeout(int val __UNUSED__, void *data __UNUSED__)
 		  WinGetW(VROOT), 1, off,
 		  WinGetH(VROOT) - fx_ripple_waterh + y);
      }
-   DoIn("FX_RIPPLE_TIMEOUT", 0.066, FX_ripple_timeout, 0, NULL);
+
+   return 1;
 }
 
 static void
 FX_Ripple_Init(const char *name __UNUSED__)
 {
    fx_ripple_count = 0;
-   DoIn("FX_RIPPLE_TIMEOUT", 0.066, FX_ripple_timeout, 0, NULL);
+   TIMER_ADD(fx_ripple_timer, 0.066, FX_ripple_timeout, NULL);
 }
 
 static void
@@ -137,7 +153,7 @@ FX_Ripple_Desk(void)
 static void
 FX_Ripple_Quit(void)
 {
-   RemoveTimerEvent("FX_RIPPLE_TIMEOUT");
+   TIMER_DEL(fx_ripple_timer);
    EClearArea(fx_ripple_win, 0, WinGetH(VROOT) - fx_ripple_waterh,
 	      WinGetW(VROOT), fx_ripple_waterh);
 }
@@ -159,7 +175,8 @@ FX_Ripple_Pause(void)
      }
 }
 
-#ifdef E_FX_RAINDROPS		/* FIXME - Requires eliminating use of PixImg */
+#if E_FX_RAINDROPS
+#include "piximg.h"
 
 /****************************** RAIN DROPS **********************************/
 
@@ -168,9 +185,10 @@ FX_Ripple_Pause(void)
 #define fx_raindrop_duration 32
 #define fx_frequency 4
 #define fx_amplitude 48
-static Window       fx_raindrops_win = None;
+static Win          fx_raindrops_win = NULL;
 static int          fx_raindrops_number = 4;
 static PixImg      *fx_raindrops_draw = NULL;
+static Timer       *fx_raindrops_timer = NULL;
 
 typedef struct {
    int                 x, y;
@@ -180,8 +198,8 @@ typedef struct {
 
 static DropContext  fx_raindrops[4];
 
-static void
-FX_raindrops_timeout(int val __UNUSED__, void *data __UNUSED__)
+static int
+FX_raindrops_timeout(void *data __UNUSED__)
 {
    static GC           gc1 = 0, gc = 0;
    int                 i, x, y, xx, yy;
@@ -189,6 +207,9 @@ FX_raindrops_timeout(int val __UNUSED__, void *data __UNUSED__)
    static char         first = 1;
    static char         sintab[256];
    static unsigned char disttab[fx_raindrop_size][fx_raindrop_size];
+   EObj               *bgeo;
+
+   bgeo = DeskGetBackgroundObj(DesksGetCurrent());
 
    if (fx_raindrops_win == None)
      {
@@ -214,7 +235,7 @@ FX_raindrops_timeout(int val __UNUSED__, void *data __UNUSED__)
 	       }
 	  }
 
-	fx_raindrops_win = DeskGetBackgroundWin(DesksGetCurrent());
+	fx_raindrops_win = EobjGetWin(bgeo);
 
 	if (gc)
 	   EXFreeGC(gc);
@@ -222,28 +243,31 @@ FX_raindrops_timeout(int val __UNUSED__, void *data __UNUSED__)
 	   EXFreeGC(gc1);
 
 	gcv.subwindow_mode = IncludeInferiors;
-	gc = EXCreateGC(fx_raindrops_win, GCSubwindowMode, &gcv);
-	gc1 = EXCreateGC(fx_raindrops_win, 0L, &gcv);
+	gc = EXCreateGC(WinGetXwin(fx_raindrops_win), GCSubwindowMode, &gcv);
+	gc1 = EXCreateGC(WinGetXwin(fx_raindrops_win), 0L, &gcv);
 
 	fx_raindrops_draw =
-	   ECreatePixImg(fx_raindrops_win, fx_raindrop_size, fx_raindrop_size);
-
+	   ECreatePixImg(WinGetXwin(fx_raindrops_win), fx_raindrop_size,
+			 fx_raindrop_size);
 	if (!fx_raindrops_draw)
-	   return;
+	   return 0;
 
 	for (i = 0; i < fx_raindrops_number; i++)
 	  {
 	     fx_raindrops[i].buf =
-		ECreatePixImg(fx_raindrops_win, fx_raindrop_size,
+		ECreatePixImg(WinGetXwin(fx_raindrops_win), fx_raindrop_size,
 			      fx_raindrop_size);
 	     if (fx_raindrops[i].buf)
-		XShmGetImage(disp, fx_raindrops_win, fx_raindrops[i].buf->xim,
-			     fx_raindrops[i].x, fx_raindrops[i].y, 0xffffffff);
+		XShmGetImage(disp, WinGetXwin(fx_raindrops_win),
+			     fx_raindrops[i].buf->xim, fx_raindrops[i].x,
+			     fx_raindrops[i].y, 0xffffffff);
 	     if (!fx_raindrops[i].buf)
-		return;
+		return 0;
 	  }
      }
 
+   SET_GC_CLIP(bgeo, gc1);
+
    for (i = 0; i < fx_raindrops_number; i++)
      {
 	fx_raindrops[i].count++;
@@ -252,9 +276,8 @@ FX_raindrops_timeout(int val __UNUSED__, void *data __UNUSED__)
 	     int                 j, count = 0;
 	     char                intersect = 1;
 
-	     XClearArea(disp, fx_raindrops_win, fx_raindrops[i].x,
-			fx_raindrops[i].y, fx_raindrop_size, fx_raindrop_size,
-			False);
+	     EClearArea(fx_raindrops_win, fx_raindrops[i].x,
+			fx_raindrops[i].y, fx_raindrop_size, fx_raindrop_size);
 	     fx_raindrops[i].count = 0;
 	     while (intersect)
 	       {
@@ -314,7 +337,8 @@ FX_raindrops_timeout(int val __UNUSED__, void *data __UNUSED__)
 			 }
 		    }
 	       }
-	     XShmGetImage(disp, fx_raindrops_win, fx_raindrops[i].buf->xim,
+	     XShmGetImage(disp, WinGetXwin(fx_raindrops_win),
+			  fx_raindrops[i].buf->xim,
 			  fx_raindrops[i].x, fx_raindrops[i].y, 0xffffffff);
 	  }
 	percent_done =
@@ -368,14 +392,14 @@ FX_raindrops_timeout(int val __UNUSED__, void *data __UNUSED__)
 		    }
 	       }
 	  }
-	XShmPutImage(disp, fx_raindrops_win, gc1, fx_raindrops_draw->xim, 0, 0,
+	XShmPutImage(disp, WinGetXwin(fx_raindrops_win), gc1,
+		     fx_raindrops_draw->xim, 0, 0,
 		     fx_raindrops[i].x, fx_raindrops[i].y, fx_raindrop_size,
 		     fx_raindrop_size, False);
-	ESync();
+	ESync(0);
      }
 
-   DoIn("FX_RAINDROPS_TIMEOUT", (0.066 /*/ (float)fx_raindrops_number */ ),
-	FX_raindrops_timeout, 0, NULL);
+   return 1;
 }
 
 static void
@@ -390,7 +414,7 @@ FX_Raindrops_Init(const char *name __UNUSED__)
 	fx_raindrops[i].x = rand() % (WinGetW(VROOT) - fx_raindrop_size);
 	fx_raindrops[i].y = rand() % (WinGetH(VROOT) - fx_raindrop_size);
      }
-   DoIn("FX_RAINDROPS_TIMEOUT", 0.066, FX_raindrops_timeout, 0, NULL);
+   TIMER_ADD(fx_raindrops_timer, 0.066, FX_raindrops_timeout, NULL);
 }
 
 static void
@@ -404,11 +428,11 @@ FX_Raindrops_Quit(void)
 {
    int                 i;
 
-   RemoveTimerEvent("FX_RAINDROPS_TIMEOUT");
+   TIMER_DEL(fx_raindrops_timer);
    for (i = 0; i < fx_raindrops_number; i++)
      {
-	XClearArea(disp, fx_raindrops_win, fx_raindrops[i].x, fx_raindrops[i].y,
-		   fx_raindrop_size, fx_raindrop_size, False);
+	EClearArea(fx_raindrops_win, fx_raindrops[i].x, fx_raindrops[i].y,
+		   fx_raindrop_size, fx_raindrop_size);
 	if (fx_raindrops[i].buf)
 	   EDestroyPixImg(fx_raindrops[i].buf);
 	fx_raindrops[i].buf = NULL;
@@ -450,9 +474,10 @@ FX_Raindrops_Pause(void)
 static Pixmap       fx_wave_above = None;
 static Win          fx_wave_win = NULL;
 static int          fx_wave_count = 0;
+static Timer       *fx_wave_timer = NULL;
 
-static void
-FX_Wave_timeout(int val __UNUSED__, void *data __UNUSED__)
+static int
+FX_Wave_timeout(void *data __UNUSED__)
 {
    /* Variables */
    static double       incv = 0, inch = 0;
@@ -460,13 +485,16 @@ FX_Wave_timeout(int val __UNUSED__, void *data __UNUSED__)
    double              incx2;
    static GC           gc1 = 0, gc = 0;
    int                 y;
+   EObj               *bgeo;
+
+   bgeo = DeskGetBackgroundObj(DesksGetCurrent());
 
    /* Check to see if we need to create stuff */
    if (!fx_wave_above)
      {
 	XGCValues           gcv;
 
-	fx_wave_win = DeskGetBackgroundWin(DesksGetCurrent());
+	fx_wave_win = EobjGetWin(bgeo);
 
 	fx_wave_above =
 	   ECreatePixmap(fx_wave_win, WinGetW(VROOT), FX_WAVE_WATERH * 2, 0);
@@ -482,7 +510,7 @@ FX_Wave_timeout(int val __UNUSED__, void *data __UNUSED__)
    /* On the zero, grab the desktop again. */
    if (fx_wave_count == 0)
      {
-	XCopyArea(disp, EoGetXwin(DesksGetCurrent()), fx_wave_above, gc, 0,
+	XCopyArea(disp, WinGetXwin(fx_wave_win), fx_wave_above, gc, 0,
 		  WinGetH(VROOT) - (FX_WAVE_WATERH * 3), WinGetW(VROOT),
 		  FX_WAVE_WATERH * 2, 0, 0);
      }
@@ -505,6 +533,8 @@ FX_Wave_timeout(int val __UNUSED__, void *data __UNUSED__)
    if (incx > (M_PI_2 * 4))
       incx = 0;
 
+   SET_GC_CLIP(bgeo, gc1);
+
    /* Copy the area to correct bugs */
    if (fx_wave_count == 0)
      {
@@ -555,15 +585,14 @@ FX_Wave_timeout(int val __UNUSED__, void *data __UNUSED__)
 	  }
      }
 
-   /* Make noise */
-   DoIn("FX_WAVE_TIMEOUT", 0.066, FX_Wave_timeout, 0, NULL);
+   return 1;
 }
 
 static void
 FX_Waves_Init(const char *name __UNUSED__)
 {
    fx_wave_count = 0;
-   DoIn("FX_WAVE_TIMEOUT", 0.066, FX_Wave_timeout, 0, NULL);
+   TIMER_ADD(fx_wave_timer, 0.066, FX_Wave_timeout, NULL);
 }
 
 static void
@@ -577,7 +606,7 @@ FX_Waves_Desk(void)
 static void
 FX_Waves_Quit(void)
 {
-   RemoveTimerEvent("FX_WAVE_TIMEOUT");
+   TIMER_DEL(fx_wave_timer);
    EClearArea(fx_wave_win, 0, WinGetH(VROOT) - FX_WAVE_WATERH,
 	      WinGetW(VROOT), FX_WAVE_WATERH);
 }
@@ -599,22 +628,25 @@ FX_Waves_Pause(void)
      }
 }
 
-#ifdef E_FX_IMAGESPINNER
+#if E_FX_IMAGESPINNER
 
 /****************************** IMAGESPINNER ********************************/
 
-static Window       fx_imagespinner_win = None;
+static Win          fx_imagespinner_win = NULL;
 static int          fx_imagespinner_count = 3;
 static char        *fx_imagespinner_params = NULL;
+static Timer       *fx_imagespinner_timer = NULL;
 
-static void
-FX_imagespinner_timeout(int val __UNUSED__, void *data __UNUSED__)
+static int
+FX_imagespinner_timeout(void *data __UNUSED__)
 {
    char               *string = NULL;
+   EObj               *bgeo;
 
    if (fx_imagespinner_win == None)
      {
-	fx_imagespinner_win = DeskGetBackgroundWin(DesksGetCurrent());
+	bgeo = DeskGetBackgroundObj(DesksGetCurrent());
+	fx_imagespinner_win = EobjGetWin(bgeo);
      }
 
 #if 0				/* Don't use getword */
@@ -641,35 +673,38 @@ FX_imagespinner_timeout(int val __UNUSED__, void *data __UNUSED__)
 	     sscanf(fx_imagespinner_params, "%*s %i %i ", &x, &y);
 	     x = ((WinGetW(VROOT) * x) >> 10) - ((w * x) >> 10);
 	     y = ((WinGetH(VROOT) * y) >> 10) - ((h * y) >> 10);
-	     EImageRenderOnDrawable(im, fx_imagespinner_win, 0, x, y, w, h);
+	     EImageRenderOnDrawable(im, fx_imagespinner_win, None, 0,
+				    x, y, w, h);
 	     EImageFree(im);
 	  }
 	Efree(string);
      }
 
-   DoIn("FX_IMAGESPINNER_TIMEOUT", 0.066, FX_imagespinner_timeout, 0, NULL);
+   return 1;
 }
 
 static void
 FX_ImageSpinner_Init(const char *name)
 {
    fx_imagespinner_count = 3;
-   DoIn("FX_IMAGESPINNER_TIMEOUT", 0.066, FX_imagespinner_timeout, 0, NULL);
+   TIMER_ADD(fx_imagespinner_timer, 0.066, FX_imagespinner_timeout, NULL);
    fx_imagespinner_params = Estrdup(name);
 }
 
 static void
 FX_ImageSpinner_Desk(void)
 {
-   fx_imagespinner_win = DeskGetBackgroundWin(DesksGetCurrent());
+   EObj               *bgeo;
+
+   bgeo = DeskGetBackgroundObj(DesksGetCurrent());
+   fx_imagespinner_win = EobjGetWin(bgeo);
 }
 
 static void
 FX_ImageSpinner_Quit(void)
 {
-   RemoveTimerEvent("FX_IMAGESPINNER_TIMEOUT");
-   XClearArea(disp, fx_imagespinner_win, 0, 0, WinGetW(VROOT),
-	      WinGetH(VROOT), False);
+   TIMER_DEL(fx_imagespinner_timer);
+   EClearArea(fx_imagespinner_win, 0, 0, WinGetW(VROOT), WinGetH(VROOT));
    Efree(fx_imagespinner_params);
    fx_imagespinner_params = NULL;
    fx_imagespinner_win = None;
@@ -703,13 +738,13 @@ static FXHandler    fx_handlers[] = {
    {"waves",
     FX_Waves_Init, FX_Waves_Desk, FX_Waves_Quit, FX_Waves_Pause,
     0, 0},
-#ifdef E_FX_RAINDROPS		/* FIXME */
+#if E_FX_RAINDROPS		/* FIXME */
    {"raindrops",
     FX_Raindrops_Init, FX_Raindrops_Desk, FX_Raindrops_Quit,
     FX_Raindrops_Pause,
     0, 0},
 #endif
-#ifdef E_FX_IMAGESPINNER
+#if E_FX_IMAGESPINNER
    {"imagespinner",
     FX_ImageSpinner_Init, FX_ImageSpinner_Desk, FX_ImageSpinner_Quit,
     FX_ImageSpinner_Pause,
@@ -914,7 +949,7 @@ const DialogDef     DlgFx = {
    "CONFIGURE_FX",
    N_("FX"),
    N_("Special FX Settings"),
-   "SOUND_SETTINGS_FX",
+   SOUND_SETTINGS_FX,
    "pix/fx.png",
    N_("Enlightenment Special Effects\n" "Settings Dialog\n"),
    _DlgFillFx,
@@ -947,10 +982,6 @@ FxIpc(const char *params)
 	else
 	   IpcPrintf("Error: unknown mode specified");
      }
-   else if (!strncmp(word1, "cfg", 2))
-     {
-	DialogShowSimple(&DlgFx, NULL);
-     }
 }
 
 static const IpcItem FxIpcArray[] = {
@@ -958,7 +989,6 @@ static const IpcItem FxIpcArray[] = {
     FxIpc,
     "fx", "fx",
     "Toggle various effects on/off",
-    "  fx cfg               Configure effects\n"
     "  fx <effect> <mode>   Set the mode of a particular effect\n"
     "  fx <effect> ?\"      Get the current mode\n"
     "the following effects are available\n"
@@ -971,7 +1001,7 @@ static const IpcItem FxIpcArray[] = {
 static const CfgItem FxCfgItems[] = {
    CFR_ITEM_BOOL(fx_handlers[0].enabled, ripples.enabled, 0),
    CFR_ITEM_BOOL(fx_handlers[1].enabled, waves.enabled, 0),
-#ifdef E_FX_RAINDROPS		/* FIXME */
+#if E_FX_RAINDROPS		/* FIXME */
    CFR_ITEM_BOOL(fx_handlers[2].enabled, raindrops.enabled, 0),
 #endif
 };
