@@ -33,7 +33,14 @@
 #include "timers.h"
 #include <math.h>
 
-#define USE_GROUP_SHOWHIDE 0	/* Don't think this is useful. */
+#define DEBUG_GROUPS 0
+#if DEBUG_GROUPS
+#define Dprintf(fmt, ...) Eprintf("%s: " fmt, __func__, __VA_ARGS__)
+#else
+#define Dprintf(fmt...)
+#endif
+
+#define USE_GROUP_SHOWHIDE 1	/* Enable group borders */
 
 #define SET_OFF    0
 #define SET_ON     1
@@ -50,6 +57,7 @@ static struct {
    Group              *current;
 } Mode_groups;
 
+static void         AddEwinToGroup(EWin * ewin, Group * g);
 static void         RemoveEwinFromGroup(EWin * ewin, Group * g);
 
 int
@@ -59,12 +67,12 @@ GroupsGetSwapmove(void)
 }
 
 static Group       *
-GroupCreate(void)
+GroupCreate(int gid)
 {
    Group              *g;
    double              t;
 
-   g = EMALLOC(Group, 1);
+   g = ECALLOC(Group, 1);
    if (!g)
       return NULL;
 
@@ -72,10 +80,18 @@ GroupCreate(void)
       group_list = ecore_list_new();
    ecore_list_append(group_list, g);
 
-   t = GetTime();
-   g->index = (int)((GetTime() - (floor(t / 1000) * 1000)) * 10000);
-   /* g->index = (int)(GetTime() * 100); */
-
+   if (gid == -1)
+     {
+	/* Create new group id */
+	t = GetTime();
+	g->index = (int)((GetTime() - (floor(t / 1000) * 1000)) * 10000);
+	/* g->index = (int)(GetTime() * 100); */
+     }
+   else
+     {
+	/* Use given group id */
+	g->index = gid;
+     }
    g->cfg.iconify = Conf_groups.dflt.iconify;
    g->cfg.kill = Conf_groups.dflt.kill;
    g->cfg.move = Conf_groups.dflt.move;
@@ -84,9 +100,8 @@ GroupCreate(void)
    g->cfg.stick = Conf_groups.dflt.stick;
    g->cfg.shade = Conf_groups.dflt.shade;
    g->cfg.mirror = Conf_groups.dflt.mirror;
-   g->num_members = 0;
-   g->members = NULL;
 
+   Dprintf("grp=%p gid=%d\n", g, g->index);
    return g;
 }
 
@@ -96,6 +111,7 @@ GroupDestroy(Group * g)
    if (!g)
       return;
 
+   Dprintf("grp=%p gid=%d\n", g, g->index);
    ecore_list_node_remove(group_list, g);
 
    if (g == Mode_groups.current)
@@ -111,13 +127,25 @@ GroupMatchId(const void *data, const void *match)
    return ((const Group *)data)->index != (int)(long)match;
 }
 
-Group              *
+static Group       *
 GroupFind(int gid)
 {
    return (Group *) ecore_list_find(group_list, GroupMatchId,
 				    (void *)(long)gid);
 }
 
+void
+GroupRemember(int gid)
+{
+   Group              *g;
+
+   g = GroupFind(gid);
+   if (!g)
+      return;
+
+   g->save = 1;
+}
+
 static Group       *
 GroupFind2(const char *groupid)
 {
@@ -134,12 +162,6 @@ GroupFind2(const char *groupid)
    return GroupFind(gid);
 }
 
-void
-GroupSetId(Group * group, int gid)
-{
-   group->index = gid;
-}
-
 static void
 CopyGroupConfig(GroupConfig * src, GroupConfig * dest)
 {
@@ -152,41 +174,39 @@ CopyGroupConfig(GroupConfig * src, GroupConfig * dest)
 static void
 BreakWindowGroup(EWin * ewin, Group * g)
 {
-   int                 i, j, num;
+   int                 i, j;
    EWin               *ewin2;
+   Group              *g2;
 
-   if (ewin)
+   Dprintf("ewin=%p group=%p gid=%d\n", ewin, g, g->index);
+   if (!ewin || !ewin->groups)
+      return;
+
+   for (j = 0; j < ewin->num_groups; j++)
      {
-	if (ewin->groups)
+	g2 = ewin->groups[j];
+	if (g && g != g2)
+	   continue;
+
+	for (i = 0; i < g2->num_members; i++)
 	  {
-	     for (j = 0; j < ewin->num_groups; j++)
-		if (ewin->groups[j] == g)
-		  {
-		     num = g->num_members;
-		     for (i = 0; i < num; i++)
-		       {
-			  ewin2 = g->members[0];
-			  RemoveEwinFromGroup(g->members[0], g);
-			  SnapshotEwinUpdate(ewin2, SNAP_USE_GROUPS);
-		       }
-		     return;
-		  }
+	     ewin2 = g2->members[0];
+	     RemoveEwinFromGroup(ewin2, g2);
+	     SnapshotEwinUpdate(ewin2, SNAP_USE_GROUPS);
 	  }
      }
 }
 
-Group              *
-BuildWindowGroup(EWin ** ewins, int num)
+static void
+BuildWindowGroup(EWin ** ewins, int num, int gid)
 {
    int                 i;
    Group              *group;
 
-   Mode_groups.current = group = GroupCreate();
+   Mode_groups.current = group = GroupCreate(gid);
 
    for (i = 0; i < num; i++)
       AddEwinToGroup(ewins[i], group);
-
-   return group;
 }
 
 Group             **
@@ -195,7 +215,14 @@ GroupsGetList(int *pnum)
    return (Group **) ecore_list_items_get(group_list, pnum);
 }
 
-Group             **
+Group              *const *
+EwinGetGroups(const EWin * ewin, int *num)
+{
+   *num = ewin->num_groups;
+   return ewin->groups;
+}
+
+static Group      **
 ListWinGroups(const EWin * ewin, char group_select, int *num)
 {
    Group             **groups = NULL;
@@ -247,24 +274,55 @@ ListWinGroups(const EWin * ewin, char group_select, int *num)
    return groups;
 }
 
-void
-AddEwinToGroup(EWin * ewin, Group * g)
+static void
+_GroupAddEwin(Group * g, EWin * ewin)
 {
    int                 i;
 
-   if (ewin && g)
+   for (i = 0; i < ewin->num_groups; i++)
+      if (ewin->groups[i] == g)
+	 return;
+
+   ewin->num_groups++;
+   ewin->groups = EREALLOC(Group *, ewin->groups, ewin->num_groups);
+   ewin->groups[ewin->num_groups - 1] = g;
+   g->num_members++;
+   g->members = EREALLOC(EWin *, g->members, g->num_members);
+   g->members[g->num_members - 1] = ewin;
+}
+
+static void
+AddEwinToGroup(EWin * ewin, Group * g)
+{
+   if (!ewin || !g)
+      return;
+
+   _GroupAddEwin(g, ewin);
+   SnapshotEwinUpdate(ewin, SNAP_USE_GROUPS);
+}
+
+void
+GroupsEwinAdd(EWin * ewin, const int *pgid, int ngid)
+{
+   Group              *g;
+   int                 i, gid;
+
+   for (i = 0; i < ngid; i++)
      {
-	for (i = 0; i < ewin->num_groups; i++)
-	   if (ewin->groups[i] == g)
-	      return;
-	ewin->num_groups++;
-	ewin->groups = EREALLOC(Group *, ewin->groups, ewin->num_groups);
-	ewin->groups[ewin->num_groups - 1] = g;
-	g->num_members++;
-	g->members = EREALLOC(EWin *, g->members, g->num_members);
-	g->members[g->num_members - 1] = ewin;
-	SnapshotEwinUpdate(ewin, SNAP_USE_GROUPS);
+	gid = pgid[i];
+	g = GroupFind(gid);
+	Dprintf("ewin=%p gid=%d grp=%p\n", ewin, gid, g);
+	if (!g)
+	  {
+	     /* This should not happen, but may if group/snap configs are corrupted */
+	     BuildWindowGroup(&ewin, 1, gid);
+	  }
+	else
+	  {
+	     _GroupAddEwin(g, ewin);
+	  }
      }
+   SnapshotEwinUpdate(ewin, SNAP_USE_GROUPS);
 }
 
 static int
@@ -324,6 +382,11 @@ RemoveEwinFromGroup(EWin * ewin, Group * g)
 	     g->num_members--;
 	     if (g->num_members > 0)
 		g->members = EREALLOC(EWin *, g->members, g->num_members);
+	     else if (g->save)
+	       {
+		  Efree(g->members);
+		  g->members = NULL;
+	       }
 	     else
 	       {
 		  GroupDestroy(g);
@@ -343,7 +406,7 @@ RemoveEwinFromGroup(EWin * ewin, Group * g)
 		ewin->groups =
 		   EREALLOC(Group *, ewin->groups, ewin->num_groups);
 
-	     SaveGroups();
+	     GroupsSave();
 	     return;
 	  }
      }
@@ -401,7 +464,6 @@ ShowHideWinGroups(EWin * ewin, int group_index, char onoff)
    EWin              **gwins;
    int                 i, num;
    const Border       *b = NULL;
-   const Border       *previous_border;
 
    if (!ewin || group_index >= ewin->num_groups)
       return;
@@ -416,60 +478,20 @@ ShowHideWinGroups(EWin * ewin, int group_index, char onoff)
 	num = ewin->groups[group_index]->num_members;
      }
 
-   previous_border = ewin->previous_border;
+   if (onoff == SET_TOGGLE)
+      onoff = (ewin->border == ewin->normal_border) ? SET_ON : SET_OFF;
 
    for (i = 0; i < num; i++)
      {
-	b = NULL;
-	switch (onoff)
-	  {
-	  case SET_TOGGLE:
-	     if ((!previous_border) && (!gwins[i]->previous_border))
-	       {
-		  if (!gwins[i]->border->group_border_name)
-		     continue;
+	if (onoff == SET_ON)
+	   b = BorderFind(gwins[i]->border->group_border_name);
+	else
+	   b = gwins[i]->normal_border;
 
-		  b = BorderFind(gwins[i]->border->group_border_name);
-		  if (b)
-		     gwins[i]->previous_border = gwins[i]->border;
-	       }
-	     else if ((previous_border) && (gwins[i]->previous_border))
-	       {
-		  b = gwins[i]->previous_border;
-		  gwins[i]->previous_border = NULL;
-	       }
-	     break;
-	  case SET_ON:
-	     if (!gwins[i]->previous_border)
-	       {
-		  if (!gwins[i]->border->group_border_name)
-		     continue;
-
-		  b = BorderFind(gwins[i]->border->group_border_name);
-		  if (b)
-		     gwins[i]->previous_border = gwins[i]->border;
-	       }
-	     break;
-	  case SET_OFF:
-	     if (gwins[i]->previous_border)
-	       {
-		  b = gwins[i]->previous_border;
-		  gwins[i]->previous_border = NULL;
-	       }
-	     break;
-	  default:
-	     break;
-	  }
-
-	if (b)
-	  {
-	     EwinSetBorder(gwins[i], b, 1);
-	     SnapshotEwinUpdate(gwins[i], SNAP_USE_GROUPS);
-	  }
+	EwinBorderChange(gwins[i], b, 0);
      }
    if (group_index < 0)
       Efree(gwins);
-   SaveGroups();
 }
 #else
 
@@ -478,7 +500,7 @@ ShowHideWinGroups(EWin * ewin, int group_index, char onoff)
 #endif /* USE_GROUP_SHOWHIDE */
 
 void
-SaveGroups(void)
+GroupsSave(void)
 {
    Group              *g;
    FILE               *f;
@@ -494,18 +516,9 @@ SaveGroups(void)
 
    ECORE_LIST_FOR_EACH(group_list, g)
    {
-      if (!g->members)
+      if (!g->save)
 	 continue;
 
-      /* Only if the group should be remembered, write info */
-      if (!g->members[0]->snap)
-	 continue;
-
-#if 0
-      if (!g->members[0]->snap->num)
-	 continue;
-#endif
-
       fprintf(f, "NEW: %i\n", g->index);
       fprintf(f, "ICONIFY: %i\n", g->cfg.iconify);
       fprintf(f, "KILL: %i\n", g->cfg.kill);
@@ -520,7 +533,7 @@ SaveGroups(void)
    fclose(f);
 }
 
-static void
+void
 GroupsLoad(void)
 {
    FILE               *f;
@@ -544,9 +557,7 @@ GroupsLoad(void)
 
 	if (!strcmp(ss, "NEW:"))
 	  {
-	     g = GroupCreate();
-	     if (g)
-		g->index = ii;
+	     g = GroupCreate(ii);
 	     continue;
 	  }
 	if (!g)
@@ -631,7 +642,7 @@ ChooseGroup(Dialog * d __UNUSED__, int val, void *data __UNUSED__)
 	Efree(tmp_groups);
 	tmp_groups = NULL;
 
-	SaveGroups();
+	GroupsSave();
      }
 }
 
@@ -686,7 +697,7 @@ static const DialogDef DlgGroupChoose = {
    "GROUP_SELECTION",
    NULL,
    N_("Window Group Selection"),
-   "SOUND_SETTINGS_GROUP",
+   SOUND_SETTINGS_GROUP,
    "pix/group.png",
    N_("Enlightenment Window Group\n" "Selection Dialog\n"),
    _DlgFillGroupChoose,
@@ -899,7 +910,7 @@ static const DialogDef DlgGroups = {
    "CONFIGURE_GROUP",
    NULL,
    N_("Window Group Settings"),
-   "SOUND_SETTINGS_GROUP",
+   SOUND_SETTINGS_GROUP,
    "pix/group.png",
    N_("Enlightenment Window Group\n" "Settings Dialog\n"),
    _DlgFillGroups,
@@ -1014,7 +1025,7 @@ const DialogDef     DlgGroupDefaults = {
    "CONFIGURE_DEFAULT_GROUP_CONTROL",
    N_("Groups"),
    N_("Default Group Control Settings"),
-   "SOUND_SETTINGS_GROUP",
+   SOUND_SETTINGS_GROUP,
    "pix/group.png",
    N_("Enlightenment Default\n" "Group Control Settings Dialog\n"),
    _DlgFillGroupDefaults,
@@ -1039,49 +1050,31 @@ GroupsConfigure(const char *params)
    sscanf(p, "%100s %n", s, &l);
    p += l;
 
+   ewin = GetContextEwin();
+
    if (!strcmp(s, "group"))
      {
-	ewin = GetFocusEwin();
-	if (ewin)
-	   SettingsGroups(ewin);
-     }
-   else if (!s[0] || !strcmp(s, "group_defaults"))
-     {
-	DialogShowSimple(&DlgGroupDefaults, NULL);
+	SettingsGroups(ewin);
      }
    else if (!strcmp(s, "add"))
      {
-	ewin = GetFocusEwin();
 	ChooseGroupDialog(ewin,
 			  _("Pick the group the window will belong to:"),
 			  GROUP_SELECT_ALL_EXCEPT_EWIN, GROUP_OP_ADD);
      }
    else if (!strcmp(s, "del"))
      {
-	ewin = GetFocusEwin();
 	ChooseGroupDialog(ewin,
 			  _("Select the group to remove the window from:"),
 			  GROUP_SELECT_EWIN_ONLY, GROUP_OP_DEL);
      }
    else if (!strcmp(s, "break"))
      {
-	ewin = GetFocusEwin();
 	ChooseGroupDialog(ewin, _("Select the group to break:"),
 			  GROUP_SELECT_EWIN_ONLY, GROUP_OP_BREAK);
      }
 }
 
-static void
-GroupsSighan(int sig, void *prm __UNUSED__)
-{
-   switch (sig)
-     {
-     case ESIGNAL_INIT:
-	GroupsLoad();
-	break;
-     }
-}
-
 static void
 GroupShow(Group * g)
 {
@@ -1157,7 +1150,7 @@ IPC_GroupOps(const char *params)
 
    if (!strcmp(operation, "start"))
      {
-	BuildWindowGroup(&ewin, 1);
+	BuildWindowGroup(&ewin, 1, -1);
 	IpcPrintf("start %8x", win);
      }
    else if (!strcmp(operation, "add"))
@@ -1188,7 +1181,7 @@ IPC_GroupOps(const char *params)
 	IpcPrintf("Error: no such operation: %s", operation);
 	return;
      }
-   SaveGroups();
+   GroupsSave();
 }
 
 static void
@@ -1399,7 +1392,7 @@ static const CfgItem GroupsCfgItems[] = {
 extern const EModule ModGroups;
 const EModule       ModGroups = {
    "groups", "grp",
-   GroupsSighan,
+   NULL,
    {N_IPC_FUNCS, GroupsIpcArray},
    {N_CFG_ITEMS, GroupsCfgItems}
 };
