@@ -31,7 +31,6 @@ SignalHandler(int sig)
 {
    static int          loop_count = 0;
    int                 status;
-   const char         *txt;
 
    Mode.wm.in_signal_handler = 1;
 
@@ -59,17 +58,17 @@ SignalHandler(int sig)
 	break;
 
      case SIGILL:
-	txt = _("Enlightenment performed an Illegal Instruction.\n" "\n"
+	Alert(_("Enlightenment performed an Illegal Instruction.\n" "\n"
 		"This most likely is due to you having installed an run a\n"
 		"binary of Enlightenment that was compiled for a make or model\n"
 		"of CPU not 100%% identical or compatible with yours. Please\n"
 		"either obtain the correct package for your system, or\n"
 		"re-compile Enlightenment and possibly any support libraries\n"
-		"that you got in binary format to run Enlightenment.\n");
-	goto do_alert;
+		"that you got in binary format to run Enlightenment.\n"));
+	goto do_abort;
 
      case SIGFPE:
-	txt = _("Enlightenment caused a Floating Point Exception.\n" "\n"
+	Alert(_("Enlightenment caused a Floating Point Exception.\n" "\n"
 		"This means that Enlightenment or support library routines it calls\n"
 		"have performed an illegal mathematical operation (most likely\n"
 		"dividing a number by zero). This is most likely a bug. It is\n"
@@ -77,11 +76,11 @@ SignalHandler(int sig)
 		"compile Enlightenment with debugging symbols in and run\n"
 		"Enlightenment under gdb so you can backtrace for where it died and\n"
 		"send in a useful bug report with backtrace information and variable\n"
-		"dumps etc.\n");
-	goto do_alert;
+		"dumps etc.\n"));
+	goto do_abort;
 
      case SIGSEGV:
-	txt = _("Enlightenment caused Segment Violation (Segfault)\n" "\n"
+	Alert(_("Enlightenment caused Segment Violation (Segfault)\n" "\n"
 		"This means that Enlightenment or support library routines it calls\n"
 		"have accessed areas of your system's memory that they are not\n"
 		"allowed access to. This is most likely a bug. It is recommended to\n"
@@ -89,17 +88,17 @@ SignalHandler(int sig)
 		"Enlightenment with debugging symbols in and run Enlightenment\n"
 		"under gdb so you can backtrace for where it died and send in a\n"
 		"useful bug report with backtrace information and variable\n"
-		"dumps etc.\n");
-	goto do_alert;
+		"dumps etc.\n"));
+	goto do_abort;
 
      case SIGBUS:
-	txt = _("Enlightenment caused Bus Error.\n" "\n"
+	Alert(_("Enlightenment caused Bus Error.\n" "\n"
 		"It is suggested you check your hardware and OS installation.\n"
 		"It is highly unusual to cause Bus Errors on operational\n"
-		"hardware.\n");
-	goto do_alert;
+		"hardware.\n"));
+	goto do_abort;
 
-      do_alert:
+      do_abort:
 	if (loop_count > 0)
 	   abort();
 	loop_count++;
@@ -107,7 +106,6 @@ SignalHandler(int sig)
 	disp = NULL;
 #endif
 	Mode.wm.exit_now = 1;
-	DialogAlert(txt);
 	SessionExit(EEXIT_ERROR, NULL);
 	abort();
 	break;
