@@ -429,7 +429,6 @@ EHintsGetInfo(EWin * ewin)
       return;
 
    ewin->state.identified = 1;
-   ewin->client.grav = StaticGravity;
    ewin->state.placed = 1;
 
    if (num < 2)
@@ -462,7 +461,7 @@ EHintsGetInfo(EWin * ewin)
       ecore_x_window_prop_string_get(EwinGetClientXwin(ewin),
 				     E16_ATOM_WIN_BORDER);
    if (str)
-      EwinSetBorderByName(ewin, str);
+      EwinBorderSetInitially(ewin, str);
    Efree(str);
 
    if (EDebug(EDBUG_TYPE_SNAPS))
