@@ -59,12 +59,8 @@ EobjGetImage(EObj * eo, Drawable draw)
 {
    EImage             *im;
    Pixmap              mask;
-   int                 shaped;
 
-   mask = None;
-   shaped = EShapeCheck(EobjGetWin(eo));
-   if (shaped)
-      mask = EWindowGetShapePixmap(EobjGetWin(eo));
+   mask = EWindowGetShapePixmap(EobjGetWin(eo));
    im = EImageGrabDrawable(draw, mask, 0, 0, EobjGetW(eo), EobjGetH(eo), 0);
    if (mask)
       EFreePixmap(mask);
@@ -99,7 +95,7 @@ HiwinRenderImageInit(Hiwin * phi)
    ESetWindowBackgroundPixmap(EoGetWin(phi), None);
 
    /* Reset shape */
-   EShapeCombineMask(EoGetWin(phi), ShapeBounding, 0, 0, None, ShapeSet);
+   EShapeSetMask(EoGetWin(phi), 0, 0, None);
    EoShapeUpdate(phi, 0);
 }
 
@@ -250,7 +246,7 @@ HiwinCreate(void)
       return NULL;
 
    EoInit(phi, EOBJ_TYPE_MISC, None, 0, 0, 3, 3, 1, "HiWin");
-   EoSetShadow(phi, 0);
+   EoSetFade(phi, 1);
    EoSetFloating(phi, 1);
    EoSetLayer(phi, 19);
    EventCallbackRegister(EoGetWin(phi), 0, HiwinEvent, phi);
