@@ -34,35 +34,18 @@
 
 #define ENABLE_DESTROY 0	/* Broken */
 
-#if ENABLE_COLOR_MODIFIERS
-typedef struct {
-   int                 num;
-   unsigned char      *px;
-   unsigned char      *py;
-   unsigned char       map[256];
-} ModCurve;
-
-typedef struct {
-   char               *name;
-   ModCurve            red, green, blue;
-   unsigned int        ref_count;
-} ColorModifierClass;
-#endif
-
 struct _imagestate {
    char               *im_file;
    char               *real_file;
    char                got_colors;
    char                unloadable;
    char                transparent;
+   char                pixmapfillstyle;
+   char                bevelstyle;
+   char                rotate;
    EImage             *im;
    EImageBorder       *border;
-   int                 pixmapfillstyle;
    EColor              bg, hi, lo, hihi, lolo;
-   int                 bevelstyle;
-#if ENABLE_COLOR_MODIFIERS
-   ColorModifierClass *colmod;
-#endif
 };
 
 typedef struct {
@@ -76,14 +59,13 @@ struct _imageclass {
    char               *name;
    ImageStateArray     norm, active, sticky, sticky_active;
    EImageBorder        padding;
-#if ENABLE_COLOR_MODIFIERS
-   ColorModifierClass *colmod;
-#endif
    unsigned int        ref_count;
 };
 
 static Ecore_List  *iclass_list = NULL;
 
+static ImageClass  *ImageclassGetFallback(void);
+
 #ifdef ENABLE_THEME_TRANSPARENCY
 
 static EImageColorModifier *icm = NULL;
@@ -177,7 +159,7 @@ ThemeImageLoad(const char *file)
 	return im;
      }
 
-   f = ThemeFileFind(file, 0);
+   f = ThemeFileFind(file);
    if (f)
      {
 	im = EImageLoad(f);
@@ -232,11 +214,6 @@ ImagestateDestroy(ImageState * is)
 
    Efree(is->border);
 
-#if ENABLE_COLOR_MODIFIERS
-   if (is->colmod)
-      is->colmod->ref_count--;
-#endif
-
    Efree(is);
 }
 
@@ -268,26 +245,34 @@ ImagestateColorsAlloc(ImageState * is)
 static void
 ImagestateRealize(ImageState * is)
 {
-   if (is == NULL || is->im_file == NULL)
+   if (!is)
       return;
-
-   /* has bg pixmap */
-   if (is->im)
+   if (is->im)			/* Image is already loaded */
       return;
 
    /* not loaded, load and setup */
-   if (!is->real_file)
-      is->real_file = ThemeFileFind(is->im_file, 0);
+   if (!is->real_file && is->im_file)
+      is->real_file = ThemeFileFind(is->im_file);
    if (is->real_file)
-      is->im = EImageLoad(is->real_file);
+     {
+	is->im = EImageLoad(is->real_file);
+	if (is->im && is->rotate)
+	   EImageOrientate(is->im, is->rotate);
+     }
    if (!is->im)
      {
+#define S(s) ((s) ? (s) : "(null)")
 	Eprintf
 	   ("ImagestateRealize: Hmmm... is->im is NULL (im_file=%s real_file=%s)\n",
-	    is->im_file, is->real_file);
+	    S(is->im_file), S(is->real_file));
+	Efree(is->real_file);
+	is->real_file = NULL;
 	return;
      }
 
+   Efree(is->im_file);		/* We no longer need the file */
+   is->im_file = NULL;
+
    EImageCheckAlpha(is->im);
 
    if (is->border)
@@ -331,9 +316,6 @@ ImageclassCreate(const char *name)
    ic->padding.right = 0;
    ic->padding.top = 0;
    ic->padding.bottom = 0;
-#if ENABLE_COLOR_MODIFIERS
-   ic->colmod = NULL;
-#endif
    ic->ref_count = 0;
 
    return ic;
@@ -362,11 +344,6 @@ ImageclassDestroy(ImageClass * ic)
    FreeImageStateArray(&(ic->sticky));
    FreeImageStateArray(&(ic->sticky_active));
 
-#if ENABLE_COLOR_MODIFIERS
-   if (ic->colmod)
-      ic->colmod->ref_count--;
-#endif
-
    Efree(ic);
 }
 #endif /* ENABLE_DESTROY */
@@ -422,30 +399,18 @@ ImageclassFind(const char *name, int fallback)
    if (ic || !fallback)
       return ic;
 
-   ic = (ImageClass *) ecore_list_find(iclass_list, _ImageclassMatchName,
-				       "__FALLBACK_ICLASS");
-
-   return ic;
+#if 0
+   Eprintf("%s: Get fallback (%s)\n", __func__, name);
+#endif
+   return ImageclassGetFallback();
 }
 
 #define ISTATE_SET_STATE(which, fallback) \
    if (!ic->which) ic->which = ic->fallback;
 
-#if ENABLE_COLOR_MODIFIERS
-#define ISTATE_SET_CM(which, fallback) \
-   if (!ic->which->colmod) { \
-      ic->which->colmod = fallback; \
-      if (fallback) fallback->ref_count++; \
-     }
-#endif
-
 static void
 ImageclassPopulate(ImageClass * ic)
 {
-#if ENABLE_COLOR_MODIFIERS
-   ColorModifierClass *cm;
-#endif
-
    if (!ic)
       return;
 
@@ -470,53 +435,6 @@ ImageclassPopulate(ImageClass * ic)
    ISTATE_SET_STATE(sticky_active.hilited, sticky_active.normal);
    ISTATE_SET_STATE(sticky_active.clicked, sticky_active.normal);
    ISTATE_SET_STATE(sticky_active.disabled, sticky_active.normal);
-
-#if ENABLE_COLOR_MODIFIERS
-   if (!ic->colmod)
-     {
-	cm = FindItem("ICLASS", 0, LIST_FINDBY_NAME, LIST_TYPE_COLORMODIFIER);
-	if (!cm)
-	   cm =
-	      FindItem("DEFAULT", 0, LIST_FINDBY_NAME, LIST_TYPE_COLORMODIFIER);
-	ic->colmod = cm;
-     }
-
-   cm = FindItem("NORMAL", 0, LIST_FINDBY_NAME, LIST_TYPE_COLORMODIFIER);
-   if (!cm)
-      cm = ic->colmod;
-
-   ISTATE_SET_CM(norm.normal, cm);
-   ISTATE_SET_CM(norm.hilited, cm);
-   ISTATE_SET_CM(norm.clicked, cm);
-   ISTATE_SET_CM(norm.disabled, cm);
-
-   cm = FindItem("ACTIVE", 0, LIST_FINDBY_NAME, LIST_TYPE_COLORMODIFIER);
-   if (!cm)
-      cm = ic->colmod;
-
-   ISTATE_SET_CM(active.normal, cm);
-   ISTATE_SET_CM(active.hilited, cm);
-   ISTATE_SET_CM(active.clicked, cm);
-   ISTATE_SET_CM(active.disabled, cm);
-
-   cm = FindItem("STICKY", 0, LIST_FINDBY_NAME, LIST_TYPE_COLORMODIFIER);
-   if (!cm)
-      cm = ic->colmod;
-
-   ISTATE_SET_CM(sticky.normal, cm);
-   ISTATE_SET_CM(sticky.hilited, cm);
-   ISTATE_SET_CM(sticky.clicked, cm);
-   ISTATE_SET_CM(sticky.disabled, cm);
-
-   cm = FindItem("STICKY_ACTIVE", 0, LIST_FINDBY_NAME, LIST_TYPE_COLORMODIFIER);
-   if (!cm)
-      cm = ic->colmod;
-
-   ISTATE_SET_CM(sticky_active.normal, cm);
-   ISTATE_SET_CM(sticky_active.hilited, cm);
-   ISTATE_SET_CM(sticky_active.clicked, cm);
-   ISTATE_SET_CM(sticky_active.disabled, cm);
-#endif
 }
 
 int
@@ -530,10 +448,6 @@ ImageclassConfigLoad(FILE * fs)
    ImageState         *ICToRead = NULL;
    int                 l, r, t, b;
 
-#if ENABLE_COLOR_MODIFIERS
-   ColorModifierClass *cm = NULL;
-#endif
-
    while (GetLine(s, sizeof(s), fs))
      {
 	i1 = ConfigParseline1(s, s2, NULL, NULL);
@@ -561,6 +475,9 @@ ImageclassConfigLoad(FILE * fs)
 	  case ICLASS_TRANSPARENT:
 	     ICToRead->transparent = strtoul(s2, NULL, 0);
 	     break;
+	  case ICLASS_ROTATE:
+	     ICToRead->rotate = strtoul(s2, NULL, 0);
+	     break;
 	  case CONFIG_INHERIT:
 	     {
 		ImageClass         *ICToInherit;
@@ -571,28 +488,10 @@ ImageclassConfigLoad(FILE * fs)
 		ic->sticky = ICToInherit->sticky;
 		ic->sticky_active = ICToInherit->sticky_active;
 		ic->padding = ICToInherit->padding;
-#if ENABLE_COLOR_MODIFIERS
-		ic->colmod = ICToInherit->colmod;
-#endif
 	     }
 	     break;
 	  case CONFIG_COLORMOD:
 	  case ICLASS_COLORMOD:
-#if ENABLE_COLOR_MODIFIERS
-	     cm = FindItem(s2, 0, LIST_FINDBY_NAME, LIST_TYPE_COLORMODIFIER);
-	     if (cm)
-	       {
-		  if (ICToRead)
-		    {
-		       ICToRead->colmod = cm;
-		    }
-		  else
-		    {
-		       ic->colmod = cm;
-		    }
-		  cm->ref_count++;
-	       }
-#endif
 	     break;
 	  case ICLASS_PADDING:
 	     l = r = t = b = 0;
@@ -761,7 +660,7 @@ ImageclassGetImage(ImageClass * ic, int active, int sticky, int state)
    if (!is)
       return NULL;
 
-   if (is->im == NULL && is->im_file)
+   if (is->im == NULL)
       ImagestateRealize(is);
 
    im = is->im;
@@ -772,20 +671,6 @@ ImageclassGetImage(ImageClass * ic, int active, int sticky, int state)
    return im;
 }
 
-void
-ImageclassApplySimple(ImageClass * ic, Win win, Drawable draw, int state,
-		      int x, int y, int w, int h)
-{
-   EImage             *im;
-
-   im = ImageclassGetImage(ic, 0, 0, state);
-   if (!im)
-      return;
-
-   EImageRenderOnDrawable(im, win, draw, 0, x, y, w, h);
-   EImageFree(im);
-}
-
 #ifdef ENABLE_TRANSPARENCY
 static int
 pt_type_to_flags(int image_type)
@@ -876,13 +761,20 @@ EImage             *
 ImageclassGetImageBlended(ImageClass * ic, Win win, int w, int h, int active,
 			  int sticky, int state, int image_type)
 {
+   ImageState         *is;
    EImage             *im, *bg;
    int                 flags;
 
    if (!ic)
       return NULL;
 
-   im = ImageclassGetImage(ic, active, sticky, state);
+   is = ImageclassGetImageState(ic, state, active, sticky);
+   if (!is)
+      return NULL;
+
+   if (is->im == NULL)
+      ImagestateRealize(is);
+   im = is->im;
    if (!im)
       return NULL;
 
@@ -893,6 +785,7 @@ ImageclassGetImageBlended(ImageClass * ic, Win win, int w, int h, int active,
 	bg = pt_get_bg_image(win, w, h, flags & ICLASS_ATTR_GLASS);
 	if (bg)
 	  {
+	     /* FIXME - Tiling not implemented */
 	     EImageBlendCM(bg, im, (flags & ICLASS_ATTR_USE_CM) ? icm : NULL);
 	     goto done;
 	  }
@@ -902,10 +795,35 @@ ImageclassGetImageBlended(ImageClass * ic, Win win, int w, int h, int active,
    win = None;
 #endif
 
-   bg = EImageCreateScaled(im, 0, 0, 0, 0, w, h);
+   if (is->pixmapfillstyle == FILL_STRETCH)
+     {
+	bg = EImageCreateScaled(im, 0, 0, 0, 0, w, h);
+     }
+   else
+     {
+	int                 iw, ih, tw, th;
 
+	EImageGetSize(im, &iw, &ih);
+
+	tw = w;
+	th = h;
+	if (is->pixmapfillstyle & FILL_TILE_H)
+	   tw = iw;
+	if (is->pixmapfillstyle & FILL_TILE_V)
+	   th = ih;
+
+	bg = EImageCreate(w, h);
+	EImageTile(bg, im, 0, tw, th, 0, 0, w, h, 0, 0);
+     }
+
+#ifdef ENABLE_TRANSPARENCY
  done:
-   EImageFree(im);
+#endif
+   if ((is->unloadable) || (Conf.memory_paranoia))
+     {
+	EImageFree(is->im);
+	is->im = NULL;
+     }
 
    return bg;
 }
@@ -1021,8 +939,14 @@ ImagestateMakePmapMask(ImageState * is, Win win, PmapMask * pmm,
      }
 }
 
+#define LINE(x1, y1, x2, y2) \
+   XDrawLine(disp, win, gc, x + (x1), y + (y1), x + (x2), y + (y2))
+#define RECT(x, y, w, h) \
+	XDrawRectangle(disp, win, gc, x, y, w, h);
+
 static void
-ImagestateDrawBevel(ImageState * is, Drawable win, GC gc, int w, int h)
+ImagestateDrawBevel(ImageState * is, Drawable win, GC gc,
+		    int x, int y, int w, int h)
 {
    ImagestateColorsAlloc(is);
 
@@ -1030,93 +954,109 @@ ImagestateDrawBevel(ImageState * is, Drawable win, GC gc, int w, int h)
      {
      case BEVEL_AMIGA:
 	XSetForeground(disp, gc, is->hihi.pixel);
-	XDrawLine(disp, win, gc, 0, 0, w - 2, 0);
-	XDrawLine(disp, win, gc, 0, 0, 0, h - 2);
+	LINE(0, 0, w - 2, 0);
+	LINE(0, 0, 0, h - 2);
 	XSetForeground(disp, gc, is->lolo.pixel);
-	XDrawLine(disp, win, gc, 1, h - 1, w - 1, h - 1);
-	XDrawLine(disp, win, gc, w - 1, 1, w - 1, h - 1);
+	LINE(1, h - 1, w - 1, h - 1);
+	LINE(w - 1, 1, w - 1, h - 1);
 	break;
      case BEVEL_MOTIF:
 	XSetForeground(disp, gc, is->hi.pixel);
-	XDrawLine(disp, win, gc, 0, 0, w - 1, 0);
-	XDrawLine(disp, win, gc, 0, 0, 0, h - 1);
-	XDrawLine(disp, win, gc, 1, 1, w - 2, 1);
-	XDrawLine(disp, win, gc, 1, 1, 1, h - 2);
+	LINE(0, 0, w - 1, 0);
+	LINE(0, 0, 0, h - 1);
+	LINE(1, 1, w - 2, 1);
+	LINE(1, 1, 1, h - 2);
 	XSetForeground(disp, gc, is->lo.pixel);
-	XDrawLine(disp, win, gc, 0, h - 1, w - 1, h - 1);
-	XDrawLine(disp, win, gc, w - 1, 1, w - 1, h - 1);
-	XDrawLine(disp, win, gc, 1, h - 2, w - 2, h - 2);
-	XDrawLine(disp, win, gc, w - 2, 2, w - 2, h - 2);
+	LINE(0, h - 1, w - 1, h - 1);
+	LINE(w - 1, 1, w - 1, h - 1);
+	LINE(1, h - 2, w - 2, h - 2);
+	LINE(w - 2, 2, w - 2, h - 2);
 	break;
      case BEVEL_NEXT:
 	XSetForeground(disp, gc, is->hihi.pixel);
-	XDrawLine(disp, win, gc, 0, 0, w - 1, 0);
-	XDrawLine(disp, win, gc, 0, 0, 0, h - 1);
+	LINE(0, 0, w - 1, 0);
+	LINE(0, 0, 0, h - 1);
 	XSetForeground(disp, gc, is->hi.pixel);
-	XDrawLine(disp, win, gc, 1, 1, w - 2, 1);
-	XDrawLine(disp, win, gc, 1, 1, 1, h - 2);
+	LINE(1, 1, w - 2, 1);
+	LINE(1, 1, 1, h - 2);
 	XSetForeground(disp, gc, is->lolo.pixel);
-	XDrawLine(disp, win, gc, 1, h - 1, w - 1, h - 1);
-	XDrawLine(disp, win, gc, w - 1, 1, w - 1, h - 1);
+	LINE(1, h - 1, w - 1, h - 1);
+	LINE(w - 1, 1, w - 1, h - 1);
 	XSetForeground(disp, gc, is->lo.pixel);
-	XDrawLine(disp, win, gc, 2, h - 2, w - 2, h - 2);
-	XDrawLine(disp, win, gc, w - 2, 2, w - 2, h - 2);
+	LINE(2, h - 2, w - 2, h - 2);
+	LINE(w - 2, 2, w - 2, h - 2);
 	break;
      case BEVEL_DOUBLE:
 	XSetForeground(disp, gc, is->hi.pixel);
-	XDrawLine(disp, win, gc, 0, 0, w - 2, 0);
-	XDrawLine(disp, win, gc, 0, 0, 0, h - 2);
+	LINE(0, 0, w - 2, 0);
+	LINE(0, 0, 0, h - 2);
 	XSetForeground(disp, gc, is->lo.pixel);
-	XDrawLine(disp, win, gc, 1, 1, w - 3, 1);
-	XDrawLine(disp, win, gc, 1, 1, 1, h - 3);
+	LINE(1, 1, w - 3, 1);
+	LINE(1, 1, 1, h - 3);
 	XSetForeground(disp, gc, is->lo.pixel);
-	XDrawLine(disp, win, gc, 1, h - 1, w - 1, h - 1);
-	XDrawLine(disp, win, gc, w - 1, 1, w - 1, h - 1);
+	LINE(1, h - 1, w - 1, h - 1);
+	LINE(w - 1, 1, w - 1, h - 1);
 	XSetForeground(disp, gc, is->hi.pixel);
-	XDrawLine(disp, win, gc, 2, h - 2, w - 2, h - 2);
-	XDrawLine(disp, win, gc, w - 2, 2, w - 2, h - 2);
+	LINE(2, h - 2, w - 2, h - 2);
+	LINE(w - 2, 2, w - 2, h - 2);
 	break;
      case BEVEL_WIDEDOUBLE:
 	XSetForeground(disp, gc, is->hihi.pixel);
-	XDrawLine(disp, win, gc, 0, 0, w - 1, 0);
-	XDrawLine(disp, win, gc, 0, 0, 0, h - 1);
+	LINE(0, 0, w - 1, 0);
+	LINE(0, 0, 0, h - 1);
 	XSetForeground(disp, gc, is->hi.pixel);
-	XDrawLine(disp, win, gc, 1, 1, w - 2, 1);
-	XDrawLine(disp, win, gc, 1, 1, 1, h - 2);
-	XDrawLine(disp, win, gc, 3, h - 4, w - 4, h - 4);
-	XDrawLine(disp, win, gc, w - 4, 3, w - 4, h - 4);
+	LINE(1, 1, w - 2, 1);
+	LINE(1, 1, 1, h - 2);
+	LINE(3, h - 4, w - 4, h - 4);
+	LINE(w - 4, 3, w - 4, h - 4);
 	XSetForeground(disp, gc, is->lolo.pixel);
-	XDrawLine(disp, win, gc, 1, h - 1, w - 1, h - 1);
-	XDrawLine(disp, win, gc, w - 1, 1, w - 1, h - 1);
+	LINE(1, h - 1, w - 1, h - 1);
+	LINE(w - 1, 1, w - 1, h - 1);
 	XSetForeground(disp, gc, is->lo.pixel);
-	XDrawLine(disp, win, gc, 2, h - 2, w - 2, h - 2);
-	XDrawLine(disp, win, gc, w - 2, 2, w - 2, h - 2);
-	XDrawLine(disp, win, gc, 3, 3, w - 4, 3);
-	XDrawLine(disp, win, gc, 3, 3, 3, h - 4);
+	LINE(2, h - 2, w - 2, h - 2);
+	LINE(w - 2, 2, w - 2, h - 2);
+	LINE(3, 3, w - 4, 3);
+	LINE(3, 3, 3, h - 4);
 	break;
      case BEVEL_THINPOINT:
 	XSetForeground(disp, gc, is->hi.pixel);
-	XDrawLine(disp, win, gc, 0, 0, w - 2, 0);
-	XDrawLine(disp, win, gc, 0, 0, 0, h - 2);
+	LINE(0, 0, w - 2, 0);
+	LINE(0, 0, 0, h - 2);
 	XSetForeground(disp, gc, is->lo.pixel);
-	XDrawLine(disp, win, gc, 1, h - 1, w - 1, h - 1);
-	XDrawLine(disp, win, gc, w - 1, 1, w - 1, h - 1);
+	LINE(1, h - 1, w - 1, h - 1);
+	LINE(w - 1, 1, w - 1, h - 1);
 	XSetForeground(disp, gc, is->hihi.pixel);
-	XDrawLine(disp, win, gc, 0, 0, 1, 0);
-	XDrawLine(disp, win, gc, 0, 0, 0, 1);
+	LINE(0, 0, 1, 0);
+	LINE(0, 0, 0, 1);
 	XSetForeground(disp, gc, is->lolo.pixel);
-	XDrawLine(disp, win, gc, w - 2, h - 1, w - 1, h - 1);
-	XDrawLine(disp, win, gc, w - 1, h - 2, w - 1, h - 1);
+	LINE(w - 2, h - 1, w - 1, h - 1);
+	LINE(w - 1, h - 2, w - 1, h - 1);
 	break;
      case BEVEL_THICKPOINT:
 	XSetForeground(disp, gc, is->hi.pixel);
-	XDrawRectangle(disp, win, gc, 0, 0, w - 1, h - 1);
+	RECT(x, y, w - 1, h - 1);
 	break;
      default:
 	break;
      }
 }
 
+static void
+ImagestateDrawNoImg(ImageState * is, Drawable draw, int x, int y, int w, int h)
+{
+   GC                  gc;
+
+   ImagestateColorsAlloc(is);
+
+   gc = EXCreateGC(draw, 0, NULL);
+   XSetFillStyle(disp, gc, FillSolid);
+   XSetForeground(disp, gc, is->bg.pixel);
+   XFillRectangle(disp, draw, gc, x, y, w, h);
+   if (is->bevelstyle != BEVEL_NONE)
+      ImagestateDrawBevel(is, draw, gc, x, y, w, h);
+   EXFreeGC(gc);
+}
+
 void
 ITApply(Win win, ImageClass * ic, ImageState * is,
 	int state, int active, int sticky, int image_type,
@@ -1143,7 +1083,7 @@ ITApply(Win win, ImageClass * ic, ImageState * is,
 	   ts = TextclassGetTextState(tc, state, active, sticky);
      }
 
-   if (is->im == NULL && is->im_file)
+   if (is->im == NULL)
       ImagestateRealize(is);
 
    /* Imlib2 will not render pixmaps with dimensions > 8192 */
@@ -1163,7 +1103,7 @@ ITApply(Win win, ImageClass * ic, ImageState * is,
 		  if (pmm.type != 0)
 		    {
 		       pmap = EGetWindowBackgroundPixmap(win);
-		       EXCopyArea(pmm.pmap, pmap, 0, 0, w, h, 0, 0);
+		       EXCopyAreaTiled(pmm.pmap, None, pmap, 0, 0, w, h, 0, 0);
 		    }
 
 		  TextstateTextDraw(ts, win, pmap, text, 0, 0, w, h,
@@ -1179,14 +1119,12 @@ ITApply(Win win, ImageClass * ic, ImageState * is,
 	       }
 
 	     if (pmm.w == w && pmm.h == h)
-		EShapeCombineMask(win, ShapeBounding, 0, 0, pmm.mask, ShapeSet);
+		EShapeSetMask(win, 0, 0, pmm.mask);
 	     else if (pmm.mask)
-		EShapeCombineMaskTiled(win, ShapeBounding, 0, 0,
-				       pmm.mask, ShapeSet, w, h);
+		EShapeSetMaskTiled(win, 0, 0, pmm.mask, w, h);
 	  }
 
 	FreePmapMask(&pmm);
-	EClearWindow(win);
 
 	if ((is->unloadable) || (Conf.memory_paranoia))
 	  {
@@ -1196,21 +1134,32 @@ ITApply(Win win, ImageClass * ic, ImageState * is,
      }
    else
      {
-	/* FIXME - No text */
 	ImagestateColorsAlloc(is);
 
-	ESetWindowBackground(win, is->bg.pixel);
-	EClearWindow(win);
-     }
+	if (is->bevelstyle == BEVEL_NONE && !text)
+	  {
+	     ESetWindowBackground(win, is->bg.pixel);
+	  }
+	else
+	  {
+	     Pixmap              pmap;
+	     GC                  gc;
 
-   if (is->bevelstyle != BEVEL_NONE)
-     {
-	GC                  gc;
-
-	gc = EXCreateGC(WinGetXwin(win), 0, NULL);
-	ImagestateDrawBevel(is, WinGetXwin(win), gc, w, h);
-	EXFreeGC(gc);
+	     pmap = EGetWindowBackgroundPixmap(win);
+	     gc = EXCreateGC(WinGetXwin(win), 0, NULL);
+	     XSetFillStyle(disp, gc, FillSolid);
+	     XSetForeground(disp, gc, is->bg.pixel);
+	     XFillRectangle(disp, pmap, gc, 0, 0, w, h);
+	     if (is->bevelstyle != BEVEL_NONE)
+		ImagestateDrawBevel(is, pmap, gc, 0, 0, w, h);
+	     if (ts && text)
+		TextstateTextDraw(ts, win, pmap, text, 0, 0, w, h,
+				  &(ic->padding), 0,
+				  TextclassGetJustification(tc), flags);
+	     EXFreeGC(gc);
+	  }
      }
+   EClearWindow(win);
 }
 
 void
@@ -1265,7 +1214,7 @@ ImageclassApplyCopy(ImageClass * ic, Win win, int w, int h,
    if (!is)
       return;
 
-   if (is->im == NULL && is->im_file)
+   if (is->im == NULL)
       ImagestateRealize(is);
 
    /* Imlib2 will not render pixmaps with dimensions > 8192 */
@@ -1289,38 +1238,58 @@ ImageclassApplyCopy(ImageClass * ic, Win win, int w, int h,
      }
    else
      {
-	GC                  gc;
-	Pixmap              pmap;
-
-	ImagestateColorsAlloc(is);
-
 	if (pmm->pmap)
 	   Eprintf("ImageclassApplyCopy: Hmm... pmm->pmap already set\n");
 
-	pmap = ECreatePixmap(win, w, h, 0);
 	pmm->type = 0;
-	pmm->pmap = pmap;
+	pmm->pmap = ECreatePixmap(win, w, h, 0);
 	pmm->mask = 0;
 
-	gc = EXCreateGC(pmap, 0, NULL);
-	/* bg color */
-	XSetForeground(disp, gc, is->bg.pixel);
-	XFillRectangle(disp, pmap, gc, 0, 0, w, h);
-	/* if there is a bevel to draw, draw it */
-	if (is->bevelstyle != BEVEL_NONE)
-	   ImagestateDrawBevel(is, pmap, gc, w, h);
-	EXFreeGC(gc);
+	ImagestateDrawNoImg(is, pmm->pmap, 0, 0, w, h);
 	/* FIXME - No text */
      }
 }
 
-static void
-ImageclassSetupFallback(void)
+void
+ImageclassApplySimple(ImageClass * ic, Win win, Drawable draw, int state,
+		      int x, int y, int w, int h)
+{
+   EImage             *im;
+
+   if (!ic)
+      return;
+
+   im = ImageclassGetImage(ic, 0, 0, state);
+   if (im)
+     {
+	EImageRenderOnDrawable(im, win, draw, 0, x, y, w, h);
+	EImageFree(im);
+     }
+   else
+     {
+	ImageState         *is;
+
+	is = ImageclassGetImageState(ic, state, 0, 0);
+	if (!is)
+	   return;
+
+	ImagestateDrawNoImg(is, draw, x, y, w, h);
+     }
+}
+
+static ImageClass  *
+ImageclassGetFallback(void)
 {
    ImageClass         *ic;
 
-   /* create a fallback imageclass in case no imageclass can be found */
-   ic = ImageclassCreate("__FALLBACK_ICLASS");
+   ic = ImageclassFind("__fb_ic", 0);
+   if (ic)
+      return ic;
+
+   /* Create fallback imageclass */
+   ic = ImageclassCreate("__fb_ic");
+   if (!ic)
+      return ic;
 
    ic->norm.normal = ImagestateCreate(NULL);
    ImagestateColorsSetGray(ic->norm.normal, 255, 255, 160, 0, 0);
@@ -1349,37 +1318,42 @@ ImageclassSetupFallback(void)
    SET_COLOR(&(ic->active.clicked->bg), 230, 190, 210);
    ic->active.clicked->bevelstyle = BEVEL_AMIGA;
 
-   ic->padding.left = 8;
-   ic->padding.right = 8;
-   ic->padding.top = 8;
-   ic->padding.bottom = 8;
+   ic->padding.left = 4;
+   ic->padding.right = 4;
+   ic->padding.top = 4;
+   ic->padding.bottom = 4;
 
    ImageclassPopulate(ic);
 
+   return ic;
+}
+
+ImageClass         *
+ImageclassGetBlack(void)
+{
+   ImageClass         *ic;
+
+   ic = ImageclassFind("__BLACK", 0);
+   if (ic)
+      return ic;
+
    /* Create all black image class for filler borders */
    ic = ImageclassCreate("__BLACK");
+   if (!ic)
+      return ic;
 
    ic->norm.normal = ImagestateCreate(NULL);
    ImagestateColorsSetGray(ic->norm.normal, 0, 0, 0, 0, 0);
 
    ImageclassPopulate(ic);
+
+   return ic;
 }
 
 /*
  * Imageclass Module
  */
 
-static void
-ImageclassSighan(int sig, void *prm __UNUSED__)
-{
-   switch (sig)
-     {
-     case ESIGNAL_INIT:
-	ImageclassSetupFallback();
-	break;
-     }
-}
-
 static void
 ImageclassIpc(const char *params)
 {
@@ -1550,7 +1524,7 @@ ImageclassIpc(const char *params)
 static const IpcItem ImageclassIpcArray[] = {
    {
     ImageclassIpc,
-    "imageclass", NULL,
+    "imageclass", "ic",
     "List imageclasses, apply an imageclass",
     NULL}
    ,
@@ -1563,7 +1537,7 @@ static const IpcItem ImageclassIpcArray[] = {
 extern const EModule ModImageclass;
 const EModule       ModImageclass = {
    "imageclass", "ic",
-   ImageclassSighan,
+   NULL,
    {N_IPC_FUNCS, ImageclassIpcArray}
    ,
    {0, NULL}
