@@ -33,6 +33,7 @@
 #include "hints.h"		/* FIXME - Should not be here */
 #include "screen.h"
 #include "session.h"
+#include "settings.h"
 #include "snaps.h"
 #include "timers.h"
 #include "xwin.h"
@@ -402,15 +403,18 @@ doMoveConstrainedNoGroup(EWin * ewin, const char *params)
 }
 #endif
 
-static void
-OpacityTimeout(int val, void *data __UNUSED__)
+static int
+OpacityTimeout(void *data)
 {
-   EWin               *ewin;
+   EWin               *ewin = (EWin *) data;
 
-   ewin = EwinFindByClient(val);
-   if (ewin)
-      if (ewin->state.active)
-	 EoChangeOpacity(ewin, ewin->props.focused_opacity);
+   if (!EwinFindByPtr(ewin))	/* May be gone */
+      return 0;
+
+   if (ewin->state.active)
+      EoChangeOpacity(ewin, ewin->props.focused_opacity);
+
+   return 0;
 }
 
 static void
@@ -473,6 +477,10 @@ IpcWinop(const WinOp * wop, EWin * ewin, const char *prm)
 	   EwinOpIconify(ewin, OPSRC_USER, on);
 	break;
 
+     case EWIN_OP_ALONE:
+	EwinAlone(ewin);
+	break;
+
      case EWIN_OP_SHADE:
 	on = ewin->state.shaded;
 	if (SetEwinBoolean(wop->name, &on, param1, 1))
@@ -629,15 +637,15 @@ IpcWinop(const WinOp * wop, EWin * ewin, const char *prm)
 	break;
 
      case EWIN_OP_MAX_WIDTH:
-	MaxWidth(ewin, param1);
+	MaxSizeHV(ewin, param1, 1, 0);
 	break;
 
      case EWIN_OP_MAX_HEIGHT:
-	MaxHeight(ewin, param1);
+	MaxSizeHV(ewin, param1, 0, 1);
 	break;
 
      case EWIN_OP_MAX_SIZE:
-	MaxSize(ewin, param1);
+	MaxSizeHV(ewin, param1, 1, 1);
 	break;
 
      case EWIN_OP_FULLSCREEN:
@@ -686,10 +694,11 @@ IpcWinop(const WinOp * wop, EWin * ewin, const char *prm)
 	EwinOpSetOpacity(ewin, OPSRC_USER, a);
 	if (ewin->state.active)
 	  {
+	     Timer              *op_timer;
+
 	     EoChangeOpacity(ewin, OpacityFromPercent(a));
 	     if (ewin->props.focused_opacity)
-		DoIn("OPACITY_TIMEOUT", 0.001 * 700, OpacityTimeout,
-		     EwinGetClientXwin(ewin), NULL);
+		TIMER_ADD(op_timer, 0.001 * 700, OpacityTimeout, ewin);
 	  }
 	break;
 
@@ -736,9 +745,9 @@ IpcWinop(const WinOp * wop, EWin * ewin, const char *prm)
 	  {
 	     ewin->props.no_button_grabs = on;
 	     if (ewin->props.no_button_grabs)
-		UnGrabButtonGrabs(ewin);
+		UnGrabButtonGrabs(EoGetWin(ewin));
 	     else
-		GrabButtonGrabs(ewin);
+		GrabButtonGrabs(EoGetWin(ewin));
 	  }
 	goto ewin_update_snap_flags;
 
@@ -911,6 +920,15 @@ IPC_ForceSave(const char *params __UNUSED__)
    autosave();
 }
 
+static void
+IPC_Exec(const char *params)
+{
+   if (params)
+      execApplication(params, EXEC_SET_LANG | EXEC_SET_STARTUP_ID);
+   else
+      IpcPrintf("exec what?\n");
+}
+
 static void
 IPC_Restart(const char *params __UNUSED__)
 {
@@ -951,8 +969,7 @@ IPC_About(const char *params __UNUSED__)
 static void
 IPC_Version(const char *params __UNUSED__)
 {
-   IpcPrintf(_("Enlightenment Version : %s\n" "code is current to    : %s\n"),
-	     e_wm_version, e_wm_date);
+   IpcPrintf("%s %s\n", e_wm_name, e_wm_version);
 }
 
 static void
@@ -1164,8 +1181,8 @@ IPC_ObjInfo(const char *params __UNUSED__)
 	eo = lst[i];
 	IpcPrintf
 	   (" %2d %#9lx %2d %d %d %2d/%2d  %3d %d  %d %3d %5d,%5d %4dx%4d %d %d %s\n",
-	    i, EobjGetXwin(eo), WinGetDepth(eo->win), eo->type, eo->shown,
-	    eo->shaped, EShapeCheck(eo->win), eo->desk->num,
+	    i, EobjGetXwin(eo), WinGetDepth(EobjGetWin(eo)), eo->type,
+	    eo->shown, eo->shaped, EShapeCheck(EobjGetWin(eo)), eo->desk->num,
 	    eo->sticky, eo->floating, eo->ilayer,
 	    EobjGetX(eo), EobjGetY(eo), EobjGetW(eo), EobjGetH(eo),
 #if USE_COMPOSITE
@@ -1359,7 +1376,7 @@ IPC_InsertKeys(const char *params, Client * c __UNUSED__)
    if (win == None)
       return;
 
-   SoundPlay("SOUND_INSERT_KEYS");
+   SoundPlay(SOUND_INSERT_KEYS);
    ev.window = win;
    for (i = 0; i < (int)strlen(s); i++)
      {
@@ -1482,6 +1499,13 @@ static const IpcItem IPCArray[] = {
     NULL},
    {
     IPC_About, "about", NULL, "Show E info", NULL},
+   {
+    IPC_Cfg, "configure", "cfg", "Configuration", NULL},
+   {
+    IPC_Exec,
+    "exec", NULL,
+    "Execute program",
+    "  exec <command>       Execute command\n"},
    {
     IPC_Restart,
     "restart", NULL,
@@ -1513,7 +1537,7 @@ static const IpcItem IPCArray[] = {
     "  win_op <windowid> border <BORDERNAME>\n"
     "  win_op <windowid> title <title>\n"
     "  win_op <windowid> <close/kill>\n"
-    "  win_op <windowid> <focus/iconify/shade/stick>\n"
+    "  win_op <windowid> <focus/iconify/alone/shade/stick>\n"
 #if USE_COMPOSITE
     "  win_op <windowid> <fade/shadow>\n"
 #endif
@@ -1567,10 +1591,10 @@ static const IpcItem IPCArray[] = {
     "  screen size         Show current screen size\n"
     "  screen split nx ny  Simulate xinerama by subdividing screen\n"},
    {
-    SnapIpcFunc,
+    SnapshotsIpcFunc,
     "list_remember", "rl",
     "Retrieve a list of remembered windows and their attributes",
-    SnapIpcText},
+    SnapshotsIpcText},
    {
     IPC_Debug,
     "debug", NULL,
@@ -1713,28 +1737,29 @@ EFunc(EWin * ewin, const char *params)
    return ok;
 }
 
-static void
-doEFuncDeferred(int val __UNUSED__, void *data)
+static int
+doEFuncDeferred(void *data)
 {
    void              **prm = (void **)data;
    EWin               *ewin;
 
    ewin = (EWin *) prm[0];
    if (ewin && !EwinFindByPtr(ewin))
-      return;
+      return 0;
 
    EFunc(ewin, (const char *)prm[1]);
 
    Efree(prm[1]);
    Efree(data);
+
+   return 0;
 }
 
 void
 EFuncDefer(EWin * ewin, const char *cmd)
 {
-   static int          seqn = 0;
-   char                s[32];
    void              **prm;
+   Timer              *defer_timer;
 
    prm = EMALLOC(void *, 2);
 
@@ -1743,8 +1768,7 @@ EFuncDefer(EWin * ewin, const char *cmd)
    prm[0] = ewin;
    prm[1] = Estrdup(cmd);
 
-   Esnprintf(s, sizeof(s), "EFunc-%d", seqn++);
-   DoIn(s, 0.0, doEFuncDeferred, 0, prm);
+   TIMER_ADD(defer_timer, 0.0, doEFuncDeferred, prm);
 }
 
 static int
@@ -1810,7 +1834,7 @@ IPC_Help(const char *params)
 	     nick = (ipc->nick) ? ipc->nick : "";
 	     IpcPrintf("%18s %4s: %s\n", ipc->name, nick, ipc->help_text);
 	     if (ipc->extended_help_text)
-		IpcPrintf(ipc->extended_help_text);
+		IpcPrintf("%s", ipc->extended_help_text);
 	  }
      }
    else
@@ -1827,7 +1851,7 @@ IPC_Help(const char *params)
 	     IpcPrintf("%18s %4s: %s\n", ipc->name, nick, ipc->help_text);
 	     IpcPrintf("----------------------------------------\n");
 	     if (ipc->extended_help_text)
-		IpcPrintf(ipc->extended_help_text);
+		IpcPrintf("%s", ipc->extended_help_text);
 	  }
      }
 }
