@@ -45,6 +45,10 @@
 #include <iconv.h>
 #define BAD_CD ((iconv_t)-1)
 
+#ifndef ICONV_CONST		/* Not sure this is necessary */
+#define ICONV_CONST
+#endif
+
 static iconv_t      iconv_cd_int2utf8 = BAD_CD;
 static iconv_t      iconv_cd_utf82int = BAD_CD;
 static iconv_t      iconv_cd_int2loc = BAD_CD;
@@ -54,17 +58,15 @@ static char        *
 Eiconv(iconv_t icd, const char *txt, size_t len)
 {
    char                buf[4096];
-   char               *pi, *po;
+   ICONV_CONST char   *pi;
+   char               *po;
    size_t              err, ni, no;
 
-   pi = (char *)txt;
+   pi = (ICONV_CONST char *)txt;
    po = buf;
    ni = (len > 0) ? len : strlen(txt);
-   if (!icd)
-     {
-	Eprintf("*** WARNING - Missing conversion\n");
-	return Estrndup(txt, ni);
-     }
+   if (icd == BAD_CD)
+      return Estrndup(txt, ni);
    no = sizeof(buf);
    err = iconv(icd, &pi, &ni, &po, &no);
 
@@ -73,8 +75,21 @@ Eiconv(iconv_t icd, const char *txt, size_t len)
    return po;
 }
 
+static              iconv_t
+EiconvOpen(const char *to, const char *from)
+{
+   iconv_t             icd;
+
+   icd = iconv_open(to, from);
+   if (icd == BAD_CD)
+      Eprintf("*** WARNING - Missing conversion %s->%s\n", from, to);
+
+   return icd;
+}
+
 #endif
 
+#if 0				/* Unused */
 /* Convert locale to internal format (alloc always) */
 char               *
 EstrLoc2Int(const char *str, int len)
@@ -91,6 +106,7 @@ EstrLoc2Int(const char *str, int len)
       len = strlen(str);
    return Estrndup(str, len);
 }
+#endif
 
 /* Convert UTF-8 to internal format (alloc always) */
 char               *
@@ -165,11 +181,11 @@ EwcOpen(int utf8)
       enc = nl_langinfo(CODESET);
 
 #if SIZEOF_WCHAR_T == 4
-   iconv_cd_str2wcs = iconv_open("UCS-4", enc);
-   iconv_cd_wcs2str = iconv_open(enc, "UCS-4");
+   iconv_cd_str2wcs = EiconvOpen("UCS-4", enc);
+   iconv_cd_wcs2str = EiconvOpen(enc, "UCS-4");
 #else
-   iconv_cd_str2wcs = iconv_open("WCHAR_T", enc);
-   iconv_cd_wcs2str = iconv_open(enc, "WCHAR_T");
+   iconv_cd_str2wcs = EiconvOpen("WCHAR_T", enc);
+   iconv_cd_wcs2str = EiconvOpen(enc, "WCHAR_T");
 #endif
 
    if (iconv_cd_str2wcs != BAD_CD && iconv_cd_wcs2str != BAD_CD)
@@ -202,11 +218,12 @@ int
 EwcStrToWcs(const char *str, int len, wchar_t * wcs, int wcl)
 {
 #if HAVE_ICONV
-   char               *pi, *po;
+   ICONV_CONST char   *pi;
+   char               *po;
    size_t              ni, no, rc;
    char                buf[4096];
 
-   pi = (char *)str;
+   pi = (ICONV_CONST char *)str;
    ni = len;
 
    if (!wcs)
@@ -242,10 +259,10 @@ int
 EwcWcsToStr(const wchar_t * wcs, int wcl, char *str, int len)
 {
 #if HAVE_ICONV
-   char               *pi;
+   ICONV_CONST char   *pi;
    size_t              ni, no, rc;
 
-   pi = (char *)wcs;
+   pi = (ICONV_CONST char *)wcs;
    ni = wcl * sizeof(wchar_t);
    no = len;
    rc = iconv(iconv_cd_wcs2str, &pi, &ni, &str, &no);
@@ -375,23 +392,23 @@ LangInit(void)
 		enc_loc, enc_int, MB_CUR_MAX);
      }
 
-   if (!strcasecmp(enc_loc, "utf8") || !strcasecmp(enc_loc, "utf-8"))
+   if (!Estrcasecmp(enc_loc, "utf8") || !Estrcasecmp(enc_loc, "utf-8"))
       Mode.locale.utf8_loc = 1;
-   if (!strcasecmp(enc_int, "utf8") || !strcasecmp(enc_int, "utf-8"))
+   if (!Estrcasecmp(enc_int, "utf8") || !Estrcasecmp(enc_int, "utf-8"))
       Mode.locale.utf8_int = 1;
 
 #if HAVE_ICONV
+   if (Mode.locale.utf8_int && Mode.locale.utf8_loc)
+      return;
    if (Mode.locale.utf8_int)
      {
-	iconv_cd_loc2int = iconv_open("UTF-8", enc_loc);
-	iconv_cd_int2loc = iconv_open(enc_loc, "UTF-8");
-	iconv_cd_utf82int = iconv_cd_int2utf8 = BAD_CD;
+	iconv_cd_loc2int = EiconvOpen("UTF-8", enc_loc);
+	iconv_cd_int2loc = EiconvOpen(enc_loc, "UTF-8");
      }
    else
      {
-	iconv_cd_loc2int = iconv_cd_int2loc = BAD_CD;
-	iconv_cd_utf82int = iconv_open(enc_loc, "UTF-8");
-	iconv_cd_int2utf8 = iconv_open("UTF-8", enc_loc);
+	iconv_cd_utf82int = EiconvOpen(enc_loc, "UTF-8");
+	iconv_cd_int2utf8 = EiconvOpen("UTF-8", enc_loc);
      }
 #endif
 }
