@@ -36,7 +36,6 @@
 #include "hints.h"
 #include "session.h"
 #include "snaps.h"
-#include "timestamp.h"
 #include "user.h"
 #include "xwin.h"
 #include <sys/utsname.h>
@@ -45,7 +44,6 @@
 
 const char          e_wm_name[] = "Enlightenment";
 const char          e_wm_version[] = VERSION;
-const char          e_wm_date[] = E_CHECKOUT_DATE;
 
 EConf               Conf;
 EMode               Mode;
@@ -118,6 +116,9 @@ main(int argc, char **argv)
    str = getenv("EDEBUG_COREDUMP");
    if (str)
       Mode.wm.coredump = 1;
+   str = getenv("EDEBUG_EXIT");
+   if (str)
+      Mode.debug_exit = atoi(str);
 
    str = getenv("ECONFNAME");
    if (str)
@@ -192,7 +193,7 @@ main(int argc, char **argv)
 	     Mode.theme.path = Estrdup(eoptarg);
 	     break;
 	  case 'V':
-	     printf("%s %s - %s\n", e_wm_name, e_wm_version, e_wm_date);
+	     printf("%s %s\n", e_wm_name, e_wm_version);
 	     exit(0);
 	     break;
 	  case 'v':
@@ -248,17 +249,23 @@ main(int argc, char **argv)
    HintsInit();
    CommsInit();
    SessionInit();
-   LoadSnapInfo();
+   SnapshotsLoad();
 
 #if USE_DBUS
    DbusInit();
 #endif
 
+   if (Mode.wm.window)
+      EMapWindow(VROOT);
+
    ModulesSignal(ESIGNAL_INIT, NULL);
 
    /* Load the theme */
    ThemeConfigLoad();
 
+   if (Mode.debug_exit)
+      return 0;
+
    /* Do initial configuration */
    ModulesSignal(ESIGNAL_CONFIGURE, NULL);
 
@@ -270,9 +277,6 @@ main(int argc, char **argv)
    ExtInitWinKill();
 #endif
 
-   if (Mode.wm.window)
-      EMapWindow(VROOT);
-
    /* let's make sure we set this up and go to our desk anyways */
    DeskGoto(DesksGetCurrent());
    ESync(ESYNC_MAIN);
@@ -287,7 +291,7 @@ main(int argc, char **argv)
    EwinsManage();
 
    RunInitPrograms();
-   SpawnSnappedCmds();
+   SnapshotsSpawn();
 
    if (!Mode.wm.restart)
       StartupWindowsOpen();
