@@ -39,6 +39,7 @@ static char         menu_scan_recursive = 0;
 
 static Menu        *MenuCreateFromDirectory(const char *name, Menu * parent,
 					    MenuStyle * ms, const char *dir);
+static int          _ext_is_imagetype(const char *ext);
 
 static MenuItem    *
 MenuItemCreateFromBackground(const char *bgid, const char *file)
@@ -172,6 +173,7 @@ MenuLoadFromDirectory(Menu * m)
 	ext = fileext(ss);
 	if (S_ISDIR(st.st_mode))
 	  {
+	     /* Submenu */
 	     Esnprintf(s, sizeof(s), "%s/%s:%s", dir, list[i], MenuGetName(m));
 	     mm = MenuCreateFromDirectory(s, m, NULL, ss);
 	     mi = MenuItemCreate(list[i], NULL, NULL, mm);
@@ -179,33 +181,22 @@ MenuLoadFromDirectory(Menu * m)
 	     if (f)
 		fprintf(f, "DIR %s\n", list[i]);
 	  }
-/* that's it - people are stupid and have executable images and just */
-/* don't get it - so I'm disablign this to save people from their own */
-/* stupidity */
-/*           else if (st.st_mode & (S_IXUSR | S_IXGRP | S_IXOTH))
- * {
- * mi = MenuItemCreate(list[i], NULL, ss, NULL);
- * MenuAddItem(m, mi);
- * if (f)
- * fprintf(f, "EXE %s\n", list[i]);
- * }
- */
-	else if ((!strcmp(ext, "jpg")) || (!strcmp(ext, "JPG"))
-		 || (!strcmp(ext, "jpeg")) || (!strcmp(ext, "Jpeg"))
-		 || (!strcmp(ext, "JPEG")) || (!strcmp(ext, "Jpg"))
-		 || (!strcmp(ext, "gif")) || (!strcmp(ext, "Gif"))
-		 || (!strcmp(ext, "GIF")) || (!strcmp(ext, "png"))
-		 || (!strcmp(ext, "Png")) || (!strcmp(ext, "PNG"))
-		 || (!strcmp(ext, "tif")) || (!strcmp(ext, "Tif"))
-		 || (!strcmp(ext, "TIFF")) || (!strcmp(ext, "tiff"))
-		 || (!strcmp(ext, "Tiff")) || (!strcmp(ext, "TIFF"))
-		 || (!strcmp(ext, "xpm")) || (!strcmp(ext, "Xpm"))
-		 || (!strcmp(ext, "XPM")) || (!strcmp(ext, "ppm"))
-		 || (!strcmp(ext, "PPM")) || (!strcmp(ext, "pgm"))
-		 || (!strcmp(ext, "PGM")) || (!strcmp(ext, "pnm"))
-		 || (!strcmp(ext, "PNM")) || (!strcmp(ext, "bmp"))
-		 || (!strcmp(ext, "Bmp")) || (!strcmp(ext, "BMP")))
+#if 0
+	else if (st.st_mode & (S_IXUSR | S_IXGRP | S_IXOTH))
 	  {
+	     /* Executable */
+	     /* that's it - people are stupid and have executable images and just */
+	     /* don't get it - so I'm disablign this to save people from their own */
+	     /* stupidity */
+	     mi = MenuItemCreate(list[i], NULL, ss, NULL);
+	     MenuAddItem(m, mi);
+	     if (f)
+		fprintf(f, "EXE %s\n", list[i]);
+	  }
+#endif
+	else if (_ext_is_imagetype(ext))
+	  {
+	     /* Background */
 	     char                s3[512];
 	     int                 aa, bb, cc;
 
@@ -285,7 +276,6 @@ FillFlatFileMenu(Menu * m, const char *file)
    FILE               *f;
    char                first = 1;
    char                s[4096];
-   int                 count;
    unsigned int        len;
 
    f = fopen(file, "r");
@@ -297,7 +287,6 @@ FillFlatFileMenu(Menu * m, const char *file)
 
    MenuSetIconSize(m, 0);	/* Scale to default */
 
-   count = 0;
    while (fgets(s, 4096, f))
      {
 	if (s[0] == '#')
@@ -408,15 +397,15 @@ MenuCreateFromFlatFile(const char *name, Menu * parent, MenuStyle * ms,
 
    if (isabspath(file))
      {
-	ff = FindFile(file, NULL, 0);
+	ff = FindFile(file, NULL);
      }
    else
      {
 	/* Check menus subdir first */
 	Esnprintf(buf, sizeof(buf), "menus/%s", file);
-	ff = FindFile(buf, NULL, 0);
+	ff = FindFile(buf, NULL);
 	if (!ff)
-	   ff = FindFile(file, NULL, 0);
+	   ff = FindFile(file, NULL);
      }
    if (!ff)
       goto done;
@@ -433,117 +422,6 @@ MenuCreateFromFlatFile(const char *name, Menu * parent, MenuStyle * ms,
    return m;
 }
 
-static Menu        *
-MenuCreateFromGnome(const char *name, Menu * parent, MenuStyle * ms,
-		    const char *dir)
-{
-   Menu               *m, *mm;
-   int                 i, num;
-   char              **list, s[4096], ss[4096];
-   MenuItem           *mi;
-   FILE               *f;
-   char                name_buf[20];
-
-   if (Mode.locale.lang)
-      Esnprintf(name_buf, sizeof(name_buf), "Name[%s]=", Mode.locale.lang);
-   else
-      name_buf[0] = '\0';
-
-   m = MenuCreate(name, NULL, parent, ms);
-
-   list = E_ls(dir, &num);
-   for (i = 0; i < num; i++)
-     {
-	if ((strcmp(list[i], ".")) && (strcmp(list[i], "..")))
-	  {
-	     Esnprintf(ss, sizeof(ss), "%s/%s", dir, list[i]);
-	     if (isdir(ss))
-	       {
-		  Esnprintf(s, sizeof(s), "%s/%s:%s", dir, list[i], name);
-		  mm = MenuCreateFromGnome(s, m, ms, ss);
-
-		  name = list[i];
-		  if (name_buf[0])
-		    {
-		       Esnprintf(s, sizeof(s), "%s/.directory", ss);
-		       if ((f = fopen(s, "r")) != NULL)
-			 {
-			    while (fgets(s, sizeof(s), f))
-			      {
-				 if (!strncmp(s, name_buf, strlen(name_buf)))
-				   {
-				      if (s[strlen(s) - 1] == '\n')
-					 s[strlen(s) - 1] = 0;
-				      name = &(s[strlen(name_buf)]);
-				      break;
-				   }
-			      }
-			    fclose(f);
-			 }
-		    }
-		  mi = MenuItemCreate(name, NULL, NULL, mm);
-		  MenuAddItem(m, mi);
-	       }
-	     else
-	       {
-		  f = fopen(ss, "r");
-		  if (f)
-		    {
-		       char               *iname, *exec, *texec, *en_name;
-
-		       iname = exec = texec = en_name = NULL;
-
-		       while (fgets(s, sizeof(s), f))
-			 {
-			    if (s[strlen(s) - 1] == '\n')
-			       s[strlen(s) - 1] = 0;
-			    if (!strncmp(s, "Name=", strlen("Name=")))
-			       en_name = Estrdup(&(s[strlen("Name=")]));
-			    else if (name_buf[0]
-				     && !strncmp(s, name_buf, strlen(name_buf)))
-			       iname = Estrdup(&(s[strlen(name_buf)]));
-			    else if (!strncmp
-				     (s, "TryExec=", strlen("TryExec=")))
-			       texec = Estrdup(&(s[strlen("TryExec=")]));
-			    else if (!strncmp(s, "Exec=", strlen("Exec=")))
-			       exec = Estrdup(&(s[strlen("Exec=")]));
-			 }
-		       if (iname)
-			 {
-			    Efree(en_name);
-			 }
-		       else
-			 {
-			    if (en_name)
-			       iname = en_name;
-			 }
-		       fclose(f);
-		       if ((iname) && (exec))
-			 {
-			    int                 ok = 1;
-
-			    if (texec)
-			       ok = path_canexec(texec);
-			    if (ok)
-			      {
-				 Esnprintf(s, sizeof(s), "exec %s", exec);
-				 mi = MenuItemCreate(iname, NULL, s, NULL);
-				 MenuAddItem(m, mi);
-			      }
-			 }
-		       Efree(iname);
-		       Efree(exec);
-		       Efree(texec);
-		    }
-	       }
-	  }
-     }
-   if (list)
-      StrlistFree(list, num);
-
-   return m;
-}
-
 static int
 MenuLoadFromThemes(Menu * m)
 {
@@ -559,11 +437,11 @@ MenuLoadFromThemes(Menu * m)
    lst = ThemesList(&num);
    for (i = 0; i < num; i++)
      {
-	s = fullfileof(lst[i]);
+	s = ThemePathName(lst[i]);
 	Esnprintf(ss, sizeof(ss), "theme use %s", s);
 	mi = MenuItemCreate(s, NULL, ss, NULL);
-	Efree(s);
 	MenuAddItem(m, mi);
+	Efree(s);
      }
    if (lst)
       StrlistFree(lst, i);
@@ -821,13 +699,9 @@ MenusCreateInternal(const char *type, const char *name, const char *style,
      }
    else if (!strcmp(type, "dirscan"))
      {
-	SoundPlay("SOUND_SCANNING");
+	SoundPlay(SOUND_SCANNING);
 	m = MenuCreateFromDirectory(name, NULL, ms, prm);
      }
-   else if (!strcmp(type, "gnome"))
-     {
-	m = MenuCreateFromGnome(name, NULL, ms, prm);
-     }
    else if (!strcmp(type, "borders"))
      {
 	m = MenuCreateFromBorders(name, ms);
@@ -851,3 +725,19 @@ MenusCreateInternal(const char *type, const char *name, const char *style,
 
    return m;
 }
+
+static int
+_ext_is_imagetype(const char *ext)
+{
+   static const char  *const exts[] = {
+      "jpg", "jpeg", "gif", "png", "tif", "tiff",
+      "xpm", "ppm", "pgm", "pnm", "bmp", NULL
+   };
+   int                 i;
+
+   for (i = 0; exts[i]; i++)
+      if (!Estrcasecmp(exts[i], ext))
+	 return 1;
+
+   return 0;
+}
