@@ -46,7 +46,7 @@
 
 #define DEBUG_MENU_EVENTS 0
 
-#define MENU_UNLOAD_CHECK_IMTERVAL 300	/* Seconds */
+#define MENU_UNLOAD_CHECK_INTERVAL 300	/* Seconds */
 
 static struct {
    Menu               *first;
@@ -135,6 +135,7 @@ static void         MenusHide(void);
 
 static Ecore_List  *menu_list = NULL;
 static Ecore_List  *menu_style_list = NULL;
+static Timer       *menu_timer_submenu = NULL;
 
 static MenuItem    *
 MenuFindItemByChild(Menu * m, Menu * mc)
@@ -203,10 +204,10 @@ _MenuEwinInit(EWin * ewin)
    ewin->props.skip_winlist = 1;
    ewin->props.ignorearrange = 1;
    EwinInhSetWM(ewin, focus, 1);
-   ewin->client.grav = StaticGravity;
 
    ICCCM_SetSizeConstraints(ewin, m->w, m->h, m->w, m->h, 0, 0, 1, 1,
 			    0.0, 65535.0);
+   ewin->icccm.grav = StaticGravity;
 
    EoSetLayer(ewin, 12);
    ewin->ewmh.opacity = OpacityFromPercent(Conf.opacity.menus);
@@ -236,7 +237,9 @@ _MenuEwinMoveResize(EWin * ewin, int resize __UNUSED__)
 static void
 _MenuEwinClose(EWin * ewin)
 {
-   if ((Menu *) (ewin->data) == Mode_menus.active)
+   Menu               *m = (Menu *) ewin->data;
+
+   if (m == Mode_menus.active)
      {
 	GrabKeyboardRelease();
 	Mode_menus.active = NULL;
@@ -377,13 +380,6 @@ MenuShow(Menu * m, char noshow)
    m->ref_count++;
 }
 
-static void
-MenuStyleSetName(MenuStyle * ms, const char *name)
-{
-   Efree(ms->name);
-   ms->name = Estrdup(name);
-}
-
 static MenuStyle   *
 MenuStyleCreate(const char *name)
 {
@@ -397,8 +393,8 @@ MenuStyleCreate(const char *name)
       menu_style_list = ecore_list_new();
    ecore_list_prepend(menu_style_list, ms);
 
+   ms->name = Estrdup(name);
    ms->iconpos = ICON_LEFT;
-   MenuStyleSetName(ms, name);
 
    return ms;
 }
@@ -436,8 +432,28 @@ _MenuStyleMatchName(const void *data, const void *match)
 MenuStyle          *
 MenuStyleFind(const char *name)
 {
-   return (MenuStyle *) ecore_list_find(menu_style_list, _MenuStyleMatchName,
-					name);
+   MenuStyle          *ms;
+
+   ms = (MenuStyle *) ecore_list_find(menu_style_list, _MenuStyleMatchName,
+				      name);
+   if (ms)
+      return ms;
+
+   ms = (MenuStyle *) ecore_list_find(menu_style_list, _MenuStyleMatchName,
+				      "__fb_ms");
+   if (ms)
+      return ms;
+
+   ms = MenuStyleCreate("__fb_ms");
+   if (!ms)
+      return ms;
+
+   ms->tclass = TextclassFind(NULL, 1);
+   ms->bg_iclass = ImageclassFind(NULL, 1);
+   ms->item_iclass = ImageclassFind(NULL, 1);
+   ms->sub_iclass = ImageclassFind(NULL, 1);
+
+   return ms;
 }
 
 void
@@ -920,7 +936,7 @@ MenuRedraw(Menu * m)
 	EGetWindowBackgroundPixmap(m->win);
 	EXCopyAreaTiled(m->pmm.pmap, None, WinGetPmap(m->win),
 			0, 0, m->w, m->h, 0, 0);
-	EShapeCombineMask(m->win, ShapeBounding, 0, 0, m->pmm.mask, ShapeSet);
+	EShapeSetMask(m->win, 0, 0, m->pmm.mask);
 	EClearWindow(m->win);
 	for (i = 0; i < m->num; i++)
 	   MenuDrawItem(m, m->items[i], 0, -1);
@@ -995,7 +1011,7 @@ MenuDrawItem(Menu * m, MenuItem * mi, char shape, int state)
      }
 
    ESetWindowBackgroundPixmap(mi->win, mi_pmm->pmap);
-   EShapeCombineMask(mi->win, ShapeBounding, 0, 0, mi_pmm->mask, ShapeSet);
+   EShapeSetMask(mi->win, 0, 0, mi_pmm->mask);
    EClearWindow(mi->win);
 
    if ((shape) && (m->style->use_item_bg))
@@ -1017,9 +1033,9 @@ MenuShowMasker(Menu * m __UNUSED__)
 
 	EobjReparent(eo, EoObj(DesksGetCurrent()), 0, 0);
 	EobjSetLayer(eo, 11);
-	ESelectInput(eo->win, ButtonPressMask | ButtonReleaseMask |
+	ESelectInput(EobjGetWin(eo), ButtonPressMask | ButtonReleaseMask |
 		     EnterWindowMask | LeaveWindowMask);
-	EventCallbackRegister(eo->win, 0, MenuMaskerHandleEvents, NULL);
+	EventCallbackRegister(EobjGetWin(eo), 0, MenuMaskerHandleEvents, NULL);
 
 	Mode_menus.cover_win = eo;
      }
@@ -1035,7 +1051,7 @@ MenuHideMasker(void)
    if (!eo)
       return;
 
-   EventCallbackUnregister(eo->win, 0, MenuMaskerHandleEvents, NULL);
+   EventCallbackUnregister(EobjGetWin(eo), 0, MenuMaskerHandleEvents, NULL);
    EobjWindowDestroy(eo);
    Mode_menus.cover_win = NULL;
 }
@@ -1154,7 +1170,7 @@ MenusActive(void)
 static void
 MenusHide(void)
 {
-   RemoveTimerEvent("SUBMENU_SHOW");
+   TIMER_DEL(menu_timer_submenu);
 
    MenuHide(Mode_menus.first);
    Mode_menus.first = NULL;
@@ -1454,7 +1470,7 @@ MenusHandleMotion(void)
 
 		  if (Mode_menus.current_depth)
 		    {
-#ifdef HAVE_XINERAMA
+#ifdef USE_XINERAMA
 		       ewin = Mode_menus.list[0]->ewin;
 		       if (ewin->head == head_num)
 			 {
@@ -1481,7 +1497,7 @@ MenusHandleMotion(void)
 			    if (((xdist != 0) || (ydist != 0))
 				&& (Conf.menus.warp))
 			       EXWarpPointer(None, xdist, ydist);
-#ifdef HAVE_XINERAMA
+#ifdef USE_XINERAMA
 			 }
 #endif
 		    }
@@ -1549,8 +1565,8 @@ MenuSelectItemByChild(Menu * m, Menu * mc)
    MenuSelectItem(m, mi, 0);
 }
 
-static void
-SubmenuShowTimeout(int val __UNUSED__, void *dat)
+static int
+SubmenuShowTimeout(void *dat)
 {
    int                 mx, my, my2, xo, yo, mw;
    Menu               *m;
@@ -1561,35 +1577,33 @@ SubmenuShowTimeout(int val __UNUSED__, void *dat)
    int                 bl2, br2, bt2, bb2;
 
    data = (struct _mdata *)dat;
-   if (!data)
-      return;
-   if (!data->m)
-      return;
+   if (!data || !data->m)
+      goto done;
 
    m = data->m;
    if (!ecore_list_goto(menu_list, m))
-      return;
+      goto done;
    ewin = m->ewin;
    if (!ewin || !EwinFindByPtr(ewin))
-      return;
+      goto done;
    if (!EoIsShown(ewin))
-      return;
+      goto done;
 
    mi = data->mi;
    if (!mi)
-      return;
+      goto done;
 
    if (mi->child != m->child)
       MenuHide(m->child);
    m->child = mi->child;
    if (!mi->child)
-      return;
+      goto done;
 
    mi->child->parent = m;
    MenuShow(mi->child, 1);
    ewin2 = mi->child->ewin;
    if (!ewin2 || !EwinFindByPtr(ewin2))
-      return;
+      goto done;
 
    EGetGeometry(mi->win, NULL, &mx, &my, &mw, NULL, NULL, NULL);
    my2 = 0;
@@ -1664,6 +1678,10 @@ SubmenuShowTimeout(int val __UNUSED__, void *dat)
 
    if (Conf.menus.animate)
       EwinUnShade(ewin2);
+
+ done:
+   menu_timer_submenu = NULL;
+   return 0;
 }
 
 static void
@@ -1686,13 +1704,13 @@ MenuActivateItem(Menu * m, MenuItem * mi)
    if (mi && !mi->child && mi_prev && !mi_prev->child)
       return;
 
-   RemoveTimerEvent("SUBMENU_SHOW");
+   TIMER_DEL(menu_timer_submenu);
 
    if ((mi && mi->child && !mi->child->shown) || (mi && mi->child != m->child))
      {
 	mdata.m = m;
 	mdata.mi = mi;
-	DoIn("SUBMENU_SHOW", 0.2, SubmenuShowTimeout, 0, &mdata);
+	TIMER_ADD(menu_timer_submenu, 0.2, SubmenuShowTimeout, &mdata);
      }
 }
 
@@ -1863,6 +1881,12 @@ MenuConfigLoad(FILE * fs)
 	i1 = ConfigParseline1(s, s2, &p2, &p3);
 	switch (i1)
 	  {
+	  default:
+	     break;
+
+	  case CONFIG_VERSION:
+	     continue;
+
 	  case CONFIG_MENU:
 	     err = -1;
 	     i2 = atoi(s2);
@@ -1871,35 +1895,48 @@ MenuConfigLoad(FILE * fs)
 	     m = NULL;
 	     ic = NULL;
 	     _EFREE(txt);
-	     break;
+	     continue;
 	  case CONFIG_CLOSE:
 	     err = 0;
-	     break;
+	     continue;
 
 	  case MENU_PREBUILT:
 	     sscanf(p3, "%4000s %4000s %4000s", s3, s4, s5);
 	     m = MenusCreateInternal(s4, s2, s3, s5);
-	     break;
+	     continue;
+
 	  case CONFIG_CLASSNAME:
 	     if (!m)
 		m = MenuCreate(s2, NULL, NULL, NULL);
 	     else
 		MenuSetName(m, s2);
 	     params = _MenuCheckAlias(s2);
-	     if (params)
+	     if (m && params)
 		MenuSetAlias(m, params);
-	     break;
-	  case MENU_USE_STYLE:
-	     MenuSetStyle(m, MenuStyleFind(s2));
-	     break;
-	  case MENU_TITLE:
-	     MenuSetTitle(m, p2);
-	     break;
+	     continue;
+
 	  case MENU_ITEM:
 	     ic = NULL;
 	     if (strcmp("NULL", s2))
 		ic = ImageclassFind(s2, 0);
 	     _EFDUP(txt, p3);
+	     continue;
+	  }
+
+	/* The rest require the menu m to be created */
+	if (!m)
+	  {
+	     ConfigParseError("Menu", s);
+	     continue;
+	  }
+
+	switch (i1)
+	  {
+	  case MENU_USE_STYLE:
+	     MenuSetStyle(m, MenuStyleFind(s2));
+	     break;
+	  case MENU_TITLE:
+	     MenuSetTitle(m, p2);
 	     break;
 	  case MENU_ACTION:
 	     if ((txt) || (ic))
@@ -1927,7 +1964,7 @@ MenuConfigLoad(FILE * fs)
 	     sscanf(p3, "%s %n", s3, &len);
 	     ic = NULL;
 	     if (strcmp("NULL", s3))
-		ic = ImageclassFind(s3, 0);
+		ic = ImageclassFind(s3, 1);
 	     mm = MenuFind(s2, NULL);
 	     mi = MenuItemCreate(p3 + len, ic, NULL, mm);
 	     MenuAddItem(m, mi);
@@ -1945,8 +1982,8 @@ MenuConfigLoad(FILE * fs)
    return err;
 }
 
-static void
-MenusTimeout(int val __UNUSED__, void *data __UNUSED__)
+static int
+MenusTimeout(void *data __UNUSED__)
 {
    Menu               *m;
    time_t              ts;
@@ -1956,7 +1993,7 @@ MenusTimeout(int val __UNUSED__, void *data __UNUSED__)
    ECORE_LIST_FOR_EACH(menu_list, m)
    {
       if (m->shown || !m->filled ||
-	  ts - m->last_access < MENU_UNLOAD_CHECK_IMTERVAL)
+	  ts - m->last_access < MENU_UNLOAD_CHECK_INTERVAL)
 	 continue;
 
       m->last_change = 0;
@@ -1968,7 +2005,7 @@ MenusTimeout(int val __UNUSED__, void *data __UNUSED__)
 	 MenuDestroy(m);
    }
 
-   DoIn("MenusCheck", 1. * MENU_UNLOAD_CHECK_IMTERVAL, MenusTimeout, 0, NULL);
+   return 1;
 }
 
 /*
@@ -1978,6 +2015,8 @@ MenusTimeout(int val __UNUSED__, void *data __UNUSED__)
 static void
 MenusSighan(int sig, void *prm __UNUSED__)
 {
+   Timer              *menu_unload_timer;
+
    switch (sig)
      {
      case ESIGNAL_CONFIGURE:
@@ -1985,8 +2024,8 @@ MenusSighan(int sig, void *prm __UNUSED__)
 	break;
 
      case ESIGNAL_START:
-	DoIn("MenusCheck", 1. * MENU_UNLOAD_CHECK_IMTERVAL, MenusTimeout, 0,
-	     NULL);
+	TIMER_ADD(menu_unload_timer, 1. * MENU_UNLOAD_CHECK_INTERVAL,
+		  MenusTimeout, NULL);
 	break;
 
      case ESIGNAL_AREA_SWITCH_START:
@@ -2056,7 +2095,7 @@ const DialogDef     DlgMenus = {
    "CONFIGURE_MENUS",
    N_("Menus"),
    N_("Menu Settings"),
-   "SOUND_SETTINGS_MENUS",
+   SOUND_SETTINGS_MENUS,
    "pix/place.png",
    N_("Enlightenment Menu\n" "Settings Dialog\n"),
    _DlgFillMenus,
@@ -2084,10 +2123,6 @@ MenusIpc(const char *params)
      {
 	IpcPrintf("Menus - active=%d\n", MenusActive());
      }
-   else if (!strncmp(cmd, "cfg", 2))
-     {
-	DialogShowSimple(&DlgMenus, NULL);
-     }
    else if (!strncmp(cmd, "list", 2))
      {
 #define SS(s) ((s) ? (s) : "-")
@@ -2110,7 +2145,7 @@ MenusIpc(const char *params)
 	     Esnprintf(prm, sizeof(prm), "%s", p);
 	     p = NULL;
 	  }
-	SoundPlay("SOUND_MENU_SHOW");
+	SoundPlay(SOUND_MENU_SHOW);
 	MenusShowNamed(prm, p);
      }
 }
