@@ -93,9 +93,9 @@ typedef struct {
    int                 screen_w, screen_h;
    int                 update_phase;
    Win                 sel_win;
+   Timer              *scan_timer;
 
    /* State flags */
-   char                scan_pending;
    char                do_newbg;
    char                do_update;
    int                 x1, y1, x2, y2;
@@ -105,7 +105,7 @@ typedef struct {
 } Pager;
 
 static void         PagerScanCancel(Pager * p);
-static void         PagerScanTimeout(int val, void *data);
+static int          PagerScanTimeout(void *data);
 static void         PagerCheckUpdate(Pager * p, void *prm);
 static void         PagerUpdateEwinsFromPager(Pager * p);
 static void         PagerHiwinHide(void);
@@ -158,7 +158,6 @@ PagerDestroy(Pager * p)
 
    PagerScanCancel(p);
    Efree(p->name);
-   EDestroyWindow(p->win);
    PagerHiwinHide();
    if (p->bgpmap != None)
       EFreePixmap(p->bgpmap);
@@ -169,31 +168,21 @@ PagerDestroy(Pager * p)
 static void
 PagerScanTrig(Pager * p)
 {
-   char                s[128];
-
-   if (p->scan_pending || Conf_pagers.scanspeed <= 0)
+   if (p->scan_timer || Conf_pagers.scanspeed <= 0)
       return;
 
-   Esnprintf(s, sizeof(s), "pg-scan.%x", (unsigned)WinGetXwin(p->win));
-   DoIn(s, 1 / ((double)Conf_pagers.scanspeed), PagerScanTimeout, 0, p);
-   p->scan_pending = 1;
+   TIMER_ADD(p->scan_timer, 1 / ((double)Conf_pagers.scanspeed),
+	     PagerScanTimeout, p);
 }
 
 static void
 PagerScanCancel(Pager * p)
 {
-   char                s[128];
-
-   if (!p->scan_pending)
-      return;
-   p->scan_pending = 0;
-
-   Esnprintf(s, sizeof(s), "pg-scan.%x", (unsigned)WinGetXwin(p->win));
-   RemoveTimerEvent(s);
+   TIMER_DEL(p->scan_timer);
 }
 
-static void
-PagerScanTimeout(int val __UNUSED__, void *data)
+static int
+PagerScanTimeout(void *data)
 {
    Pager              *p;
    EWin               *ewin;
@@ -201,25 +190,24 @@ PagerScanTimeout(int val __UNUSED__, void *data)
    static int          offsets[8] = { 0, 4, 2, 6, 1, 5, 3, 7 };
    int                 pager_mode = PagersGetMode();
 
-   if (pager_mode != PAGER_MODE_SNAP)
-      return;
-
    p = (Pager *) data;
-   p->scan_pending = 0;
+
+   if (pager_mode != PAGER_MODE_SNAP)
+      goto nomore;
 
    ewin = p->ewin;
    if (!ewin || !EoIsShown(ewin))
-      return;
+      goto nomore;
    if (p->dsk != DesksGetCurrent())
-      return;
+      goto nomore;
    if (ewin->state.visibility == VisibilityFullyObscured)
-      return;
+      goto nomore;
 
-   if (Conf_pagers.scanspeed > 0)
-      PagerScanTrig(p);
+   if (Conf_pagers.scanspeed <= 0)
+      goto nomore;
 
    if (Mode.mode != MODE_NONE)
-      return;
+      goto nomore;
 
    DeskCurrentGetArea(&cx, &cy);
    ww = p->dw;
@@ -228,7 +216,7 @@ PagerScanTimeout(int val __UNUSED__, void *data)
    yy = cy * hh;
    phase = p->update_phase;
    if (ww <= 0 || hh <= 0)
-      return;
+      goto nomore;
 
 #if 0
    /* Due to a bug in imlib2 <= 1.2.0 we have to scan left->right in stead
@@ -255,6 +243,13 @@ PagerScanTimeout(int val __UNUSED__, void *data)
 	PagerUpdateEwinsFromPager(p);
 	p->update_phase = 0;
      }
+
+   TimerSetInterval(p->scan_timer, 1 / ((double)Conf_pagers.scanspeed));
+   return 1;
+
+ nomore:
+   p->scan_timer = NULL;
+   return 0;
 }
 
 #if 0				/* FIXME - Remove? */
@@ -331,7 +326,7 @@ PagerEwinUpdateMini(Pager * p, EWin * ewin)
      {
 	ImageClass         *ic;
 
-	ic = ImageclassFind("PAGER_WIN", 0);
+	ic = ImageclassFind("PAGER_WIN", 1);
 	ImageclassApplySimple(ic, p->win, ewin->mini_pmm.pmap,
 			      STATE_NORMAL, 0, 0, w, h);
 	Dprintf("Use Iclass, pmap=%#lx\n", ewin->mini_pmm.pmap);
@@ -599,7 +594,7 @@ PagerUpdateBg(Pager * p)
 	return;
      }
 
-   ic = ImageclassFind("PAGER_BACKGROUND", 0);
+   ic = ImageclassFind("PAGER_BACKGROUND", 1);
    if (ic)
      {
 	ImageclassApplySimple(ic, p->win, pmap, STATE_NORMAL,
@@ -683,7 +678,6 @@ static void
 _PagerEwinClose(EWin * ewin)
 {
    PagerDestroy((Pager *) ewin->data);
-   ewin->client.win = NULL;
    ewin->data = NULL;
 }
 
@@ -821,10 +815,12 @@ PagerCheckUpdate(Pager * p, void *prm __UNUSED__)
    p->do_newbg = p->do_update = 0;
 }
 
-static void
-_PagersUpdateTimeout(int val __UNUSED__, void *data __UNUSED__)
+static int
+_PagersUpdateTimeout(void *data __UNUSED__)
 {
    Mode_pagers.timer_pending = 0;
+
+   return 0;
 }
 
 static void
@@ -832,6 +828,7 @@ PagersCheckUpdate(void)
 {
    static double       tlast = 0.;
    double              t, dt;
+   Timer              *pager_update_timer;
 
    if (!Mode_pagers.update_pending || !Conf_pagers.enable)
       return;
@@ -844,7 +841,7 @@ PagersCheckUpdate(void)
 	  {
 	     /* The purpose of this timer is to trigger the idler */
 	     if (!Mode_pagers.timer_pending)
-		DoIn("pg-upd", dt, _PagersUpdateTimeout, 0, NULL);
+		TIMER_ADD(pager_update_timer, dt, _PagersUpdateTimeout, NULL);
 	     Mode_pagers.timer_pending = 1;
 	     return;
 	  }
@@ -1032,7 +1029,7 @@ PagerMenuShow(Pager * p, int x, int y)
       MenuDestroy(p_menu);
    p_menu = MenuCreate("__DESK_MENU", _("Desktop Options"), NULL, NULL);
 
-   mi = MenuItemCreate(_("Pager Settings..."), NULL, "pg cfg", NULL);
+   mi = MenuItemCreate(_("Pager Settings..."), NULL, "cfg pagers", NULL);
    MenuAddItem(p_menu, mi);
 
    if (PagersGetMode() != PAGER_MODE_SIMPLE)
@@ -1284,7 +1281,6 @@ PagerSetHiQ(char onoff)
 static void
 _PagerSetSnap(Pager * p, void *prm __UNUSED__)
 {
-   p->scan_pending = 0;
    PagerScanTrig(p);
 }
 
@@ -1432,7 +1428,7 @@ PagerHandleMouseDown(Pager * p, int px, int py, int button)
    else if (button == Conf_pagers.win_button)
      {
 	ewin = EwinInPagerAt(p, px, py);
-	if ((ewin) && (ewin->type != EWIN_TYPE_PAGER))
+	if (ewin && ewin->type != EWIN_TYPE_PAGER && !ewin->state.inhibit_move)
 	  {
 	     PagerHiwinShow(p, ewin, 1, !Mode.wm.window);
 	     Mode.mode = MODE_PAGER_DRAG_PENDING;
@@ -1461,7 +1457,7 @@ PagerHandleMouseUp(Pager * p, int px, int py, int button)
      {
 	DeskGoto(p->dsk);
 	if (p->dsk != DesksGetCurrent())
-	   SoundPlay("SOUND_DESKTOP_SHUT");
+	   SoundPlay(SOUND_DESKTOP_SHUT);
 	DeskCurrentGotoArea(px / p->dw, py / p->dh);
      }
    else if (button == Conf_pagers.win_button)
@@ -1729,7 +1725,7 @@ PagersShow(int enable)
 	for (i = 0; i < DesksGetNumber(); i++)
 	   PagersForDesktopEnable(DeskGet(i));
 	UpdatePagerSel();
-	Mode_pagers.idler = IdlerAdd(50, _PagersIdler, NULL);
+	Mode_pagers.idler = IdlerAdd(_PagersIdler, NULL);
      }
    else if (!enable && Conf_pagers.enable)
      {
@@ -1747,19 +1743,23 @@ _PagerReconfigure(Pager * p, void *prm __UNUSED__)
    PagerReconfigure(p, 1);
 }
 
-static void
-_PagersReconfigureTimeout(int val __UNUSED__, void *data __UNUSED__)
+static int
+_PagersReconfigureTimeout(void *data __UNUSED__)
 {
    PagersForeach(NULL, _PagerReconfigure, NULL);
+
+   return 0;
 }
 
 static void
 PagersReconfigure(void)
 {
+   Timer              *pg_timer_cfg;
+
    if (!Conf_pagers.enable)
       return;
 
-   DoIn("pg-cfg", .5, _PagersReconfigureTimeout, 0, NULL);
+   TIMER_ADD(pg_timer_cfg, .5, _PagersReconfigureTimeout, NULL);
 }
 
 /*
@@ -1992,7 +1992,7 @@ const DialogDef     DlgPagers = {
    "CONFIGURE_PAGER",
    N_("Pagers"),
    N_("Pager Settings"),
-   "SOUND_SETTINGS_PAGER",
+   SOUND_SETTINGS_PAGER,
    "pix/pager.png",
    N_("Enlightenment Desktop & Area\n" "Pager Settings Dialog\n"),
    _DlgFillPagers,
@@ -2083,11 +2083,7 @@ IPC_Pager(const char *params)
    sscanf(p, "%100s %n", prm1, &len);
    p += len;
 
-   if (!strncmp(prm1, "cfg", 3))
-     {
-	DialogShowSimple(&DlgPagers, NULL);
-     }
-   else if (!strcmp(prm1, "on"))
+   if (!strcmp(prm1, "on"))
      {
 	PagersShow(1);
      }
@@ -2152,7 +2148,6 @@ static const IpcItem PagersIpcArray[] = {
     "use \"pager <on/off>\" to set the current mode\nuse \"pager ?\" "
     "to get the current mode\n"
     "  pager <#> <on/off/?>   Toggle or test any desktop's pager\n"
-    "  pager cfg              Configure pagers\n"
     "  pager hiq <on/off>     Toggle high quality pager\n"
     "  pager scanrate <#>     Toggle number of line updates per second\n"
     "  pager mode <mode>      Set pager mode (simple/snapshot/live)\n"
