@@ -101,7 +101,7 @@ set_save_props(SmcConn smc_conn, int master_flag)
    SmProp              styleProp;
    SmProp              priorityProp;
    SmProp             *props[7];
-   char                bufs[32], bufm[32], bufx[32];
+   char                bufs[32], bufm[32];
 
    if (EDebug(EDBUG_TYPE_SESSION))
       Eprintf("set_save_props\n");
@@ -192,6 +192,8 @@ set_save_props(SmcConn smc_conn, int master_flag)
 #ifdef USE_EXT_INIT_WIN
    if (restarting)
      {
+	char                bufx[32];
+
 	Esnprintf(bufx, sizeof(bufx), "%#lx", new_init_win_ext);
 	restartVal[n++].value = (char *)"-X";
 	restartVal[n++].value = bufx;
@@ -338,12 +340,12 @@ ice_msgs_process(void)
    if (status == IceProcessMessagesIOError)
      {
 	/* Less of the hope.... E survives */
-	DialogAlert(_("ERROR!\n" "\n"
-		      "Lost the Session Manager that was there?\n"
-		      "Here here session manager... come here... want a bone?\n"
-		      "Oh come now! Stop sulking! Bugger. Oh well. "
-		      "Will continue without\n" "a session manager.\n" "\n"
-		      "I'll survive somehow.\n" "\n" "\n" "... I hope.\n"));
+	Alert(_("ERROR!\n" "\n"
+		"Lost the Session Manager that was there?\n"
+		"Here here session manager... come here... want a bone?\n"
+		"Oh come now! Stop sulking! Bugger. Oh well. "
+		"Will continue without\n" "a session manager.\n" "\n"
+		"I'll survive somehow.\n" "\n" "\n" "... I hope.\n"));
 	ice_exit();
      }
 }
@@ -440,7 +442,7 @@ SessionInit(void)
 }
 
 void
-SessionGetInfo(EWin * ewin)
+SessionGetInfo(EWin * ewin __UNUSED__)
 {
 #if 0				/* Unused */
 #if USE_SM
@@ -455,7 +457,6 @@ SessionGetInfo(EWin * ewin)
    ewin = NULL;
 #endif /* USE_SM */
 #endif
-   ewin = NULL;
 }
 
 void
@@ -474,7 +475,7 @@ SessionSave(int shutdown)
    if (EDebug(EDBUG_TYPE_SESSION))
       Eprintf("SessionSave(%d)\n", shutdown);
 
-   Real_SaveSnapInfo(0, NULL);
+   SnapshotsSaveReal(NULL);
 
 #if USE_SM
    if (shutdown && sm_conn)
@@ -491,7 +492,7 @@ SessionSave(int shutdown)
  * and then restore it on restart. We grab X input via the ext_init_win
  * so the our clients remain frozen while we are down.
  */
-static void
+__NORETURN__ static void
 doSMExit(int mode, const char *params)
 {
    int                 l;
@@ -526,7 +527,7 @@ doSMExit(int mode, const char *params)
    switch (mode)
      {
      case EEXIT_EXEC:
-	SoundPlay("SOUND_EXIT");
+	SoundPlay(SOUND_EXIT);
 	EDisplayClose();
 
 	Esnprintf(s, sizeof(s), "exec %s", params);
@@ -538,7 +539,7 @@ doSMExit(int mode, const char *params)
      case EEXIT_THEME:
 	ss = params;
      case EEXIT_RESTART:
-	SoundPlay("SOUND_WAIT");
+	SoundPlay(SOUND_WAIT);
 #ifdef USE_EXT_INIT_WIN
 	if (disp && !Mode.wm.window)
 	   new_init_win_ext = ExtInitWinCreate();
@@ -561,7 +562,7 @@ doSMExit(int mode, const char *params)
 #endif
 #ifdef USE_EXT_INIT_WIN
 	if (new_init_win_ext != None)
-	   l += Esnprintf(s + l, sizeof(s) - l, " -X %li", new_init_win_ext);
+	   l += Esnprintf(s + l, sizeof(s) - l, " -X %#lx", new_init_win_ext);
 #endif
 	if (ss)
 	   l += Esnprintf(s + l, sizeof(s) - l, " -t %s", ss);
@@ -574,7 +575,7 @@ doSMExit(int mode, const char *params)
      }
 
    restarting = False;
-   SoundPlay("SOUND_EXIT");
+   SoundPlay(SOUND_EXIT);
    EExit(0);
 }
 
@@ -635,7 +636,7 @@ SessionLogoutConfirm(void)
    d = DialogFind("LOGOUT_DIALOG");
    if (!d)
      {
-	SoundPlay("SOUND_LOGOUT");
+	SoundPlay(SOUND_LOGOUT);
 	d = DialogCreate("LOGOUT_DIALOG");
 	table = DialogInitItem(d);
 	DialogSetTitle(d, _("Are you sure?"));
@@ -806,7 +807,7 @@ const DialogDef     DlgSession = {
    "CONFIGURE_SESSION",
    N_("Session"),
    N_("Session Settings"),
-   "SOUND_SETTINGS_SESSION",
+   SOUND_SETTINGS_SESSION,
    "pix/miscellaneous.png",
    N_("Enlightenment Session\n" "Settings Dialog\n"),
    _DlgFillSession,
