@@ -29,6 +29,7 @@ static int          tmp_move;
 static int          tmp_resize;
 static int          tmp_geominfo;
 static int          tmp_maximize;
+static char         tmp_dragbar_nocover;
 static char         tmp_avoid_server_grab;
 static char         tmp_update_while_moving;
 static char         tmp_sync_request;
@@ -45,6 +46,7 @@ CB_ConfigureMoveResize(Dialog * d __UNUSED__, int val, void *data __UNUSED__)
 	Conf.movres.avoid_server_grab = tmp_avoid_server_grab;
 	Conf.movres.update_while_moving = tmp_update_while_moving;
 	Conf.movres.enable_sync_request = tmp_sync_request;
+	Conf.movres.dragbar_nocover = tmp_dragbar_nocover;
      }
    autosave();
 }
@@ -61,6 +63,7 @@ _DlgFillMoveResize(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
    tmp_avoid_server_grab = Conf.movres.avoid_server_grab;
    tmp_update_while_moving = Conf.movres.update_while_moving;
    tmp_sync_request = Conf.movres.enable_sync_request;
+   tmp_dragbar_nocover = Conf.movres.dragbar_nocover;
 
    DialogItemTableSetOptions(table, 2, 0, 0, 0);
 
@@ -206,13 +209,18 @@ _DlgFillMoveResize(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
    DialogItemSetColSpan(di, 2);
    DialogItemSetText(di, _("Synchronize move/resize with application"));
    DialogItemCheckButtonSetPtr(di, &tmp_sync_request);
+
+   di = DialogAddItem(table, DITEM_CHECKBUTTON);
+   DialogItemSetColSpan(di, 2);
+   DialogItemSetText(di, _("Do not cover dragbar"));
+   DialogItemCheckButtonSetPtr(di, &tmp_dragbar_nocover);
 }
 
 const DialogDef     DlgMoveResize = {
    "CONFIGURE_MOVERESIZE",
    N_("Move/Resize"),
    N_("Move & Resize Settings"),
-   "SOUND_SETTINGS_MOVERESIZE",
+   SOUND_SETTINGS_MOVERESIZE,
    "pix/moveres.png",
    N_("Enlightenment Move & Resize\n" "Method Settings Dialog\n"),
    _DlgFillMoveResize,
@@ -234,7 +242,7 @@ static int          tmp_shade_speed;
 static char         tmp_place_ignore_struts;
 static char         tmp_raise_fullscreen;
 
-#ifdef HAVE_XINERAMA
+#ifdef USE_XINERAMA
 static char         tmp_extra_head;
 #endif
 
@@ -261,7 +269,7 @@ CB_ConfigurePlacement(Dialog * d __UNUSED__, int val, void *data __UNUSED__)
 
 	Conf.place.ignore_struts = tmp_place_ignore_struts;
 	Conf.place.raise_fullscreen = tmp_raise_fullscreen;
-#ifdef HAVE_XINERAMA
+#ifdef USE_XINERAMA
 	if (Mode.display.xinerama_active)
 	   Conf.place.extra_head = tmp_extra_head;
 #endif
@@ -293,7 +301,7 @@ _DlgFillPlacement(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
    tmp_place_ignore_struts = Conf.place.ignore_struts;
    tmp_raise_fullscreen = Conf.place.raise_fullscreen;
 
-#ifdef HAVE_XINERAMA
+#ifdef USE_XINERAMA
    tmp_extra_head = Conf.place.extra_head;
 #endif
 
@@ -423,7 +431,7 @@ _DlgFillPlacement(Dialog * d __UNUSED__, DItem * table, void *data __UNUSED__)
    DialogItemSetText(di, _("Raise fullscreen windows"));
    DialogItemCheckButtonSetPtr(di, &tmp_raise_fullscreen);
 
-#ifdef HAVE_XINERAMA_no		/* Not implemented */
+#ifdef USE_XINERAMA_no		/* Not implemented */
    if (Mode.display.xinerama_active)
      {
 	di = DialogAddItem(table, DITEM_CHECKBUTTON);
@@ -438,7 +446,7 @@ const DialogDef     DlgPlacement = {
    "CONFIGURE_PLACEMENT",
    N_("Placement"),
    N_("Window Placement Settings"),
-   "SOUND_SETTINGS_PLACEMENT",
+   SOUND_SETTINGS_PLACEMENT,
    "pix/place.png",
    N_("Enlightenment Window Placement\n" "Settings Dialog\n"),
    _DlgFillPlacement,
@@ -490,7 +498,7 @@ const DialogDef     DlgAutoraise = {
    "CONFIGURE_AUTORAISE",
    N_("Autoraise"),
    N_("Autoraise Settings"),
-   "SOUND_SETTINGS_AUTORAISE",
+   SOUND_SETTINGS_AUTORAISE,
    "pix/raise.png",
    N_("Enlightenment Automatic Raising\n" "of Windows Settings Dialog\n"),
    _DlgFillAutoraise,
@@ -560,7 +568,7 @@ const DialogDef     DlgMisc = {
    "CONFIGURE_MISCELLANEOUS",
    N_("Miscellaneous"),
    N_("Miscellaneous Settings"),
-   "SOUND_SETTINGS_MISCELLANEOUS",
+   SOUND_SETTINGS_MISCELLANEOUS,
    "pix/miscellaneous.png",
    N_("Enlightenment Miscellaneous\n" "Settings Dialog\n"),
    _DlgFillMisc,
@@ -694,18 +702,12 @@ const DialogDef     DlgComposite = {
    "CONFIGURE_COMPOSITE",
    N_("Composite"),
    N_("Composite Settings"),
-   "SOUND_SETTINGS_COMPOSITE",
+   SOUND_SETTINGS_COMPOSITE,
    "pix/pager.png",
    N_("Enlightenment Composite\n" "Settings Dialog\n"),
    _DlgFillComposite,
    DLG_OAC, CB_ConfigureComposite,
 };
-
-void
-SettingsComposite(void)
-{
-   DialogShowSimple(&DlgComposite, NULL);
-}
 #endif
 
 /*
@@ -729,7 +731,9 @@ static const DialogDef *dialogs[] = {
    &DlgRemember,
    &DlgFx,
    &DlgBackground,
+#ifdef ENABLE_THEME_TRANSPARENCY
    &DlgThemeTrans,
+#endif
 #if USE_COMPOSITE
    &DlgComposite,
 #endif
@@ -786,7 +790,7 @@ static const DialogDef DlgConfiguration = {
    "CONFIGURE_ALL",
    NULL,
    N_("Enlightenment Settings"),
-   "SOUND_SETTINGS_ALL",
+   SOUND_SETTINGS_ALL,
    NULL,
    NULL,
    _DlgFillConfiguration,
@@ -794,7 +798,22 @@ static const DialogDef DlgConfiguration = {
 };
 
 void
-SettingsConfiguration(void)
+IPC_Cfg(const char *params)
 {
-   DialogShowSimple(&DlgConfiguration, NULL);
+   unsigned int        i;
+   const char         *name;
+
+   if (!params || !params[0])
+     {
+	DialogShowSimple(&DlgConfiguration, NULL);
+	return;
+     }
+
+   for (i = 0; i < N_CFG_DLGS; i++)
+     {
+	name = dialogs[i]->label;
+	if (strcasecmp(params, name))
+	   continue;
+	DialogShowSimple(dialogs[i], NULL);
+     }
 }
