@@ -28,6 +28,9 @@
 #include "emodule.h"
 #include "settings.h"
 #include "sound.h"
+#include "sounds.h"
+
+#define N_SOUNDS (SOUND_NOT_USED - 1)
 
 typedef struct {
    char               *name;
@@ -40,8 +43,16 @@ typedef struct {
 static struct {
    char                enable;
    char               *theme;
+   unsigned int        mask1, mask2;
 } Conf_sound;
 
+static struct {
+   char                cfg_loaded;
+   char               *theme_path;
+} Mode_sound;
+
+#define SOUND_THEME_PATH ((Mode_sound.theme_path) ? Mode_sound.theme_path : Mode.theme.path)
+
 static Ecore_List  *sound_list = NULL;
 
 #if USE_MODULES
@@ -56,6 +67,70 @@ static const SoundOps *ops = &SoundOps_pa;
 #endif
 #endif
 
+static void         _SoundConfigLoad(void);
+
+static const char  *const sound_names[N_SOUNDS] = {
+   "SOUND_ALERT",		/*  0 0x00000001 */
+   "SOUND_BUTTON_CLICK",
+   "SOUND_BUTTON_RAISE",
+   "SOUND_DEICONIFY",
+   "SOUND_DESKTOP_LOWER",	/*  4 0x00000010 */
+   "SOUND_DESKTOP_RAISE",
+   "SOUND_DESKTOP_SHUT",
+   "SOUND_ERROR_IPC",
+   "SOUND_EXIT",		/*  8 0x00000100 */
+   "SOUND_FOCUS_SET",
+   "SOUND_ICONIFY",
+   "SOUND_INSERT_KEYS",
+   "SOUND_LOGOUT",		/* 12 0x00001000 */
+   "SOUND_LOWER",
+   "SOUND_MENU_SHOW",
+   "SOUND_MOVE_AREA_DOWN",
+   "SOUND_MOVE_AREA_LEFT",	/* 16 0x00010000 */
+   "SOUND_MOVE_AREA_RIGHT",
+   "SOUND_MOVE_AREA_UP",
+   "SOUND_MOVE_RESIST",
+   "SOUND_MOVE_START",		/* 20 0x00100000 */
+   "SOUND_MOVE_STOP",
+   "SOUND_RAISE",
+   "SOUND_RESIZE_START",
+   "SOUND_RESIZE_STOP",		/* 24 0x01000000 */
+   "SOUND_SCANNING",
+   "SOUND_SETTINGS_ACTIVE",
+   "SOUND_SETTINGS_ALL",
+   "SOUND_SETTINGS_AREA",	/* 28 0x10000000 */
+   "SOUND_SETTINGS_AUDIO",
+   "SOUND_SETTINGS_AUTORAISE",
+   "SOUND_SETTINGS_BG",
+   "SOUND_SETTINGS_COMPOSITE",	/*  0 0x00000001 */
+   "SOUND_SETTINGS_DESKTOPS",
+   "SOUND_SETTINGS_FOCUS",
+   "SOUND_SETTINGS_FX",
+   "SOUND_SETTINGS_GROUP",	/*  4 0x00000010 */
+   "SOUND_SETTINGS_ICONBOX",
+   "SOUND_SETTINGS_MENUS",
+   "SOUND_SETTINGS_MISCELLANEOUS",
+   "SOUND_SETTINGS_MOVERESIZE",	/*  8 0x00000100 */
+   "SOUND_SETTINGS_PAGER",
+   "SOUND_SETTINGS_PLACEMENT",
+   "SOUND_SETTINGS_SESSION",
+   "SOUND_SETTINGS_TOOLTIPS",	/* 12 0x00001000 */
+   "SOUND_SETTINGS_TRANS",
+   "SOUND_SHADE",
+   "SOUND_SLIDEOUT_SHOW",
+   "SOUND_STARTUP",		/* 16 0x00010000 */
+   "SOUND_UNSHADE",
+   "SOUND_WAIT",
+   "SOUND_WINDOW_BORDER_CHANGE",
+   "SOUND_WINDOW_CHANGE_LAYER_DOWN",	/* 20 0x00100000 */
+   "SOUND_WINDOW_CHANGE_LAYER_UP",
+   "SOUND_WINDOW_CLOSE",
+   "SOUND_WINDOW_SLIDE",
+   "SOUND_WINDOW_SLIDE_END",	/* 24 0x01000000 */
+   "SOUND_WINDOW_STICK",
+   "SOUND_WINDOW_UNSTICK",
+};
+
 static void
 _SclassSampleDestroy(void *data, void *user_data __UNUSED__)
 {
@@ -103,6 +178,12 @@ SclassDestroy(SoundClass * sclass)
    Efree(sclass);
 }
 
+static void
+_SclassDestroy(void *data, void *user_data __UNUSED__)
+{
+   SclassDestroy((SoundClass *) data);
+}
+
 static void
 SclassApply(SoundClass * sclass)
 {
@@ -113,7 +194,7 @@ SclassApply(SoundClass * sclass)
      {
 	char               *file;
 
-	file = FindFile(sclass->file, Mode.theme.path, 0);
+	file = FindFile(sclass->file, SOUND_THEME_PATH);
 	if (file)
 	  {
 	     sclass->sample = ops->SampleLoad(file);
@@ -147,8 +228,8 @@ SclassFind(const char *name)
    return (SoundClass *) ecore_list_find(sound_list, _SclassMatchName, name);
 }
 
-void
-SoundPlay(const char *name)
+static void
+_SoundPlayByName(const char *name)
 {
    SoundClass         *sclass;
 
@@ -166,6 +247,24 @@ SoundPlay(const char *name)
    SclassApply(sclass);
 }
 
+#define _SoundMasked(i) \
+    (((i) <= 32) ? Conf_sound.mask1 & (1 << ((i) - 1)) : \
+                   Conf_sound.mask2 & (1 << ((i) - 1)))
+void
+SoundPlay(int sound)
+{
+   if (!Conf_sound.enable)
+      return;
+
+   if (sound <= 0 || sound > N_SOUNDS)
+      return;
+
+   if (_SoundMasked(sound))
+      return;
+
+   _SoundPlayByName(sound_names[sound - 1]);
+}
+
 static int
 SoundFree(const char *name)
 {
@@ -205,6 +304,8 @@ SoundInit(void)
 		 "communicating with the audio server (Esound). Audio will\n"
 		 "now be disabled.\n"));
      }
+
+   _SoundConfigLoad();
 }
 
 static void
@@ -223,7 +324,7 @@ SoundExit(void)
  */
 
 static int
-SoundConfigLoad(FILE * fs)
+_SoundConfigParse(FILE * fs)
 {
    int                 err = 0;
    SoundClass         *sc;
@@ -254,6 +355,39 @@ SoundConfigLoad(FILE * fs)
    return err;
 }
 
+static void
+_SoundConfigLoad(void)
+{
+   if (Mode_sound.cfg_loaded)
+      return;
+   Mode_sound.cfg_loaded = 1;
+
+   Efree(Mode_sound.theme_path);
+   if (Conf_sound.theme)
+      Mode_sound.theme_path = ThemeFind(Conf_sound.theme);
+   else
+      Mode_sound.theme_path = NULL;
+
+   ConfigFileLoad("sound.cfg", SOUND_THEME_PATH, _SoundConfigParse, 1);
+}
+
+static void
+_SoundConfigUnload(void)
+{
+   ecore_list_for_each(sound_list, _SclassDestroy, NULL);
+   Mode_sound.cfg_loaded = 0;
+}
+
+static void
+_SoundThemeChange(void *item __UNUSED__, const char *theme)
+{
+   if (*theme == '\0')
+      theme = NULL;
+   _SoundConfigUnload();
+   _EFDUP(Conf_sound.theme, theme);
+   _SoundConfigLoad();
+}
+
 /*
  * Sound module
  */
@@ -264,15 +398,15 @@ SoundSighan(int sig, void *prm __UNUSED__)
    switch (sig)
      {
      case ESIGNAL_INIT:
-	SoundInit();
+	memset(&Mode_sound, 0, sizeof(Mode_sound));
 	break;
      case ESIGNAL_CONFIGURE:
-	ConfigFileLoad("sound.cfg", Mode.theme.path, SoundConfigLoad, 1);
+	SoundInit();
 	break;
      case ESIGNAL_START:
 	if (!Conf_sound.enable)
 	   break;
-	SoundPlay("SOUND_STARTUP");
+	SoundPlay(SOUND_STARTUP);
 	SoundFree("SOUND_STARTUP");
 	break;
      case ESIGNAL_EXIT:
@@ -321,7 +455,7 @@ const DialogDef     DlgSound = {
    "CONFIGURE_AUDIO",
    N_("Sound"),
    N_("Audio Settings"),
-   "SOUND_SETTINGS_AUDIO",
+   SOUND_SETTINGS_AUDIO,
    "pix/sound.png",
    N_("Enlightenment Audio\n" "Settings Dialog\n"),
    _DlgFillSound,
@@ -349,11 +483,7 @@ SoundIpc(const char *params)
 	p += len;
      }
 
-   if (!strncmp(cmd, "cfg", 3))
-     {
-	DialogShowSimple(&DlgSound, NULL);
-     }
-   else if (!strncmp(cmd, "del", 3))
+   if (!strncmp(cmd, "del", 3))
      {
 	SoundFree(prm);
      }
@@ -378,7 +508,7 @@ SoundIpc(const char *params)
      }
    else if (!strncmp(cmd, "play", 2))
      {
-	SoundPlay(prm);
+	_SoundPlayByName(prm);
      }
 }
 
@@ -398,7 +528,9 @@ static const IpcItem SoundIpcArray[] = {
 
 static const CfgItem SoundCfgItems[] = {
    CFG_ITEM_BOOL(Conf_sound, enable, 0),
-   CFG_ITEM_STR(Conf_sound, theme),
+   CFG_FUNC_STR(Conf_sound, theme, _SoundThemeChange),
+   CFG_ITEM_HEX(Conf_sound, mask1, 0),
+   CFG_ITEM_HEX(Conf_sound, mask2, 0),
 };
 #define N_CFG_ITEMS (sizeof(SoundCfgItems)/sizeof(CfgItem))
 
