@@ -41,9 +41,6 @@ StartupWindowsCreate(void)
    int                 x, y, bx, by, bw, bh;
    EObj               *eo;
 
-   if (!Conf.startup.animate)
-      return;
-
    /* Acting only as boolean? */
    if (BackgroundFind("STARTUP_BACKGROUND_SIDEWAYS"))
       bg_sideways = 1;
@@ -79,8 +76,7 @@ StartupWindowsCreate(void)
    if (!eo)
       return;
    init_win1 = eo;
-   w1 = eo->win;
-   eo->fade = eo->shadow = 0;
+   w1 = EobjGetWin(eo);
    win1 = ECreateWindow(w1, x, y, WinGetW(VROOT), WinGetH(VROOT), 0);
 
    eo = EobjWindowCreate(EOBJ_TYPE_MISC,
@@ -88,8 +84,7 @@ StartupWindowsCreate(void)
    if (!eo)
       return;
    init_win2 = eo;
-   w2 = eo->win;
-   eo->fade = eo->shadow = 0;
+   w2 = EobjGetWin(eo);
    win2 = ECreateWindow(w2, -x, -y, WinGetW(VROOT), WinGetH(VROOT), 0);
 
    EMapWindow(win1);
