@@ -36,6 +36,7 @@
 #include "xwin.h"
 
 static Ecore_List  *tt_list = NULL;
+static Timer       *tt_timer = NULL;
 
 static struct {
    char                enable;
@@ -69,7 +70,6 @@ static void
 TooltipRealize(ToolTip * tt)
 {
    int                 i, wh;
-   EImage             *im;
    EObj               *eo;
 
    for (i = 0; i < 5; i++)
@@ -77,14 +77,13 @@ TooltipRealize(ToolTip * tt)
 	if (!tt->iclass[i])
 	   continue;
 
-	im = ImageclassGetImage(tt->iclass[i], 0, 0, STATE_NORMAL);
-
 	wh = (i + 1) * 8;
 	eo = EobjWindowCreate(EOBJ_TYPE_MISC, -50, -100, wh, wh, 1, tt->name);
+	eo->fade = eo->shadow = 1;
 	EobjChangeOpacity(eo, OpacityFromPercent(Conf.opacity.tooltips));
 	tt->win[i] = eo;
      }
-   tt->iwin = ECreateWindow(tt->TTWIN->win, 0, 0, 1, 1, 0);
+   tt->iwin = ECreateWindow(EobjGetWin(tt->TTWIN), 0, 0, 1, 1, 0);
 }
 
 static ToolTip     *
@@ -93,10 +92,15 @@ TooltipCreate(const char *name, const char *ic0, const char *ic1,
 	      const char *tclass, int dist, const char *tooltippic)
 {
    ToolTip            *tt;
+   ImageClass         *ic;
 
    if (ic0 == NULL || tclass == NULL)
       return NULL;
 
+   ic = ImageclassAlloc(ic0, 0);
+   if (!ic)
+      return NULL;
+
    tt = ECALLOC(ToolTip, 1);
    if (!tt)
       return NULL;
@@ -106,7 +110,7 @@ TooltipCreate(const char *name, const char *ic0, const char *ic1,
    tt->iclass[1] = ImageclassAlloc(ic2, 0);
    tt->iclass[2] = ImageclassAlloc(ic3, 0);
    tt->iclass[3] = ImageclassAlloc(ic4, 0);
-   tt->iclass[4] = ImageclassAlloc(ic0, 0);
+   tt->iclass[4] = ic;
    tt->tclass = TextclassAlloc(tclass, 1);
    tt->tooltippic = ImageclassAlloc(tooltippic, 0);
 
@@ -244,7 +248,8 @@ TooltipIclassPaste(ToolTip * tt, const char *ic_name, int x, int y, int *px)
       return;
 
    EImageGetSize(im, &w, &h);
-   EImageRenderOnDrawable(im, tt->TTWIN->win, None, EIMAGE_BLEND, x, y, w, h);
+   EImageRenderOnDrawable(im, EobjGetWin(tt->TTWIN), None, EIMAGE_BLEND, x, y,
+			  w, h);
 
    *px = x + w;
 }
@@ -565,7 +570,8 @@ TooltipShow(ToolTip * tt, const char *text, ActionClass * ac, int x, int y)
 	eo = tt->win[i];
 	if (!eo)
 	   continue;
-	ImageclassApply(tt->iclass[i], eo->win, 0, 0, STATE_NORMAL, ST_TOOLTIP);
+	ImageclassApply(tt->iclass[i], EobjGetWin(eo), 0, 0, STATE_NORMAL,
+			ST_TOOLTIP);
 	EobjShapeUpdate(eo, 0);
 	EobjMap(eo, 0);
      }
@@ -573,8 +579,8 @@ TooltipShow(ToolTip * tt, const char *text, ActionClass * ac, int x, int y)
    xx = pad->left + iw;
 
    /* draw the ordinary tooltip text */
-   TextDraw(tt->tclass, tt->TTWIN->win, None, 0, 0, STATE_NORMAL, text, xx,
-	    pad->top, headline_w, headline_h, 17, 512);
+   TextDraw(tt->tclass, EobjGetWin(tt->TTWIN), None, 0, 0, STATE_NORMAL, text,
+	    xx, pad->top, headline_w, headline_h, 17, 512);
 
    /* draw the icons and labels, if any */
    if (ac)
@@ -598,9 +604,9 @@ TooltipShow(ToolTip * tt, const char *text, ActionClass * ac, int x, int y)
 
 	     if (ActionGetEvent(aa) == EVENT_DOUBLE_DOWN)
 	       {
-		  TextDraw(tt->tclass, tt->TTWIN->win, None, 0, 0, STATE_NORMAL,
-			   "2x", xx + iw - double_w, y, double_w, heights[i],
-			   17, 0);
+		  TextDraw(tt->tclass, EobjGetWin(tt->TTWIN), None, 0, 0,
+			   STATE_NORMAL, "2x", xx + iw - double_w, y, double_w,
+			   heights[i], 17, 0);
 	       }
 
 	     if (ActionGetAnybutton(aa))
@@ -650,8 +656,8 @@ TooltipShow(ToolTip * tt, const char *text, ActionClass * ac, int x, int y)
 		     TooltipIclassPaste(tt, "TOOLTIP_KEY_MOD5", x, y, &x);
 	       }
 
-	     TextDraw(tt->tclass, tt->TTWIN->win, None, 0, 0, STATE_NORMAL, tts,
-		      pad->left + icons_width + iw, y,
+	     TextDraw(tt->tclass, EobjGetWin(tt->TTWIN), None, 0, 0,
+		      STATE_NORMAL, tts, pad->left + icons_width + iw, y,
 		      labels_width, heights[i], 17, 0);
 	     y += heights[i];
 
@@ -717,8 +723,8 @@ TooltipsEnable(int enable)
 
 static ToolTip     *ttip = NULL;
 
-static void
-ToolTipTimeout(int val __UNUSED__, void *data __UNUSED__)
+static int
+ToolTipTimeout(void *data __UNUSED__)
 {
    int                 x, y;
    unsigned int        mask;
@@ -728,33 +734,37 @@ ToolTipTimeout(int val __UNUSED__, void *data __UNUSED__)
    if (!ttip)
       ttip = TooltipFind("DEFAULT");
    if (!ttip)
-      return;
+      goto done;
 
    /* In the case of multiple screens, check to make sure
     * the root window is still where the mouse is... */
    if (!EQueryPointer(NULL, &x, &y, NULL, &mask))
-      return;
+      goto done;
 
    /* In case this is a virtual root */
    if (x < 0 || y < 0 || x >= WinGetW(VROOT) || y >= WinGetH(VROOT))
-      return;
+      goto done;
 
    /* dont pop up tooltip is mouse button down */
    if (mask &
        (Button1Mask | Button2Mask | Button3Mask | Button4Mask | Button5Mask))
-      return;
+      goto done;
 
    if (!Mode_tooltips.ac_func)
-      return;
+      goto done;
    ac = Mode_tooltips.ac_func(Mode_tooltips.ac_data);
    if (!ac)
-      return;
+      goto done;
 
    tts = ActionclassGetTooltipString(ac);
    if (!tts)
-      return;
+      goto done;
 
    TooltipShow(ttip, _(tts), ac, x, y);
+
+ done:
+   tt_timer = NULL;
+   return 0;
 }
 
 /*
@@ -772,7 +782,7 @@ TooltipsSetPending(int type, CB_GetAclass * func, void *data)
 
    TooltipHide(ttip);
 
-   RemoveTimerEvent("TOOLTIP_TIMEOUT");
+   TIMER_DEL(tt_timer);
 
    if (Conf_tooltips.showroottooltip)
      {
@@ -798,8 +808,7 @@ TooltipsSetPending(int type, CB_GetAclass * func, void *data)
    if (type && !Conf_tooltips.showroottooltip)
       return;
 
-   DoIn("TOOLTIP_TIMEOUT", 0.001 * Conf_tooltips.delay, ToolTipTimeout, 0,
-	NULL);
+   TIMER_ADD(tt_timer, 0.001 * Conf_tooltips.delay, ToolTipTimeout, NULL);
 }
 
 /*
@@ -877,31 +886,13 @@ const DialogDef     DlgTooltips = {
    "CONFIGURE_TOOLTIPS",
    N_("Tooltips"),
    N_("Tooltip Settings"),
-   "SOUND_SETTINGS_TOOLTIPS",
+   SOUND_SETTINGS_TOOLTIPS,
    "pix/tips.png",
    N_("Enlightenment Tooltip\n" "Settings Dialog\n"),
    _DlgFillTooltips,
    DLG_OAC, CB_ConfigureTooltips,
 };
 
-static void
-TooltipsIpc(const char *params)
-{
-   if (params && !strncmp(params, "cfg", 3))
-     {
-	DialogShowSimple(&DlgTooltips, NULL);
-     }
-}
-
-static const IpcItem TooltipsIpcArray[] = {
-   {
-    TooltipsIpc,
-    "tooltips", "tt",
-    "Tooltip functions",
-    "  tooltips cfg          Configure tooltips\n"}
-};
-#define N_IPC_FUNCS (sizeof(TooltipsIpcArray)/sizeof(IpcItem))
-
 static const CfgItem TooltipsCfgItems[] = {
    CFG_ITEM_BOOL(Conf_tooltips, enable, 1),
    CFG_ITEM_BOOL(Conf_tooltips, showroottooltip, 1),
@@ -916,6 +907,6 @@ extern const EModule ModTooltips;
 const EModule       ModTooltips = {
    "tooltips", "tt",
    TooltipsSighan,
-   {N_IPC_FUNCS, TooltipsIpcArray},
+   {0, NULL},
    {N_CFG_ITEMS, TooltipsCfgItems}
 };
