@@ -40,15 +40,11 @@ EFonts_Init(void)
 {
 #if !TEST_TTFONT
    char                s[4096];
-   char              **lst;
-   int                 i, num;
 
    Esnprintf(s, sizeof(s), "%s/ttfonts", Mode.theme.path);
    imlib_add_path_to_font_path(s);
-   lst = StrlistFromString(Conf.theme.ttfont_path, ':', &num);
-   for (i = 0; i < num; i++)
-      imlib_add_path_to_font_path(lst[i]);
-   StrlistFree(lst, num);
+   Esnprintf(s, sizeof(s), "%s/fonts", EDirRoot());
+   imlib_add_path_to_font_path(s);
 #endif
 }
 
@@ -99,7 +95,7 @@ EFont_draw_string(EImage * im, EFont * f, int x, int y,
    imlib_context_set_image(im);
    imlib_context_set_color(r, g, b, 255);
    imlib_context_set_font(f);
-   imlib_text_draw(x, y - imlib_get_font_ascent(), text);
+   imlib_text_draw(x, y - imlib_get_maximum_font_ascent(), text);
 }
 
 typedef struct {
@@ -123,9 +119,8 @@ _ift_Load(TextState * ts, const char *name __UNUSED__)
    if (len > 1000)
       return -1;
 
-   Esnprintf(s, sizeof(s) - 8, "%s.ttf", ts->fontname);
-   strncpy(s, ts->fontname, len);
-   strcpy(s + len, ".ttf");
+   memcpy(s, ts->fontname, len);
+   s[len] = '\0';
    font = Efont_load(s, atoi(ss + 1));
    if (!font)
       return -1;
