@@ -25,7 +25,14 @@
 #define _UTIL_H_
 
 #include "config.h"
+
 #include <stdarg.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+
+#define INT2PTR(i) ((void*)(long)(i))
+#define PTR2INT(p) ((int)(long)(p))
 
 /* Inspired by Xfuncproto.h */
 #if defined(__GNUC__) && ((__GNUC__ * 100 + __GNUC_MINOR__) >= 303)
@@ -38,8 +45,10 @@
 
 #if HAVE___ATTRIBUTE__
 #define __PRINTF_N__(no)  __attribute__((__format__(__printf__, (no), (no)+1)))
+#define __NORETURN__      __attribute__((noreturn))
 #else
 #define __PRINTF_N__(no)
+#define __NORETURN__
 #endif
 #define __PRINTF__   __PRINTF_N__(1)
 #define __PRINTF_2__ __PRINTF_N__(2)
@@ -52,8 +61,18 @@
 #define USE_LIBC_STRNDUP 1	/* Use libc strndup if present */
 #endif
 
+#ifdef HAVE_STRCASECMP
+#define Estrcasecmp(s1, s2) strcasecmp(s1, s2)
+#else
+int                 Estrcasecmp(const char *s1, const char *s2);
+#endif
+#ifdef HAVE_STRCASESTR
+#define Estrcasestr(haystack, needle) strcasestr(haystack, needle)
+#else
+const char         *Estrcasestr(const char *haystack, const char *needle);
+#endif
+
 /* memory.c */
-#include <stdlib.h>
 #define Ecalloc     calloc
 #define Emalloc     malloc
 #define Erealloc    realloc
