@@ -674,12 +674,14 @@ WindowMatchEwinOpsAction(EWin * ewin, int op, const char *args)
 	EoSetDesk(ewin, DeskGet(atoi(args)));
 	break;
 
+#if 0				/* Causes crash */
      case EWIN_OP_AREA:
 	a = b = 0;
 	if (sscanf(args, "%u %u", &a, &b) < 2)
 	   break;
 	EwinMoveToArea(ewin, a, b);	/* FIXME - We should not move here */
 	break;
+#endif
 
      case EWIN_OP_MOVE:
 	a = ewin->client.x;
@@ -698,6 +700,7 @@ WindowMatchEwinOpsAction(EWin * ewin, int op, const char *args)
 	   break;
 	ewin->client.w = a;
 	ewin->client.h = b;
+	ewin->state.maximized_horz = ewin->state.maximized_vert = 0;
 	break;
 
      case EWIN_OP_FULLSCREEN:
@@ -776,6 +779,10 @@ WindowMatchEwinOpsAction(EWin * ewin, int op, const char *args)
      case EWIN_OP_NO_REDIRECT:
 	WINOP_SET_BOOL(ewin->o.noredir, args);
 	break;
+
+     case EWIN_OP_NO_ARGB:
+	WINOP_SET_BOOL(ewin->props.no_argb, args);
+	break;
 #endif
      }
 }
